View source: R/bedrock_operations.R
| bedrock_create_advanced_prompt_optimization_job | R Documentation |
Creates an asynchronous batch job for advanced prompt optimization.
See https://www.paws-r-sdk.com/docs/bedrock_create_advanced_prompt_optimization_job/ for full documentation.
bedrock_create_advanced_prompt_optimization_job(
jobName,
jobDescription = NULL,
clientToken = NULL,
inputConfig,
outputConfig,
encryptionKeyArn = NULL,
tags = NULL,
modelConfigurations
)
jobName |
[required] Name of the advanced prompt optimization job. |
jobDescription |
Description of the advanced prompt optimization job. |
clientToken |
Idempotency token for the request. |
inputConfig |
[required] Input data configuration for the advanced prompt optimization job. |
outputConfig |
[required] Output data configuration for the advanced prompt optimization job. |
encryptionKeyArn |
KMS key ARN for encrypting output data. |
tags |
Tags to associate with the job. |
modelConfigurations |
[required] Model configurations for advanced prompt optimization. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.