bedrock_create_automated_reasoning_policy: Creates an Automated Reasoning policy for Amazon Bedrock...

View source: R/bedrock_operations.R

bedrock_create_automated_reasoning_policyR Documentation

Creates an Automated Reasoning policy for Amazon Bedrock Guardrails

Description

Creates an Automated Reasoning policy for Amazon Bedrock Guardrails. Automated Reasoning policies use mathematical techniques to detect hallucinations, suggest corrections, and highlight unstated assumptions in the responses of your GenAI application.

See https://www.paws-r-sdk.com/docs/bedrock_create_automated_reasoning_policy/ for full documentation.

Usage

bedrock_create_automated_reasoning_policy(
  name,
  description = NULL,
  clientRequestToken = NULL,
  policyDefinition = NULL,
  kmsKeyId = NULL,
  tags = NULL
)

Arguments

name

[required] A unique name for the Automated Reasoning policy. The name must be between 1 and 63 characters and can contain letters, numbers, hyphens, and underscores.

description

A description of the Automated Reasoning policy. Use this to provide context about the policy's purpose and the types of validations it performs.

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than once. If this token matches a previous request, Amazon Bedrock ignores the request but doesn't return an error.

policyDefinition

The policy definition that contains the formal logic rules, variables, and custom variable types used to validate foundation model responses in your application.

kmsKeyId

The identifier of the KMS key to use for encrypting the automated reasoning policy and its associated artifacts. If you don't specify a KMS key, Amazon Bedrock uses an KMS managed key for encryption. For enhanced security and control, you can specify a customer managed KMS key.

tags

A list of tags to associate with the Automated Reasoning policy. Tags help you organize and manage your policies.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.