bedrock_create_automated_reasoning_policy_version: Creates a new version of an existing Automated Reasoning...

View source: R/bedrock_operations.R

bedrock_create_automated_reasoning_policy_versionR Documentation

Creates a new version of an existing Automated Reasoning policy

Description

Creates a new version of an existing Automated Reasoning policy. This allows you to iterate on your policy rules while maintaining previous versions for rollback or comparison purposes.

See https://www.paws-r-sdk.com/docs/bedrock_create_automated_reasoning_policy_version/ for full documentation.

Usage

bedrock_create_automated_reasoning_policy_version(
  policyArn,
  clientRequestToken = NULL,
  lastUpdatedDefinitionHash,
  tags = NULL
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy for which to create a version.

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error.

lastUpdatedDefinitionHash

[required] The hash of the current policy definition used as a concurrency token to ensure the policy hasn't been modified since you last retrieved it.

tags

A list of tags to associate with the policy version.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.