bedrock_create_custom_model_deployment: Deploys a custom model for on-demand inference in Amazon...

View source: R/bedrock_operations.R

bedrock_create_custom_model_deploymentR Documentation

Deploys a custom model for on-demand inference in Amazon Bedrock

Description

Deploys a custom model for on-demand inference in Amazon Bedrock. After you deploy your custom model, you use the deployment's Amazon Resource Name (ARN) as the modelId parameter when you submit prompts and generate responses with model inference.

See https://www.paws-r-sdk.com/docs/bedrock_create_custom_model_deployment/ for full documentation.

Usage

bedrock_create_custom_model_deployment(
  modelDeploymentName,
  modelArn,
  description = NULL,
  tags = NULL,
  clientRequestToken = NULL
)

Arguments

modelDeploymentName

[required] The name for the custom model deployment. The name must be unique within your Amazon Web Services account and Region.

modelArn

[required] The Amazon Resource Name (ARN) of the custom model to deploy for on-demand inference. The custom model must be in the Active state.

description

A description for the custom model deployment to help you identify its purpose.

tags

Tags to assign to the custom model deployment. You can use tags to organize and track your Amazon Web Services resources for cost allocation and management purposes.

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.