bedrock_create_foundation_model_agreement: Request a model access agreement for the specified model

View source: R/bedrock_operations.R

bedrock_create_foundation_model_agreementR Documentation

Request a model access agreement for the specified model

Description

Request a model access agreement for the specified model.

See https://www.paws-r-sdk.com/docs/bedrock_create_foundation_model_agreement/ for full documentation.

Usage

bedrock_create_foundation_model_agreement(offerToken, modelId)

Arguments

offerToken

[required] An offer token encapsulates the information for an offer.

modelId

[required] Model Id of the model for the access request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.