View source: R/bedrock_operations.R
| bedrock_create_guardrail | R Documentation |
Creates a guardrail to block topics and to implement safeguards for your generative AI applications.
See https://www.paws-r-sdk.com/docs/bedrock_create_guardrail/ for full documentation.
bedrock_create_guardrail(
name,
description = NULL,
topicPolicyConfig = NULL,
contentPolicyConfig = NULL,
wordPolicyConfig = NULL,
sensitiveInformationPolicyConfig = NULL,
contextualGroundingPolicyConfig = NULL,
automatedReasoningPolicyConfig = NULL,
crossRegionConfig = NULL,
blockedInputMessaging,
blockedOutputsMessaging,
kmsKeyId = NULL,
tags = NULL,
clientRequestToken = NULL
)
name |
[required] The name to give the guardrail. |
description |
A description of the guardrail. |
topicPolicyConfig |
The topic policies to configure for the guardrail. |
contentPolicyConfig |
The content filter policies to configure for the guardrail. |
wordPolicyConfig |
The word policy you configure for the guardrail. |
sensitiveInformationPolicyConfig |
The sensitive information policy to configure for the guardrail. |
contextualGroundingPolicyConfig |
The contextual grounding policy configuration used to create a guardrail. |
automatedReasoningPolicyConfig |
Optional configuration for integrating Automated Reasoning policies with the new guardrail. |
crossRegionConfig |
The system-defined guardrail profile that you're using with your guardrail. Guardrail profiles define the destination Amazon Web Services Regions where guardrail inference requests can be automatically routed. For more information, see the Amazon Bedrock User Guide. |
blockedInputMessaging |
[required] The message to return when the guardrail blocks a prompt. |
blockedOutputsMessaging |
[required] The message to return when the guardrail blocks a model response. |
kmsKeyId |
The ARN of the KMS key that you use to encrypt the guardrail. |
tags |
The tags that you want to attach to the guardrail. |
clientRequestToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than once. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency in the Amazon S3 User Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.