bedrock_create_prompt_router: Creates a prompt router that manages the routing of requests...

View source: R/bedrock_operations.R

bedrock_create_prompt_routerR Documentation

Creates a prompt router that manages the routing of requests between multiple foundation models based on the routing criteria

Description

Creates a prompt router that manages the routing of requests between multiple foundation models based on the routing criteria.

See https://www.paws-r-sdk.com/docs/bedrock_create_prompt_router/ for full documentation.

Usage

bedrock_create_prompt_router(
  clientRequestToken = NULL,
  promptRouterName,
  models,
  description = NULL,
  routingCriteria,
  fallbackModel,
  tags = NULL
)

Arguments

clientRequestToken

A unique, case-sensitive identifier that you provide to ensure idempotency of your requests. If not specified, the Amazon Web Services SDK automatically generates one for you.

promptRouterName

[required] The name of the prompt router. The name must be unique within your Amazon Web Services account in the current region.

models

[required] A list of foundation models that the prompt router can route requests to. At least one model must be specified.

description

An optional description of the prompt router to help identify its purpose.

routingCriteria

[required] The criteria, which is the response quality difference, used to determine how incoming requests are routed to different models.

fallbackModel

[required] The default model to use when the routing criteria is not met.

tags

An array of key-value pairs to apply to this resource as tags. You can use tags to categorize and manage your Amazon Web Services resources.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.