View source: R/bedrock_operations.R
| bedrock_delete_automated_reasoning_policy | R Documentation |
Deletes an Automated Reasoning policy or policy version. This operation is idempotent. If you delete a policy more than once, each call succeeds. Deleting a policy removes it permanently and cannot be undone.
See https://www.paws-r-sdk.com/docs/bedrock_delete_automated_reasoning_policy/ for full documentation.
bedrock_delete_automated_reasoning_policy(policyArn, force = NULL)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to delete. |
force |
Specifies whether to force delete the automated reasoning policy even if it has active resources. When |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.