bedrock_delete_automated_reasoning_policy_build_workflow: Deletes an Automated Reasoning policy build workflow and its...

View source: R/bedrock_operations.R

bedrock_delete_automated_reasoning_policy_build_workflowR Documentation

Deletes an Automated Reasoning policy build workflow and its associated artifacts

Description

Deletes an Automated Reasoning policy build workflow and its associated artifacts. This permanently removes the workflow history and any generated assets.

See https://www.paws-r-sdk.com/docs/bedrock_delete_automated_reasoning_policy_build_workflow/ for full documentation.

Usage

bedrock_delete_automated_reasoning_policy_build_workflow(
  policyArn,
  buildWorkflowId,
  lastUpdatedAt
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to delete.

buildWorkflowId

[required] The unique identifier of the build workflow to delete.

lastUpdatedAt

[required] The timestamp when the build workflow was last updated. This is used for optimistic concurrency control to prevent accidental deletion of workflows that have been modified.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.