View source: R/bedrock_operations.R
| bedrock_delete_custom_model_deployment | R Documentation |
Deletes a custom model deployment. This operation stops the deployment and removes it from your account. After deletion, the deployment ARN can no longer be used for inference requests.
See https://www.paws-r-sdk.com/docs/bedrock_delete_custom_model_deployment/ for full documentation.
bedrock_delete_custom_model_deployment(customModelDeploymentIdentifier)
customModelDeploymentIdentifier |
[required] The Amazon Resource Name (ARN) or name of the custom model deployment to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.