bedrock_delete_foundation_model_agreement: Delete the model access agreement for the specified model

View source: R/bedrock_operations.R

bedrock_delete_foundation_model_agreementR Documentation

Delete the model access agreement for the specified model

Description

Delete the model access agreement for the specified model.

See https://www.paws-r-sdk.com/docs/bedrock_delete_foundation_model_agreement/ for full documentation.

Usage

bedrock_delete_foundation_model_agreement(modelId)

Arguments

modelId

[required] Model Id of the model access to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.