bedrock_delete_marketplace_model_endpoint: Deletes an endpoint for a model from Amazon Bedrock...

View source: R/bedrock_operations.R

bedrock_delete_marketplace_model_endpointR Documentation

Deletes an endpoint for a model from Amazon Bedrock Marketplace

Description

Deletes an endpoint for a model from Amazon Bedrock Marketplace.

See https://www.paws-r-sdk.com/docs/bedrock_delete_marketplace_model_endpoint/ for full documentation.

Usage

bedrock_delete_marketplace_model_endpoint(endpointArn)

Arguments

endpointArn

[required] The Amazon Resource Name (ARN) of the endpoint you want to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.