Learn R Programming

paws.machine.learning (version 0.8.0)

bedrock_deregister_marketplace_model_endpoint: Deregisters an endpoint for a model from Amazon Bedrock Marketplace

Description

Deregisters an endpoint for a model from Amazon Bedrock Marketplace. This operation removes the endpoint's association with Amazon Bedrock but does not delete the underlying Amazon SageMaker endpoint.

See https://www.paws-r-sdk.com/docs/bedrock_deregister_marketplace_model_endpoint/ for full documentation.

Usage

bedrock_deregister_marketplace_model_endpoint(endpointArn)

Arguments

endpointArn

[required] The Amazon Resource Name (ARN) of the endpoint you want to deregister.