bedrock_get_autom_reaso_polic_build_workf_resul_asset: Retrieves the resulting assets from a completed Automated...

bedrock_get_automated_reasoning_policy_build_workflow_result_assetsR Documentation

Retrieves the resulting assets from a completed Automated Reasoning policy build workflow, including build logs, quality reports, and generated policy artifacts

Description

Retrieves the resulting assets from a completed Automated Reasoning policy build workflow, including build logs, quality reports, and generated policy artifacts.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_build_workflow_result_assets/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_build_workflow_result_assets(
  policyArn,
  buildWorkflowId,
  assetType,
  assetId = NULL
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow assets you want to retrieve.

buildWorkflowId

[required] The unique identifier of the build workflow whose result assets you want to retrieve.

assetType

[required] The type of asset to retrieve (e.g., BUILD_LOG, QUALITY_REPORT, POLICY_DEFINITION, GENERATED_TEST_CASES, POLICY_SCENARIOS, FIDELITY_REPORT, ASSET_MANIFEST, SOURCE_DOCUMENT).

assetId

The unique identifier of the specific asset to retrieve when multiple assets of the same type exist. This is required when retrieving SOURCE_DOCUMENT assets, as multiple source documents may have been used in the workflow. The asset ID can be obtained from the asset manifest.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.