bedrock_get_automated_reasoning_policy: Retrieves details about an Automated Reasoning policy or...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policyR Documentation

Retrieves details about an Automated Reasoning policy or policy version

Description

Retrieves details about an Automated Reasoning policy or policy version. Returns information including the policy definition, metadata, and timestamps.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy(policyArn)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to retrieve. Can be either the unversioned ARN for the draft policy or an ARN for a specific policy version.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.