bedrock_get_automated_reasoning_policy_annotations: Retrieves the current annotations for an Automated Reasoning...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policy_annotationsR Documentation

Retrieves the current annotations for an Automated Reasoning policy build workflow

Description

Retrieves the current annotations for an Automated Reasoning policy build workflow. Annotations contain corrections to the rules, variables and types to be applied to the policy.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_annotations/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_annotations(policyArn, buildWorkflowId)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose annotations you want to retrieve.

buildWorkflowId

[required] The unique identifier of the build workflow whose annotations you want to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.