bedrock_get_automated_reasoning_policy_build_workflow: Retrieves detailed information about an Automated Reasoning...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policy_build_workflowR Documentation

Retrieves detailed information about an Automated Reasoning policy build workflow, including its status, configuration, and metadata

Description

Retrieves detailed information about an Automated Reasoning policy build workflow, including its status, configuration, and metadata.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_build_workflow/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_build_workflow(
  policyArn,
  buildWorkflowId
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to retrieve.

buildWorkflowId

[required] The unique identifier of the build workflow to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.