bedrock_get_automated_reasoning_policy_next_scenario: Retrieves the next test scenario for validating an Automated...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policy_next_scenarioR Documentation

Retrieves the next test scenario for validating an Automated Reasoning policy

Description

Retrieves the next test scenario for validating an Automated Reasoning policy. This is used during the interactive policy refinement process to test policy behavior.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_next_scenario/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_next_scenario(
  policyArn,
  buildWorkflowId
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy for which you want to get the next test scenario.

buildWorkflowId

[required] The unique identifier of the build workflow associated with the test scenarios.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.