bedrock_get_automated_reasoning_policy_test_case: Retrieves details about a specific Automated Reasoning policy...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policy_test_caseR Documentation

Retrieves details about a specific Automated Reasoning policy test

Description

Retrieves details about a specific Automated Reasoning policy test.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_test_case/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_test_case(policyArn, testCaseId)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test.

testCaseId

[required] The unique identifier of the test to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.