bedrock_get_automated_reasoning_policy_test_result: Retrieves the test result for a specific Automated Reasoning...

View source: R/bedrock_operations.R

bedrock_get_automated_reasoning_policy_test_resultR Documentation

Retrieves the test result for a specific Automated Reasoning policy test

Description

Retrieves the test result for a specific Automated Reasoning policy test. Returns detailed validation findings and execution status.

See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_test_result/ for full documentation.

Usage

bedrock_get_automated_reasoning_policy_test_result(
  policyArn,
  buildWorkflowId,
  testCaseId
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy.

buildWorkflowId

[required] The build workflow identifier. The build workflow must display a COMPLETED status to get results.

testCaseId

[required] The unique identifier of the test for which to retrieve results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.