bedrock_get_custom_model_deployment: Retrieves information about a custom model deployment,...

View source: R/bedrock_operations.R

bedrock_get_custom_model_deploymentR Documentation

Retrieves information about a custom model deployment, including its status, configuration, and metadata

Description

Retrieves information about a custom model deployment, including its status, configuration, and metadata. Use this operation to monitor the deployment status and retrieve details needed for inference requests.

See https://www.paws-r-sdk.com/docs/bedrock_get_custom_model_deployment/ for full documentation.

Usage

bedrock_get_custom_model_deployment(customModelDeploymentIdentifier)

Arguments

customModelDeploymentIdentifier

[required] The Amazon Resource Name (ARN) or name of the custom model deployment to retrieve information about.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.