bedrock_get_marketplace_model_endpoint: Retrieves details about a specific endpoint for a model from...

View source: R/bedrock_operations.R

bedrock_get_marketplace_model_endpointR Documentation

Retrieves details about a specific endpoint for a model from Amazon Bedrock Marketplace

Description

Retrieves details about a specific endpoint for a model from Amazon Bedrock Marketplace.

See https://www.paws-r-sdk.com/docs/bedrock_get_marketplace_model_endpoint/ for full documentation.

Usage

bedrock_get_marketplace_model_endpoint(endpointArn)

Arguments

endpointArn

[required] The Amazon Resource Name (ARN) of the endpoint you want to get information about.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.