bedrock_get_resource_policy: Gets the resource policy document for a Bedrock resource

View source: R/bedrock_operations.R

bedrock_get_resource_policyR Documentation

Gets the resource policy document for a Bedrock resource

Description

Gets the resource policy document for a Bedrock resource

See https://www.paws-r-sdk.com/docs/bedrock_get_resource_policy/ for full documentation.

Usage

bedrock_get_resource_policy(resourceArn)

Arguments

resourceArn

[required] The ARN of the Bedrock resource to which this resource policy applies.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.