View source: R/bedrock_operations.R
| bedrock_list_advanced_prompt_optimization_jobs | R Documentation |
Lists all advanced prompt optimization jobs for the account.
See https://www.paws-r-sdk.com/docs/bedrock_list_advanced_prompt_optimization_jobs/ for full documentation.
bedrock_list_advanced_prompt_optimization_jobs(
maxResults = NULL,
nextToken = NULL,
sortBy = NULL,
sortOrder = NULL
)
maxResults |
Maximum number of results to return. |
nextToken |
Pagination token for the next page of results. |
sortBy |
Field to sort by in the returned list of jobs. |
sortOrder |
Sort order for the results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.