bedrock_list_prompt_routers: Retrieves a list of prompt routers

View source: R/bedrock_operations.R

bedrock_list_prompt_routersR Documentation

Retrieves a list of prompt routers

Description

Retrieves a list of prompt routers.

See https://www.paws-r-sdk.com/docs/bedrock_list_prompt_routers/ for full documentation.

Usage

bedrock_list_prompt_routers(maxResults = NULL, nextToken = NULL, type = NULL)

Arguments

maxResults

The maximum number of prompt routers to return in one page of results.

nextToken

Specify the pagination token from a previous request to retrieve the next page of results.

type

The type of the prompt routers, such as whether it's default or custom.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.