Registers an existing Amazon SageMaker endpoint with Amazon Bedrock Marketplace, allowing it to be used with Amazon Bedrock APIs.
See https://www.paws-r-sdk.com/docs/bedrock_register_marketplace_model_endpoint/ for full documentation.
bedrock_register_marketplace_model_endpoint(
endpointIdentifier,
modelSourceIdentifier
)[required] The ARN of the Amazon SageMaker endpoint you want to register with Amazon Bedrock Marketplace.
[required] The ARN of the model from Amazon Bedrock Marketplace that is deployed on the endpoint.