bedrock_start_automated_reasoning_policy_build_workflow: Starts a new build workflow for an Automated Reasoning policy

View source: R/bedrock_operations.R

bedrock_start_automated_reasoning_policy_build_workflowR Documentation

Starts a new build workflow for an Automated Reasoning policy

Description

Starts a new build workflow for an Automated Reasoning policy. This initiates the process of analyzing source documents and generating policy rules, variables, and types.

See https://www.paws-r-sdk.com/docs/bedrock_start_automated_reasoning_policy_build_workflow/ for full documentation.

Usage

bedrock_start_automated_reasoning_policy_build_workflow(
  policyArn,
  buildWorkflowType,
  clientRequestToken = NULL,
  sourceContent
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy for which to start the build workflow.

buildWorkflowType

[required] The type of build workflow to start (e.g., DOCUMENT_INGESTION for processing new documents, POLICY_REPAIR for fixing existing policies).

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than once. If this token matches a previous request, Amazon Bedrock ignores the request but doesn't return an error.

sourceContent

[required] The source content for the build workflow, such as documents to analyze or repair instructions for existing policies.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.