bedrock_start_automated_reasoning_policy_test_workflow: Initiates a test workflow to validate Automated Reasoning...

View source: R/bedrock_operations.R

bedrock_start_automated_reasoning_policy_test_workflowR Documentation

Initiates a test workflow to validate Automated Reasoning policy tests

Description

Initiates a test workflow to validate Automated Reasoning policy tests. The workflow executes the specified tests against the policy and generates validation results.

See https://www.paws-r-sdk.com/docs/bedrock_start_automated_reasoning_policy_test_workflow/ for full documentation.

Usage

bedrock_start_automated_reasoning_policy_test_workflow(
  policyArn,
  buildWorkflowId,
  testCaseIds = NULL,
  clientRequestToken = NULL
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to test.

buildWorkflowId

[required] The build workflow identifier. The build workflow must show a COMPLETED status before running tests.

testCaseIds

The list of test identifiers to run. If not provided, all tests for the policy are run.

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request but doesn't return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.