bedrock_update_automated_reasoning_policy: Updates an existing Automated Reasoning policy with new...

View source: R/bedrock_operations.R

bedrock_update_automated_reasoning_policyR Documentation

Updates an existing Automated Reasoning policy with new rules, variables, or configuration

Description

Updates an existing Automated Reasoning policy with new rules, variables, or configuration. This creates a new version of the policy while preserving the previous version.

See https://www.paws-r-sdk.com/docs/bedrock_update_automated_reasoning_policy/ for full documentation.

Usage

bedrock_update_automated_reasoning_policy(
  policyArn,
  policyDefinition,
  name = NULL,
  description = NULL
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to update. This must be the ARN of a draft policy.

policyDefinition

[required] The updated policy definition containing the formal logic rules, variables, and types.

name

The updated name for the Automated Reasoning policy.

description

The updated description for the Automated Reasoning policy.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.