bedrock_update_automated_reasoning_policy_annotations: Updates the annotations for an Automated Reasoning policy...

View source: R/bedrock_operations.R

bedrock_update_automated_reasoning_policy_annotationsR Documentation

Updates the annotations for an Automated Reasoning policy build workflow

Description

Updates the annotations for an Automated Reasoning policy build workflow. This allows you to modify extracted rules, variables, and types before finalizing the policy.

See https://www.paws-r-sdk.com/docs/bedrock_update_automated_reasoning_policy_annotations/ for full documentation.

Usage

bedrock_update_automated_reasoning_policy_annotations(
  policyArn,
  buildWorkflowId,
  annotations,
  lastUpdatedAnnotationSetHash
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose annotations you want to update.

buildWorkflowId

[required] The unique identifier of the build workflow whose annotations you want to update.

annotations

[required] The updated annotations containing modified rules, variables, and types for the policy.

lastUpdatedAnnotationSetHash

[required] The hash value of the annotation set that you're updating. This is used for optimistic concurrency control to prevent conflicting updates.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.