bedrock_update_automated_reasoning_policy_test_case: Updates an existing Automated Reasoning policy test

View source: R/bedrock_operations.R

bedrock_update_automated_reasoning_policy_test_caseR Documentation

Updates an existing Automated Reasoning policy test

Description

Updates an existing Automated Reasoning policy test. You can modify the content, query, expected result, and confidence threshold.

See https://www.paws-r-sdk.com/docs/bedrock_update_automated_reasoning_policy_test_case/ for full documentation.

Usage

bedrock_update_automated_reasoning_policy_test_case(
  policyArn,
  testCaseId,
  guardContent,
  queryContent = NULL,
  lastUpdatedAt,
  expectedAggregatedFindingsResult,
  confidenceThreshold = NULL,
  clientRequestToken = NULL
)

Arguments

policyArn

[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test.

testCaseId

[required] The unique identifier of the test to update.

guardContent

[required] The updated content to be validated by the Automated Reasoning policy.

queryContent

The updated input query or prompt that generated the content.

lastUpdatedAt

[required] The timestamp when the test was last updated. This is used as a concurrency token to prevent conflicting modifications.

expectedAggregatedFindingsResult

[required] The updated expected result of the Automated Reasoning check.

confidenceThreshold

The updated minimum confidence level for logic validation. If null is provided, the threshold will be removed.

clientRequestToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.