bedrock_update_custom_model_deployment: Updates a custom model deployment with a new custom model

View source: R/bedrock_operations.R

bedrock_update_custom_model_deploymentR Documentation

Updates a custom model deployment with a new custom model

Description

Updates a custom model deployment with a new custom model. This allows you to deploy updated models without creating new deployment endpoints.

See https://www.paws-r-sdk.com/docs/bedrock_update_custom_model_deployment/ for full documentation.

Usage

bedrock_update_custom_model_deployment(
  modelArn,
  customModelDeploymentIdentifier
)

Arguments

modelArn

[required] ARN of the new custom model to deploy. This replaces the currently deployed model.

customModelDeploymentIdentifier

[required] Identifier of the custom model deployment to update with the new custom model.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.