bedrock_update_guardrail: Updates a guardrail with the values you specify

View source: R/bedrock_operations.R

bedrock_update_guardrailR Documentation

Updates a guardrail with the values you specify

Description

Updates a guardrail with the values you specify.

See https://www.paws-r-sdk.com/docs/bedrock_update_guardrail/ for full documentation.

Usage

bedrock_update_guardrail(
  guardrailIdentifier,
  name,
  description = NULL,
  topicPolicyConfig = NULL,
  contentPolicyConfig = NULL,
  wordPolicyConfig = NULL,
  sensitiveInformationPolicyConfig = NULL,
  contextualGroundingPolicyConfig = NULL,
  automatedReasoningPolicyConfig = NULL,
  crossRegionConfig = NULL,
  blockedInputMessaging,
  blockedOutputsMessaging,
  kmsKeyId = NULL
)

Arguments

guardrailIdentifier

[required] The unique identifier of the guardrail. This can be an ID or the ARN.

name

[required] A name for the guardrail.

description

A description of the guardrail.

topicPolicyConfig

The topic policy to configure for the guardrail.

contentPolicyConfig

The content policy to configure for the guardrail.

wordPolicyConfig

The word policy to configure for the guardrail.

sensitiveInformationPolicyConfig

The sensitive information policy to configure for the guardrail.

contextualGroundingPolicyConfig

The contextual grounding policy configuration used to update a guardrail.

automatedReasoningPolicyConfig

Updated configuration for Automated Reasoning policies associated with the guardrail.

crossRegionConfig

The system-defined guardrail profile that you're using with your guardrail. Guardrail profiles define the destination Amazon Web Services Regions where guardrail inference requests can be automatically routed.

For more information, see the Amazon Bedrock User Guide.

blockedInputMessaging

[required] The message to return when the guardrail blocks a prompt.

blockedOutputsMessaging

[required] The message to return when the guardrail blocks a model response.

kmsKeyId

The ARN of the KMS key with which to encrypt the guardrail.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.