bedrockagent_associate_agent_knowledge_base: Associates a knowledge base with an agent

View source: R/bedrockagent_operations.R

bedrockagent_associate_agent_knowledge_baseR Documentation

Associates a knowledge base with an agent

Description

Associates a knowledge base with an agent. If a knowledge base is associated and its indexState is set to Enabled, the agent queries the knowledge base for information to augment its response to the user.

See https://www.paws-r-sdk.com/docs/bedrockagent_associate_agent_knowledge_base/ for full documentation.

Usage

bedrockagent_associate_agent_knowledge_base(
  agentId,
  agentVersion,
  knowledgeBaseId,
  description,
  knowledgeBaseState = NULL
)

Arguments

agentId

[required] The unique identifier of the agent with which you want to associate the knowledge base.

agentVersion

[required] The version of the agent with which you want to associate the knowledge base.

knowledgeBaseId

[required] The unique identifier of the knowledge base to associate with the agent.

description

[required] A description of what the agent should use the knowledge base for.

knowledgeBaseState

Specifies whether to use the knowledge base or not when sending an InvokeAgent request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.