bedrockagent_create_data_source: Connects a knowledge base to a data source

View source: R/bedrockagent_operations.R

bedrockagent_create_data_sourceR Documentation

Connects a knowledge base to a data source

Description

Connects a knowledge base to a data source. You specify the configuration for the specific data source service in the dataSourceConfiguration field.

See https://www.paws-r-sdk.com/docs/bedrockagent_create_data_source/ for full documentation.

Usage

bedrockagent_create_data_source(
  knowledgeBaseId,
  clientToken = NULL,
  name,
  description = NULL,
  dataSourceConfiguration,
  dataDeletionPolicy = NULL,
  serverSideEncryptionConfiguration = NULL,
  vectorIngestionConfiguration = NULL
)

Arguments

knowledgeBaseId

[required] The unique identifier of the knowledge base to which to add the data source.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

name

[required] The name of the data source.

description

A description of the data source.

dataSourceConfiguration

[required] The connection configuration for the data source.

dataDeletionPolicy

The data deletion policy for the data source.

You can set the data deletion policy to:

  • DELETE: Deletes all data from your data source that’s converted into vector embeddings upon deletion of a knowledge base or data source resource. Note that the vector store itself is not deleted, only the data. This flag is ignored if an Amazon Web Services account is deleted.

  • RETAIN: Retains all data from your data source that’s converted into vector embeddings upon deletion of a knowledge base or data source resource. Note that the vector store itself is not deleted if you delete a knowledge base or data source resource.

serverSideEncryptionConfiguration

Contains details about the server-side encryption for the data source.

vectorIngestionConfiguration

Contains details about how to ingest the documents in the data source.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.