bedrockagent_create_flow_version: Creates a version of the flow that you can deploy

View source: R/bedrockagent_operations.R

bedrockagent_create_flow_versionR Documentation

Creates a version of the flow that you can deploy

Description

Creates a version of the flow that you can deploy. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

See https://www.paws-r-sdk.com/docs/bedrockagent_create_flow_version/ for full documentation.

Usage

bedrockagent_create_flow_version(
  flowIdentifier,
  description = NULL,
  clientToken = NULL
)

Arguments

flowIdentifier

[required] The unique identifier of the flow that you want to create a version of.

description

A description of the version of the flow.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.