bedrockagent_create_knowledge_base: Creates a knowledge base

View source: R/bedrockagent_operations.R

bedrockagent_create_knowledge_baseR Documentation

Creates a knowledge base

Description

Creates a knowledge base. A knowledge base contains your data sources so that Large Language Models (LLMs) can use your data. To create a knowledge base, you must first set up your data sources and configure a supported vector store. For more information, see Set up a knowledge base.

See https://www.paws-r-sdk.com/docs/bedrockagent_create_knowledge_base/ for full documentation.

Usage

bedrockagent_create_knowledge_base(
  clientToken = NULL,
  name,
  description = NULL,
  roleArn,
  knowledgeBaseConfiguration,
  storageConfiguration = NULL,
  tags = NULL
)

Arguments

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

name

[required] A name for the knowledge base.

description

A description of the knowledge base.

roleArn

[required] The Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the knowledge base.

knowledgeBaseConfiguration

[required] Contains details about the embeddings model used for the knowledge base.

storageConfiguration

Contains details about the configuration of the vector database used for the knowledge base.

tags

Specify the key-value pairs for the tags that you want to attach to your knowledge base in this object.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.