bedrockagent_create_prompt_version: Creates a static snapshot of your prompt that can be deployed...

View source: R/bedrockagent_operations.R

bedrockagent_create_prompt_versionR Documentation

Creates a static snapshot of your prompt that can be deployed to production

Description

Creates a static snapshot of your prompt that can be deployed to production. For more information, see Deploy prompts using Prompt management by creating versions in the Amazon Bedrock User Guide.

See https://www.paws-r-sdk.com/docs/bedrockagent_create_prompt_version/ for full documentation.

Usage

bedrockagent_create_prompt_version(
  promptIdentifier,
  description = NULL,
  clientToken = NULL,
  tags = NULL
)

Arguments

promptIdentifier

[required] The unique identifier of the prompt that you want to create a version of.

description

A description for the version of the prompt.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

tags

Any tags that you want to attach to the version of the prompt. For more information, see Tagging resources in Amazon Bedrock.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.