bedrockagent_delete_agent_action_group: Deletes an action group in an agent

View source: R/bedrockagent_operations.R

bedrockagent_delete_agent_action_groupR Documentation

Deletes an action group in an agent

Description

Deletes an action group in an agent.

See https://www.paws-r-sdk.com/docs/bedrockagent_delete_agent_action_group/ for full documentation.

Usage

bedrockagent_delete_agent_action_group(
  agentId,
  agentVersion,
  actionGroupId,
  skipResourceInUseCheck = NULL
)

Arguments

agentId

[required] The unique identifier of the agent that the action group belongs to.

agentVersion

[required] The version of the agent that the action group belongs to.

actionGroupId

[required] The unique identifier of the action group to delete.

skipResourceInUseCheck

By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.