bedrockagent_delete_flow_alias: Deletes an alias of a flow

View source: R/bedrockagent_operations.R

bedrockagent_delete_flow_aliasR Documentation

Deletes an alias of a flow

Description

Deletes an alias of a flow.

See https://www.paws-r-sdk.com/docs/bedrockagent_delete_flow_alias/ for full documentation.

Usage

bedrockagent_delete_flow_alias(flowIdentifier, aliasIdentifier)

Arguments

flowIdentifier

[required] The unique identifier of the flow that the alias belongs to.

aliasIdentifier

[required] The unique identifier of the alias to be deleted.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.