bedrockagent_delete_knowledge_base_documents: Deletes documents from a data source and syncs the changes to...

View source: R/bedrockagent_operations.R

bedrockagent_delete_knowledge_base_documentsR Documentation

Deletes documents from a data source and syncs the changes to the knowledge base that is connected to it

Description

Deletes documents from a data source and syncs the changes to the knowledge base that is connected to it. For more information, see Ingest changes directly into a knowledge base in the Amazon Bedrock User Guide.

See https://www.paws-r-sdk.com/docs/bedrockagent_delete_knowledge_base_documents/ for full documentation.

Usage

bedrockagent_delete_knowledge_base_documents(
  knowledgeBaseId,
  dataSourceId,
  clientToken = NULL,
  documentIdentifiers
)

Arguments

knowledgeBaseId

[required] The unique identifier of the knowledge base that is connected to the data source.

dataSourceId

[required] The unique identifier of the data source that contains the documents.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

documentIdentifiers

[required] A list of objects, each of which contains information to identify a document to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.