bedrockagent_get_agent_action_group: Gets information about an action group for an agent

View source: R/bedrockagent_operations.R

bedrockagent_get_agent_action_groupR Documentation

Gets information about an action group for an agent

Description

Gets information about an action group for an agent.

See https://www.paws-r-sdk.com/docs/bedrockagent_get_agent_action_group/ for full documentation.

Usage

bedrockagent_get_agent_action_group(agentId, agentVersion, actionGroupId)

Arguments

agentId

[required] The unique identifier of the agent that the action group belongs to.

agentVersion

[required] The version of the agent that the action group belongs to.

actionGroupId

[required] The unique identifier of the action group for which to get information.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.