bedrockagent_get_agent_alias: Gets information about an alias of an agent

View source: R/bedrockagent_operations.R

bedrockagent_get_agent_aliasR Documentation

Gets information about an alias of an agent

Description

Gets information about an alias of an agent.

See https://www.paws-r-sdk.com/docs/bedrockagent_get_agent_alias/ for full documentation.

Usage

bedrockagent_get_agent_alias(agentId, agentAliasId)

Arguments

agentId

[required] The unique identifier of the agent to which the alias to get information belongs.

agentAliasId

[required] The unique identifier of the alias for which to get information.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.