bedrockagent_get_flow_alias: Retrieves information about a flow

View source: R/bedrockagent_operations.R

bedrockagent_get_flow_aliasR Documentation

Retrieves information about a flow

Description

Retrieves information about a flow. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

See https://www.paws-r-sdk.com/docs/bedrockagent_get_flow_alias/ for full documentation.

Usage

bedrockagent_get_flow_alias(flowIdentifier, aliasIdentifier)

Arguments

flowIdentifier

[required] The unique identifier of the flow that the alias belongs to.

aliasIdentifier

[required] The unique identifier of the alias for which to retrieve information.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.