View source: R/bedrockagent_operations.R
| bedrockagent_ingest_knowledge_base_documents | R Documentation |
Ingests documents directly into the knowledge base that is connected to the data source. The dataSourceType specified in the content for each document must match the type of the data source that you specify in the header. For more information, see Ingest changes directly into a knowledge base in the Amazon Bedrock User Guide.
See https://www.paws-r-sdk.com/docs/bedrockagent_ingest_knowledge_base_documents/ for full documentation.
bedrockagent_ingest_knowledge_base_documents(
knowledgeBaseId,
dataSourceId,
clientToken = NULL,
documents
)
knowledgeBaseId |
[required] The unique identifier of the knowledge base to ingest the documents into. |
dataSourceId |
[required] The unique identifier of the data source connected to the knowledge base that you're adding documents to. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency. |
documents |
[required] A list of objects, each of which contains information about the documents to add. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.