bedrockagent_start_ingestion_job: Begins a data ingestion job

View source: R/bedrockagent_operations.R

bedrockagent_start_ingestion_jobR Documentation

Begins a data ingestion job

Description

Begins a data ingestion job. Data sources are ingested into your knowledge base so that Large Language Models (LLMs) can use your data.

See https://www.paws-r-sdk.com/docs/bedrockagent_start_ingestion_job/ for full documentation.

Usage

bedrockagent_start_ingestion_job(
  knowledgeBaseId,
  dataSourceId,
  clientToken = NULL,
  description = NULL
)

Arguments

knowledgeBaseId

[required] The unique identifier of the knowledge base for the data ingestion job.

dataSourceId

[required] The unique identifier of the data source you want to ingest into your knowledge base.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

description

A description of the data ingestion job.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.