bedrockagent_stop_ingestion_job: Stops a currently running data ingestion job

View source: R/bedrockagent_operations.R

bedrockagent_stop_ingestion_jobR Documentation

Stops a currently running data ingestion job

Description

Stops a currently running data ingestion job. You can send a start_ingestion_job request again to ingest the rest of your data when you are ready.

See https://www.paws-r-sdk.com/docs/bedrockagent_stop_ingestion_job/ for full documentation.

Usage

bedrockagent_stop_ingestion_job(knowledgeBaseId, dataSourceId, ingestionJobId)

Arguments

knowledgeBaseId

[required] The unique identifier of the knowledge base for the data ingestion job you want to stop.

dataSourceId

[required] The unique identifier of the data source for the data ingestion job you want to stop.

ingestionJobId

[required] The unique identifier of the data ingestion job you want to stop.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.