View source: R/bedrockagent_operations.R
| bedrockagent_update_agent_alias | R Documentation |
Updates configurations for an alias of an agent.
See https://www.paws-r-sdk.com/docs/bedrockagent_update_agent_alias/ for full documentation.
bedrockagent_update_agent_alias(
agentId,
agentAliasId,
agentAliasName,
description = NULL,
routingConfiguration = NULL,
aliasInvocationState = NULL
)
agentId |
[required] The unique identifier of the agent. |
agentAliasId |
[required] The unique identifier of the alias. |
agentAliasName |
[required] Specifies a new name for the alias. |
description |
Specifies a new description for the alias. |
routingConfiguration |
Contains details about the routing configuration of the alias. |
aliasInvocationState |
The invocation state for the agent alias. To pause the agent alias, set the value to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.