bedrockagent_update_data_source: Updates the configurations for a data source connector

View source: R/bedrockagent_operations.R

bedrockagent_update_data_sourceR Documentation

Updates the configurations for a data source connector

Description

Updates the configurations for a data source connector.

See https://www.paws-r-sdk.com/docs/bedrockagent_update_data_source/ for full documentation.

Usage

bedrockagent_update_data_source(
  knowledgeBaseId,
  dataSourceId,
  name,
  description = NULL,
  dataSourceConfiguration,
  dataDeletionPolicy = NULL,
  serverSideEncryptionConfiguration = NULL,
  vectorIngestionConfiguration = NULL
)

Arguments

knowledgeBaseId

[required] The unique identifier of the knowledge base for the data source.

dataSourceId

[required] The unique identifier of the data source.

name

[required] Specifies a new name for the data source.

description

Specifies a new description for the data source.

dataSourceConfiguration

[required] The connection configuration for the data source that you want to update.

dataDeletionPolicy

The data deletion policy for the data source that you want to update.

serverSideEncryptionConfiguration

Contains details about server-side encryption of the data source.

vectorIngestionConfiguration

Contains details about how to ingest the documents in the data source.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.