bedrockagent_update_flow_alias: Modifies the alias of a flow

View source: R/bedrockagent_operations.R

bedrockagent_update_flow_aliasR Documentation

Modifies the alias of a flow

Description

Modifies the alias of a flow. Include both fields that you want to keep and ones that you want to change. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.

See https://www.paws-r-sdk.com/docs/bedrockagent_update_flow_alias/ for full documentation.

Usage

bedrockagent_update_flow_alias(
  name,
  description = NULL,
  routingConfiguration,
  concurrencyConfiguration = NULL,
  flowIdentifier,
  aliasIdentifier
)

Arguments

name

[required] The name of the alias.

description

A description for the alias.

routingConfiguration

[required] Contains information about the version to which to map the alias.

concurrencyConfiguration

The configuration that specifies how nodes in the flow are executed in parallel.

flowIdentifier

[required] The unique identifier of the flow.

aliasIdentifier

[required] The unique identifier of the alias.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.