View source: R/bedrockagentcore_service.R
| bedrockagentcore | R Documentation |
Welcome to the Amazon Bedrock AgentCore Data Plane API reference. Data Plane actions process and handle data or workloads within Amazon Web Services services.
bedrockagentcore(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- bedrockagentcore(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| batch_create_memory_records | Creates multiple memory records in a single batch operation for the specified memory with custom content |
| batch_delete_memory_records | Deletes multiple memory records in a single batch operation from the specified memory |
| batch_update_memory_records | Updates multiple memory records with custom content in a single batch operation within the specified memory |
| complete_resource_token_auth | Confirms the user authentication session for obtaining OAuth2 |
| create_ab_test | Creates an A/B test for comparing agent configurations |
| create_event | Creates an event in an AgentCore Memory resource |
| create_payment_instrument | Create a new payment instrument for a connector |
| create_payment_session | Create a new payment session |
| delete_ab_test | Deletes an A/B test and its associated gateway rules |
| delete_batch_evaluation | Deletes a batch evaluation and its associated results |
| delete_event | Deletes an event from an AgentCore Memory resource |
| delete_memory_record | Deletes a memory record from an AgentCore Memory resource |
| delete_payment_instrument | Deletes a payment instrument |
| delete_payment_session | Deletes a payment session |
| delete_recommendation | Deletes a recommendation and its associated results |
| evaluate | Performs on-demand evaluation of agent traces using a specified evaluator |
| get_ab_test | Retrieves detailed information about an A/B test, including its configuration, status, and statistical results |
| get_agent_card | Retrieves the A2A agent card associated with an AgentCore Runtime agent |
| get_batch_evaluation | Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details |
| get_browser_session | Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore |
| get_code_interpreter_session | Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore |
| get_event | Retrieves information about a specific event in an AgentCore Memory resource |
| get_memory_record | Retrieves a specific memory record from an AgentCore Memory resource |
| get_payment_instrument | Get a payment instrument by ID |
| get_payment_instrument_balance | Get the balance of a payment instrument |
| get_payment_session | Get a payment session |
| get_recommendation | Retrieves detailed information about a recommendation, including its configuration, status, and results |
| get_resource_api_key | Retrieves the API key associated with an API key credential provider |
| get_resource_oauth_2_token | Returns the OAuth 2 |
| get_resource_payment_token | Generates authentication tokens for payment providers that use vendor-specific authentication mechanisms |
| get_workload_access_token | Obtains a workload access token for agentic workloads not acting on behalf of a user |
| get_workload_access_token_for_jwt | Obtains a workload access token for agentic workloads acting on behalf of a user, using a JWT token |
| get_workload_access_token_for_user_id | Obtains a workload access token for agentic workloads acting on behalf of a user, using the user's ID |
| invoke_agent_runtime | Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time |
| invoke_agent_runtime_command | Executes a command in a runtime session container and streams the output back to the caller |
| invoke_browser | Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore |
| invoke_code_interpreter | Executes code within an active code interpreter session in Amazon Bedrock AgentCore |
| invoke_harness | Operation to invoke a Harness |
| list_ab_tests | Lists all A/B tests in the account |
| list_actors | Lists all actors in an AgentCore Memory resource |
| list_batch_evaluations | Lists all batch evaluations in the account, providing summary information about each evaluation's status and configuration |
| list_browser_sessions | Retrieves a list of browser sessions in Amazon Bedrock AgentCore that match the specified criteria |
| list_code_interpreter_sessions | Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria |
| list_events | Lists events in an AgentCore Memory resource based on specified criteria |
| list_memory_extraction_jobs | Lists all long-term memory extraction jobs that are eligible to be started with optional filtering |
| list_memory_records | Lists memory records in an AgentCore Memory resource based on specified criteria |
| list_payment_instruments | List payment instruments for a manager |
| list_payment_sessions | List payment sessions |
| list_recommendations | Lists all recommendations in the account, with optional filtering by status |
| list_sessions | Lists sessions in an AgentCore Memory resource based on specified criteria |
| process_payment | Processes a payment using a payment instrument within a payment session |
| retrieve_memory_records | Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria |
| save_browser_session_profile | Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore |
| search_registry_records | Searches for registry records using semantic, lexical, or hybrid queries |
| start_batch_evaluation | Starts a batch evaluation job that evaluates agent performance across multiple sessions |
| start_browser_session | Creates and initializes a browser session in Amazon Bedrock AgentCore |
| start_code_interpreter_session | Creates and initializes a code interpreter session in Amazon Bedrock AgentCore |
| start_memory_extraction_job | Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records |
| start_recommendation | Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance |
| stop_batch_evaluation | Stops a running batch evaluation |
| stop_browser_session | Terminates an active browser session in Amazon Bedrock AgentCore |
| stop_code_interpreter_session | Terminates an active code interpreter session in Amazon Bedrock AgentCore |
| stop_runtime_session | Stops a session that is running in an running AgentCore Runtime agent |
| update_ab_test | Updates an A/B test's configuration, including variants, traffic allocation, evaluation settings, or execution status |
| update_browser_stream | Updates a browser stream |
## Not run:
svc <- bedrockagentcore()
svc$batch_create_memory_records(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.