bedrockagentcore_batch_create_memory_records: Creates multiple memory records in a single batch operation...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_batch_create_memory_recordsR Documentation

Creates multiple memory records in a single batch operation for the specified memory with custom content

Description

Creates multiple memory records in a single batch operation for the specified memory with custom content.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_create_memory_records/ for full documentation.

Usage

bedrockagentcore_batch_create_memory_records(
  memoryId,
  records,
  clientToken = NULL
)

Arguments

memoryId

[required] The unique ID of the memory resource where records will be created.

records

[required] A list of memory record creation inputs to be processed in the batch operation.

clientToken

A unique, case-sensitive identifier to ensure idempotent processing of the batch request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.