bedrockagentcore_batch_delete_memory_records: Deletes multiple memory records in a single batch operation...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_batch_delete_memory_recordsR Documentation

Deletes multiple memory records in a single batch operation from the specified memory

Description

Deletes multiple memory records in a single batch operation from the specified memory.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_delete_memory_records/ for full documentation.

Usage

bedrockagentcore_batch_delete_memory_records(memoryId, records)

Arguments

memoryId

[required] The unique ID of the memory resource where records will be deleted.

records

[required] A list of memory record deletion inputs to be processed in the batch operation.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.