bedrockagentcore_batch_update_memory_records: Updates multiple memory records with custom content in a...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_batch_update_memory_recordsR Documentation

Updates multiple memory records with custom content in a single batch operation within the specified memory

Description

Updates multiple memory records with custom content in a single batch operation within the specified memory.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_update_memory_records/ for full documentation.

Usage

bedrockagentcore_batch_update_memory_records(memoryId, records)

Arguments

memoryId

[required] The unique ID of the memory resource where records will be updated.

records

[required] A list of memory record update inputs to be processed in the batch operation.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.