bedrockagentcore_complete_resource_token_auth: Confirms the user authentication session for obtaining OAuth2

View source: R/bedrockagentcore_operations.R

bedrockagentcore_complete_resource_token_authR Documentation

Confirms the user authentication session for obtaining OAuth2

Description

Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_complete_resource_token_auth/ for full documentation.

Usage

bedrockagentcore_complete_resource_token_auth(userIdentifier, sessionUri)

Arguments

userIdentifier

[required] The OAuth2.0 token or user ID that was used to generate the workload access token used for initiating the user authorization flow to retrieve OAuth2.0 tokens.

sessionUri

[required] Unique identifier for the user's authentication session for retrieving OAuth2 tokens. This ID tracks the authorization flow state across multiple requests and responses during the OAuth2 authentication process.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.