View source: R/bedrockagentcore_operations.R
| bedrockagentcore_create_event | R Documentation |
Creates an event in an AgentCore Memory resource. Events represent interactions or activities that occur within a session and are associated with specific actors.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_create_event/ for full documentation.
bedrockagentcore_create_event(
memoryId,
actorId,
sessionId = NULL,
eventTimestamp,
payload,
branch = NULL,
clientToken = NULL,
metadata = NULL
)
memoryId |
[required] The identifier of the AgentCore Memory resource in which to create the event. |
actorId |
[required] The identifier of the actor associated with this event. An actor represents an entity that participates in sessions and generates events. |
sessionId |
The identifier of the session in which this event occurs. A session represents a sequence of related events. |
eventTimestamp |
[required] The timestamp when the event occurred. If not specified, the current time is used. |
payload |
[required] The content payload of the event. This can include conversational data or binary content. |
branch |
The branch information for this event. Branches allow for organizing events into different conversation threads or paths. |
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, AgentCore ignores the request, but does not return an error. |
metadata |
The key-value metadata to attach to the event. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.