bedrockagentcore_delete_event: Deletes an event from an AgentCore Memory resource

View source: R/bedrockagentcore_operations.R

bedrockagentcore_delete_eventR Documentation

Deletes an event from an AgentCore Memory resource

Description

Deletes an event from an AgentCore Memory resource. When you delete an event, it is permanently removed.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_delete_event/ for full documentation.

Usage

bedrockagentcore_delete_event(memoryId, sessionId, eventId, actorId)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource from which to delete the event.

sessionId

[required] The identifier of the session containing the event to delete.

eventId

[required] The identifier of the event to delete.

actorId

[required] The identifier of the actor associated with the event to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.