bedrockagentcore_delete_memory_record: Deletes a memory record from an AgentCore Memory resource

View source: R/bedrockagentcore_operations.R

bedrockagentcore_delete_memory_recordR Documentation

Deletes a memory record from an AgentCore Memory resource

Description

Deletes a memory record from an AgentCore Memory resource. When you delete a memory record, it is permanently removed.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_delete_memory_record/ for full documentation.

Usage

bedrockagentcore_delete_memory_record(memoryId, memoryRecordId)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource from which to delete the memory record.

memoryRecordId

[required] The identifier of the memory record to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.