bedrockagentcore_get_agent_card: Retrieves the A2A agent card associated with an AgentCore...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_agent_cardR Documentation

Retrieves the A2A agent card associated with an AgentCore Runtime agent

Description

Retrieves the A2A agent card associated with an AgentCore Runtime agent.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_agent_card/ for full documentation.

Usage

bedrockagentcore_get_agent_card(
  runtimeSessionId = NULL,
  agentRuntimeArn,
  qualifier = NULL
)

Arguments

runtimeSessionId

The session ID that the AgentCore Runtime agent is using.

agentRuntimeArn

[required] The ARN of the AgentCore Runtime agent for which you want to get the A2A agent card.

qualifier

Optional qualifier to specify an agent alias, such as prodcode\> or dev. If you don't provide a value, the DEFAULT alias is used.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.