View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_batch_evaluation | R Documentation |
Retrieves detailed information about a batch evaluation, including its status, configuration, results, and any error details.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_batch_evaluation/ for full documentation.
bedrockagentcore_get_batch_evaluation(batchEvaluationId)
batchEvaluationId |
[required] The unique identifier of the batch evaluation to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.