bedrockagentcore_get_browser_session: Retrieves detailed information about a specific browser...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_browser_sessionR Documentation

Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore

Description

Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, associated streams, and metadata.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_browser_session/ for full documentation.

Usage

bedrockagentcore_get_browser_session(browserIdentifier, sessionId)

Arguments

browserIdentifier

[required] The unique identifier of the browser associated with the session.

sessionId

[required] The unique identifier of the browser session to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.