bedrockagentcore_get_code_interpreter_session: Retrieves detailed information about a specific code...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_code_interpreter_sessionR Documentation

Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore

Description

Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, and metadata.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_code_interpreter_session/ for full documentation.

Usage

bedrockagentcore_get_code_interpreter_session(
  codeInterpreterIdentifier,
  sessionId
)

Arguments

codeInterpreterIdentifier

[required] The unique identifier of the code interpreter associated with the session.

sessionId

[required] The unique identifier of the code interpreter session to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.