bedrockagentcore_get_event: Retrieves information about a specific event in an AgentCore...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_eventR Documentation

Retrieves information about a specific event in an AgentCore Memory resource

Description

Retrieves information about a specific event in an AgentCore Memory resource.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_event/ for full documentation.

Usage

bedrockagentcore_get_event(memoryId, sessionId, actorId, eventId)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource containing the event.

sessionId

[required] The identifier of the session containing the event.

actorId

[required] The identifier of the actor associated with the event.

eventId

[required] The identifier of the event to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.