bedrockagentcore_get_payment_instrument: Get a payment instrument by ID

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_payment_instrumentR Documentation

Get a payment instrument by ID

Description

Get a payment instrument by ID.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_payment_instrument/ for full documentation.

Usage

bedrockagentcore_get_payment_instrument(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  paymentConnectorId = NULL,
  paymentInstrumentId
)

Arguments

userId

The user ID associated with this payment instrument.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager that owns this payment instrument.

paymentConnectorId

The ID of the payment connector.

paymentInstrumentId

[required] The ID of the payment instrument to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.