bedrockagentcore_get_payment_instrument_balance: Get the balance of a payment instrument

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_payment_instrument_balanceR Documentation

Get the balance of a payment instrument

Description

Get the balance of a payment instrument.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_payment_instrument_balance/ for full documentation.

Usage

bedrockagentcore_get_payment_instrument_balance(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  paymentConnectorId,
  paymentInstrumentId,
  chain,
  token
)

Arguments

userId

The user ID associated with this payment instrument.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager that owns this payment instrument.

paymentConnectorId

[required] The ID of the payment connector associated with this instrument.

paymentInstrumentId

[required] The ID of the payment instrument to query balance for.

chain

[required] The specific blockchain chain to query balance on. Required because balances are chain-specific.

token

[required] The token to query balance for. Only tokens supported for X402 payments are returned.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.