bedrockagentcore_get_payment_session: Get a payment session

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_payment_sessionR Documentation

Get a payment session

Description

Get a payment session.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_payment_session/ for full documentation.

Usage

bedrockagentcore_get_payment_session(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  paymentSessionId
)

Arguments

userId

The user ID associated with this payment session.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager that owns this session.

paymentSessionId

[required] The ID of the payment session to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.