bedrockagentcore_get_resource_api_key: Retrieves the API key associated with an API key credential...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_resource_api_keyR Documentation

Retrieves the API key associated with an API key credential provider

Description

Retrieves the API key associated with an API key credential provider.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_resource_api_key/ for full documentation.

Usage

bedrockagentcore_get_resource_api_key(
  workloadIdentityToken,
  resourceCredentialProviderName
)

Arguments

workloadIdentityToken

[required] The identity token of the workload from which you want to retrieve the API key.

resourceCredentialProviderName

[required] The credential provider name for the resource from which you are retrieving the API key.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.