bedrockagentcore_get_workload_access_token: Obtains a workload access token for agentic workloads not...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_get_workload_access_tokenR Documentation

Obtains a workload access token for agentic workloads not acting on behalf of a user

Description

Obtains a workload access token for agentic workloads not acting on behalf of a user.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_workload_access_token/ for full documentation.

Usage

bedrockagentcore_get_workload_access_token(workloadName)

Arguments

workloadName

[required] The unique identifier for the registered workload.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.