bedrockagentcore_invoke_agent_runtime: Sends a request to an agent or tool hosted in an Amazon...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_invoke_agent_runtimeR Documentation

Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time

Description

Sends a request to an agent or tool hosted in an Amazon Bedrock AgentCore Runtime and receives responses in real-time.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_invoke_agent_runtime/ for full documentation.

Usage

bedrockagentcore_invoke_agent_runtime(
  contentType = NULL,
  accept = NULL,
  mcpSessionId = NULL,
  runtimeSessionId = NULL,
  mcpProtocolVersion = NULL,
  runtimeUserId = NULL,
  traceId = NULL,
  traceParent = NULL,
  traceState = NULL,
  baggage = NULL,
  agentRuntimeArn,
  qualifier = NULL,
  accountId = NULL,
  payload
)

Arguments

contentType

The MIME type of the input data in the payload. This tells the agent runtime how to interpret the payload data. Common values include application/json for JSON data.

accept

The desired MIME type for the response from the agent runtime. This tells the agent runtime what format to use for the response data. Common values include application/json for JSON data.

mcpSessionId

The identifier of the MCP session.

runtimeSessionId

The identifier of the runtime session.

mcpProtocolVersion

The version of the MCP protocol being used.

runtimeUserId

The identifier of the runtime user.

traceId

The trace identifier for request tracking.

traceParent

The parent trace information for distributed tracing.

traceState

The trace state information for distributed tracing.

baggage

Additional context information for distributed tracing.

agentRuntimeArn

[required] The identifier of the agent runtime to invoke. You can specify either the full Amazon Web Services Resource Name (ARN) or the agent ID. If you use the agent ID, you must also provide the accountId query parameter.

qualifier

The qualifier to use for the agent runtime. This is an endpoint name that points to a specific version. If not specified, Amazon Bedrock AgentCore uses the default endpoint of the agent runtime.

accountId

The identifier of the Amazon Web Services account for the agent runtime resource. This parameter is required when you specify an agent ID instead of the full ARN for agentRuntimeArn.

payload

[required] The input data to send to the agent runtime. The format of this data depends on the specific agent configuration and must match the specified content type. For most agents, this is a JSON object containing the user's request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.