View source: R/bedrockagentcore_operations.R
| bedrockagentcore_invoke_harness | R Documentation |
Operation to invoke a Harness.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_invoke_harness/ for full documentation.
bedrockagentcore_invoke_harness(
harnessArn,
runtimeSessionId,
messages,
model = NULL,
systemPrompt = NULL,
tools = NULL,
skills = NULL,
allowedTools = NULL,
maxIterations = NULL,
maxTokens = NULL,
timeoutSeconds = NULL,
actorId = NULL
)
harnessArn |
[required] The ARN of the harness to invoke. |
runtimeSessionId |
[required] The session ID for the invocation. Use the same session ID across requests to continue a conversation. |
messages |
[required] The messages to send to the agent. |
model |
The model configuration to use for this invocation. If specified, overrides the harness default. |
systemPrompt |
The system prompt to use for this invocation. If specified, overrides the harness default. |
tools |
The tools available to the agent for this invocation. If specified, overrides the harness default. |
skills |
The skills available to the agent for this invocation. If specified, overrides the harness default. |
allowedTools |
The tools that the agent is allowed to use for this invocation. If specified, overrides the harness default. |
maxIterations |
The maximum number of iterations the agent loop can execute. If specified, overrides the harness default. |
maxTokens |
The maximum number of tokens the agent can generate per iteration. If specified, overrides the harness default. |
timeoutSeconds |
The maximum duration in seconds for the agent loop execution. If specified, overrides the harness default. |
actorId |
The actor ID for memory operations. Overrides the actor ID configured on the harness. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.