bedrockagentcore_list_actors: Lists all actors in an AgentCore Memory resource

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_actorsR Documentation

Lists all actors in an AgentCore Memory resource

Description

Lists all actors in an AgentCore Memory resource. We recommend using pagination to ensure that the operation returns quickly and successfully.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_actors/ for full documentation.

Usage

bedrockagentcore_list_actors(memoryId, maxResults = NULL, nextToken = NULL)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource for which to list actors.

maxResults

The maximum number of results to return in a single call. The default value is 20.

nextToken

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.