bedrockagentcore_list_batch_evaluations: Lists all batch evaluations in the account, providing summary...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_batch_evaluationsR Documentation

Lists all batch evaluations in the account, providing summary information about each evaluation's status and configuration

Description

Lists all batch evaluations in the account, providing summary information about each evaluation's status and configuration.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_batch_evaluations/ for full documentation.

Usage

bedrockagentcore_list_batch_evaluations(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

nextToken

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.