bedrockagentcore_list_memory_extraction_jobs: Lists all long-term memory extraction jobs that are eligible...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_memory_extraction_jobsR Documentation

Lists all long-term memory extraction jobs that are eligible to be started with optional filtering

Description

Lists all long-term memory extraction jobs that are eligible to be started with optional filtering.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_memory_extraction_jobs/ for full documentation.

Usage

bedrockagentcore_list_memory_extraction_jobs(
  memoryId,
  maxResults = NULL,
  filter = NULL,
  nextToken = NULL
)

Arguments

memoryId

[required] The unique identifier of the memory to list extraction jobs for.

maxResults

The maximum number of results to return in a single call. The default value is 20.

filter

Filter criteria to apply when listing extraction jobs.

nextToken

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.