View source: R/bedrockagentcore_operations.R
| bedrockagentcore_list_memory_records | R Documentation |
Lists memory records in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_memory_records/ for full documentation.
bedrockagentcore_list_memory_records(
memoryId,
namespace = NULL,
namespacePath = NULL,
memoryStrategyId = NULL,
maxResults = NULL,
nextToken = NULL,
metadataFilters = NULL
)
memoryId |
[required] The identifier of the AgentCore Memory resource for which to list memory records. |
namespace |
The namespace prefix to filter memory records by. Returns all memory records in namespaces that start with the provided prefix. Either |
namespacePath |
Use namespacePath for hierarchical retrievals. Return all memory records where namespace falls under the same parent hierarchy. Either |
memoryStrategyId |
The memory strategy identifier to filter memory records by. If specified, only memory records with this strategy ID are returned. |
maxResults |
The maximum number of results to return in a single call. The default value is 20. |
nextToken |
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. |
metadataFilters |
A list of metadata filter expressions to scope the returned memory records. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.