bedrockagentcore_list_payment_instruments: List payment instruments for a manager

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_payment_instrumentsR Documentation

List payment instruments for a manager

Description

List payment instruments for a manager.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_payment_instruments/ for full documentation.

Usage

bedrockagentcore_list_payment_instruments(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  paymentConnectorId = NULL,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

userId

The user ID associated with the payment instruments.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager that owns the payment instruments.

paymentConnectorId

The ID of the payment connector to filter by.

nextToken

Token for pagination to retrieve the next set of results.

maxResults

Maximum number of results to return in a single response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.