bedrockagentcore_list_payment_sessions: List payment sessions

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_payment_sessionsR Documentation

List payment sessions

Description

List payment sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_payment_sessions/ for full documentation.

Usage

bedrockagentcore_list_payment_sessions(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

userId

The user ID associated with the payment sessions.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager that owns the sessions.

nextToken

Token for pagination to retrieve the next set of results.

maxResults

Maximum number of results to return in a single response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.