bedrockagentcore_list_recommendations: Lists all recommendations in the account, with optional...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_recommendationsR Documentation

Lists all recommendations in the account, with optional filtering by status

Description

Lists all recommendations in the account, with optional filtering by status.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_recommendations/ for full documentation.

Usage

bedrockagentcore_list_recommendations(
  maxResults = NULL,
  nextToken = NULL,
  statusFilter = NULL
)

Arguments

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

nextToken

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

statusFilter

Optional filter to return only recommendations with the specified status.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.