bedrockagentcore_list_sessions: Lists sessions in an AgentCore Memory resource based on...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_list_sessionsR Documentation

Lists sessions in an AgentCore Memory resource based on specified criteria

Description

Lists sessions in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_sessions/ for full documentation.

Usage

bedrockagentcore_list_sessions(
  memoryId,
  actorId,
  maxResults = NULL,
  nextToken = NULL,
  filter = NULL
)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource for which to list sessions.

actorId

[required] The identifier of the actor for which to list sessions.

maxResults

The maximum number of results to return in a single call. The default value is 20.

nextToken

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

filter

Filter criteria to apply when listing sessions.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.