bedrockagentcore_process_payment: Processes a payment using a payment instrument within a...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_process_paymentR Documentation

Processes a payment using a payment instrument within a payment session

Description

Processes a payment using a payment instrument within a payment session.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_process_payment/ for full documentation.

Usage

bedrockagentcore_process_payment(
  userId = NULL,
  agentName = NULL,
  paymentManagerArn,
  paymentSessionId,
  paymentInstrumentId,
  paymentType,
  paymentInput,
  clientToken = NULL
)

Arguments

userId

The user ID associated with this payment.

agentName

The agent name associated with this request, used for observability.

paymentManagerArn

[required] The ARN of the payment manager.

paymentSessionId

[required] The ID of the payment session.

paymentInstrumentId

[required] The ID of the payment instrument to use.

paymentType

[required] The type of payment to process.

paymentInput

[required] The payment input details specific to the payment type.

clientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.