bedrockagentcore_retrieve_memory_records: Searches for and retrieves memory records from an AgentCore...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_retrieve_memory_recordsR Documentation

Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria

Description

Searches for and retrieves memory records from an AgentCore Memory resource based on specified search criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_retrieve_memory_records/ for full documentation.

Usage

bedrockagentcore_retrieve_memory_records(
  memoryId,
  namespace = NULL,
  namespacePath = NULL,
  searchCriteria,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

memoryId

[required] The identifier of the AgentCore Memory resource from which to retrieve memory records.

namespace

The namespace prefix to filter memory records by. Searches for memory records in namespaces that start with the provided prefix. Either namespace or namespacePath is required.

namespacePath

Use namespacePath for hierarchical retrievals. Return all memory records where namespace falls under the same parent hierarchy. Either namespace or namespacePath is required.

searchCriteria

[required] The search criteria to use for finding relevant memory records. This includes the search query, memory strategy ID, and other search parameters.

nextToken

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

maxResults

The maximum number of results to return in a single call. The default value is 20.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.