bedrockagentcore_save_browser_session_profile: Saves the current state of a browser session as a reusable...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_save_browser_session_profileR Documentation

Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore

Description

Saves the current state of a browser session as a reusable profile in Amazon Bedrock AgentCore. A browser profile captures persistent browser data such as cookies and local storage from an active session, enabling you to reuse this data in future browser sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_save_browser_session_profile/ for full documentation.

Usage

bedrockagentcore_save_browser_session_profile(
  traceId = NULL,
  traceParent = NULL,
  profileIdentifier,
  browserIdentifier,
  sessionId,
  clientToken = NULL
)

Arguments

traceId

The trace identifier for request tracking.

traceParent

The parent trace information for distributed tracing.

profileIdentifier

[required] The unique identifier for the browser profile. This identifier is used to reference the profile when starting new browser sessions. The identifier must follow the pattern of an alphanumeric name (up to 48 characters) followed by a hyphen and a 10-character alphanumeric suffix.

browserIdentifier

[required] The unique identifier of the browser associated with the session from which to save the profile.

sessionId

[required] The unique identifier of the browser session from which to save the profile. The session must be active when saving the profile.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request, but does not return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.