View source: R/bedrockagentcore_operations.R
| bedrockagentcore_start_batch_evaluation | R Documentation |
Starts a batch evaluation job that evaluates agent performance across multiple sessions. Batch evaluations pull agent traces from CloudWatch Logs or an existing online evaluation configuration and run specified evaluators and insights against them.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_start_batch_evaluation/ for full documentation.
bedrockagentcore_start_batch_evaluation(
batchEvaluationName,
evaluators = NULL,
dataSourceConfig,
clientToken = NULL,
evaluationMetadata = NULL,
description = NULL
)
batchEvaluationName |
[required] The name of the batch evaluation. Must be unique within your account. |
evaluators |
The list of evaluators to apply during the batch evaluation. Can include both built-in evaluators and custom evaluators. Maximum of 10 evaluators. |
dataSourceConfig |
[required] The data source configuration that specifies where to pull agent session traces from for evaluation. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error. |
evaluationMetadata |
Optional metadata for the evaluation, including session-specific ground truth data and test scenario identifiers. |
description |
The description of the batch evaluation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.