bedrockagentcore_start_code_interpreter_session: Creates and initializes a code interpreter session in Amazon...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_start_code_interpreter_sessionR Documentation

Creates and initializes a code interpreter session in Amazon Bedrock AgentCore

Description

Creates and initializes a code interpreter session in Amazon Bedrock AgentCore. The session enables agents to execute code as part of their response generation, supporting programming languages such as Python for data analysis, visualization, and computation tasks.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_start_code_interpreter_session/ for full documentation.

Usage

bedrockagentcore_start_code_interpreter_session(
  traceId = NULL,
  traceParent = NULL,
  codeInterpreterIdentifier,
  name = NULL,
  sessionTimeoutSeconds = NULL,
  certificates = NULL,
  clientToken = NULL
)

Arguments

traceId

The trace identifier for request tracking.

traceParent

The parent trace information for distributed tracing.

codeInterpreterIdentifier

[required] The unique identifier of the code interpreter to use for this session. This identifier specifies which code interpreter environment to initialize for the session.

name

The name of the code interpreter session. This name helps you identify and manage the session. The name does not need to be unique.

sessionTimeoutSeconds

The duration in seconds (time-to-live) after which the session automatically terminates, regardless of ongoing activity. Defaults to 900 seconds (15 minutes). Recommended minimum: 60 seconds. Maximum allowed: 28,800 seconds (8 hours).

certificates

A list of certificates to install in the code interpreter session.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request, but does not return an error. This parameter helps prevent the creation of duplicate sessions if there are temporary network issues.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.