bedrockagentcore_start_recommendation: Starts a recommendation job that analyzes agent traces and...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_start_recommendationR Documentation

Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance

Description

Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_start_recommendation/ for full documentation.

Usage

bedrockagentcore_start_recommendation(
  name,
  description = NULL,
  type,
  recommendationConfig,
  clientToken = NULL
)

Arguments

name

[required] The name of the recommendation. Must be unique within your account.

description

The description of the recommendation.

type

[required] The type of recommendation to generate. Valid values are SYSTEM_PROMPT_RECOMMENDATION for system prompt optimization or TOOL_DESCRIPTION_RECOMMENDATION for tool description optimization.

recommendationConfig

[required] The configuration for the recommendation, including the input to optimize, agent traces to analyze, and evaluation settings.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.