bedrockagentcore_stop_batch_evaluation: Stops a running batch evaluation

View source: R/bedrockagentcore_operations.R

bedrockagentcore_stop_batch_evaluationR Documentation

Stops a running batch evaluation

Description

Stops a running batch evaluation. Sessions that have already been evaluated retain their results.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_batch_evaluation/ for full documentation.

Usage

bedrockagentcore_stop_batch_evaluation(batchEvaluationId)

Arguments

batchEvaluationId

[required] The unique identifier of the batch evaluation to stop.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.