bedrockagentcore_stop_browser_session: Terminates an active browser session in Amazon Bedrock...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_stop_browser_sessionR Documentation

Terminates an active browser session in Amazon Bedrock AgentCore

Description

Terminates an active browser session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_browser_session/ for full documentation.

Usage

bedrockagentcore_stop_browser_session(
  traceId = NULL,
  traceParent = NULL,
  browserIdentifier,
  sessionId,
  clientToken = NULL
)

Arguments

traceId

The trace identifier for request tracking.

traceParent

The parent trace information for distributed tracing.

browserIdentifier

[required] The unique identifier of the browser associated with the session.

sessionId

[required] The unique identifier of the browser session to stop.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request, but does not return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.