bedrockagentcore_stop_code_interpreter_session: Terminates an active code interpreter session in Amazon...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_stop_code_interpreter_sessionR Documentation

Terminates an active code interpreter session in Amazon Bedrock AgentCore

Description

Terminates an active code interpreter session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_code_interpreter_session/ for full documentation.

Usage

bedrockagentcore_stop_code_interpreter_session(
  traceId = NULL,
  traceParent = NULL,
  codeInterpreterIdentifier,
  sessionId,
  clientToken = NULL
)

Arguments

traceId

The trace identifier for request tracking.

traceParent

The parent trace information for distributed tracing.

codeInterpreterIdentifier

[required] The unique identifier of the code interpreter associated with the session.

sessionId

[required] The unique identifier of the code interpreter session to stop.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request, but does not return an error.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.