View source: R/bedrockagentcore_operations.R
| bedrockagentcore_stop_runtime_session | R Documentation |
Stops a session that is running in an running AgentCore Runtime agent.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_runtime_session/ for full documentation.
bedrockagentcore_stop_runtime_session(
runtimeSessionId,
agentRuntimeArn,
qualifier = NULL,
clientToken = NULL
)
runtimeSessionId |
[required] The ID of the session that you want to stop. |
agentRuntimeArn |
[required] The ARN of the agent that contains the session that you want to stop. |
qualifier |
Optional qualifier to specify an agent alias, such as |
clientToken |
Idempotent token used to identify the request. If you use the same token with multiple requests, the same response is returned. Use ClientToken to prevent the same request from being processed more than once. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.