bedrockagentcore_update_ab_test: Updates an A/B test's configuration, including variants,...

View source: R/bedrockagentcore_operations.R

bedrockagentcore_update_ab_testR Documentation

Updates an A/B test's configuration, including variants, traffic allocation, evaluation settings, or execution status

Description

Updates an A/B test's configuration, including variants, traffic allocation, evaluation settings, or execution status.

See https://www.paws-r-sdk.com/docs/bedrockagentcore_update_ab_test/ for full documentation.

Usage

bedrockagentcore_update_ab_test(
  abTestId,
  clientToken = NULL,
  name = NULL,
  description = NULL,
  variants = NULL,
  gatewayFilter = NULL,
  evaluationConfig = NULL,
  roleArn = NULL,
  executionStatus = NULL
)

Arguments

abTestId

[required] The unique identifier of the A/B test to update.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.

name

The updated name of the A/B test.

description

The updated description of the A/B test.

variants

The updated list of variants.

gatewayFilter

The updated gateway filter.

evaluationConfig

The updated evaluation configuration.

roleArn

The updated IAM role ARN.

executionStatus

The updated execution status to enable or disable the A/B test.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.