bedrockagentcorecontrol_add_dataset_examples: Adds examples to the dataset's DRAFT

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_add_dataset_examplesR Documentation

Adds examples to the dataset's DRAFT

Description

Adds examples to the dataset's DRAFT.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_add_dataset_examples/ for full documentation.

Usage

bedrockagentcorecontrol_add_dataset_examples(
  datasetId,
  clientToken = NULL,
  source
)

Arguments

datasetId

[required] The unique identifier of the dataset to add examples to.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.

source

[required] Source of examples to add. Provide either inline examples or an S3 URI pointing to a JSONL file.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.