bedrockagentcorecontrol_create_agent_runtime: Creates an Amazon Bedrock AgentCore Runtime

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_agent_runtimeR Documentation

Creates an Amazon Bedrock AgentCore Runtime

Description

Creates an Amazon Bedrock AgentCore Runtime.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_agent_runtime/ for full documentation.

Usage

bedrockagentcorecontrol_create_agent_runtime(
  agentRuntimeName,
  agentRuntimeArtifact,
  roleArn,
  networkConfiguration,
  clientToken = NULL,
  description = NULL,
  authorizerConfiguration = NULL,
  requestHeaderConfiguration = NULL,
  protocolConfiguration = NULL,
  lifecycleConfiguration = NULL,
  environmentVariables = NULL,
  filesystemConfigurations = NULL,
  tags = NULL
)

Arguments

agentRuntimeName

[required] The name of the AgentCore Runtime.

agentRuntimeArtifact

[required] The artifact of the AgentCore Runtime.

roleArn

[required] The IAM role ARN that provides permissions for the AgentCore Runtime.

networkConfiguration

[required] The network configuration for the AgentCore Runtime.

clientToken

A unique, case-sensitive identifier to ensure idempotency of the request.

description

The description of the AgentCore Runtime.

authorizerConfiguration

The authorizer configuration for the AgentCore Runtime.

requestHeaderConfiguration

Configuration for HTTP request headers that will be passed through to the runtime.

protocolConfiguration

The protocol configuration for an agent runtime. This structure defines how the agent runtime communicates with clients.

lifecycleConfiguration

The life cycle configuration for the AgentCore Runtime.

environmentVariables

Environment variables to set in the AgentCore Runtime environment.

filesystemConfigurations

The filesystem configurations to mount into the AgentCore Runtime. Use filesystem configurations to provide persistent storage to your AgentCore Runtime sessions.

tags

A map of tag keys and values to assign to the agent runtime. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.