bedrockagentcorecontrol_create_api_key_credential_provider: Creates a new API key credential provider

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_api_key_credential_providerR Documentation

Creates a new API key credential provider

Description

Creates a new API key credential provider.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_api_key_credential_provider/ for full documentation.

Usage

bedrockagentcorecontrol_create_api_key_credential_provider(
  name,
  apiKey,
  tags = NULL
)

Arguments

name

[required] The name of the API key credential provider. The name must be unique within your account.

apiKey

[required] The API key to use for authentication. This value is encrypted and stored securely.

tags

A map of tag keys and values to assign to the API key credential provider. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.