bedrockagentcorecontrol_create_browser: Creates a custom browser

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_browserR Documentation

Creates a custom browser

Description

Creates a custom browser.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_browser/ for full documentation.

Usage

bedrockagentcorecontrol_create_browser(
  name,
  description = NULL,
  executionRoleArn = NULL,
  networkConfiguration,
  recording = NULL,
  browserSigning = NULL,
  enterprisePolicies = NULL,
  certificates = NULL,
  clientToken = NULL,
  tags = NULL
)

Arguments

name

[required] The name of the browser. The name must be unique within your account.

description

The description of the browser.

executionRoleArn

The Amazon Resource Name (ARN) of the IAM role that provides permissions for the browser to access Amazon Web Services services.

networkConfiguration

[required] The network configuration for the browser. This configuration specifies the network mode for the browser.

recording

The recording configuration for the browser. When enabled, browser sessions are recorded and stored in the specified Amazon S3 location.

browserSigning

The browser signing configuration that enables cryptographic agent identification using HTTP message signatures for web bot authentication.

enterprisePolicies

A list of enterprise policy files for the browser.

certificates

A list of certificates to install in the browser.

clientToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request but does not return an error.

tags

A map of tag keys and values to assign to the browser. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.