bedrockagentcorecontrol_create_browser_profile: Creates a browser profile in Amazon Bedrock AgentCore

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_browser_profileR Documentation

Creates a browser profile in Amazon Bedrock AgentCore

Description

Creates a browser profile in Amazon Bedrock AgentCore. A browser profile stores persistent browser data such as cookies, local storage, session storage, and browsing history that can be saved from browser sessions and reused in subsequent sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_browser_profile/ for full documentation.

Usage

bedrockagentcorecontrol_create_browser_profile(
  name,
  description = NULL,
  clientToken = NULL,
  tags = NULL
)

Arguments

name

[required] The name of the browser profile. The name must be unique within your account and can contain alphanumeric characters and underscores.

description

A description of the browser profile. Use this field to describe the purpose or contents of the profile.

clientToken

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request but does not return an error.

tags

A map of tag keys and values to assign to the browser profile. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.