View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_capacity_provider | R Documentation |
Creates a capacity provider. A capacity provider defines the Amazon EC2 infrastructure for AgentCore Runtime, including the operating system, allowed instance types, networking, and storage. It also specifies the IAM permissions that AgentCore uses to manage those instances.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_capacity_provider/ for full documentation.
bedrockagentcorecontrol_create_capacity_provider(
name,
description = NULL,
permissionsConfiguration,
clientToken = NULL,
tags = NULL,
computeConfiguration
)
name |
[required] The name of the capacity provider. The name must be unique within your account. |
description |
An optional description of the capacity provider. If you don't specify a description, the service creates the capacity provider without one. |
permissionsConfiguration |
[required] The permissions configuration for the capacity provider. This specifies the IAM role that AgentCore uses to manage the Amazon EC2 instances on your behalf. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
tags |
A map of tag keys and values to associate with the capacity provider. If you don't specify tags, the capacity provider is created with no tags. |
computeConfiguration |
[required] The compute configuration for the capacity provider. This defines the Amazon EC2 compute resources used to launch instances: the operating system, allowed instance types, networking, and storage. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.