View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_code_interpreter | R Documentation |
Creates a custom code interpreter.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_code_interpreter/ for full documentation.
bedrockagentcorecontrol_create_code_interpreter(
name,
description = NULL,
executionRoleArn = NULL,
networkConfiguration,
certificates = NULL,
clientToken = NULL,
tags = NULL
)
name |
[required] The name of the code interpreter. The name must be unique within your account. |
description |
The description of the code interpreter. |
executionRoleArn |
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the code interpreter to access Amazon Web Services services. |
networkConfiguration |
[required] The network configuration for the code interpreter. This configuration specifies the network mode for the code interpreter. |
certificates |
A list of certificates to install in the code interpreter. |
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request but does not return an error. |
tags |
A map of tag keys and values to assign to the code interpreter. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.