bedrockagentcorecontrol_create_configuration_bundle: Creates a new configuration bundle resource

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_configuration_bundleR Documentation

Creates a new configuration bundle resource

Description

Creates a new configuration bundle resource. A configuration bundle stores versioned component configurations for agent evaluation workflows.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_configuration_bundle/ for full documentation.

Usage

bedrockagentcorecontrol_create_configuration_bundle(
  clientToken = NULL,
  bundleName,
  description = NULL,
  components,
  branchName = NULL,
  commitMessage = NULL,
  createdBy = NULL,
  tags = NULL
)

Arguments

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.

bundleName

[required] The name for the configuration bundle. Names must be unique within your account.

description

The description for the configuration bundle.

components

[required] A map of component identifiers to their configurations. Each component represents a configurable element within the bundle.

branchName

The branch name for version tracking. Defaults to mainline if not specified.

commitMessage

A commit message describing the initial version of the configuration bundle.

createdBy

The source that created this version, including the source name and optional ARN.

tags

A map of tag keys and values to assign to the configuration bundle. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.