bedrockagentcorecontrol_create_dataset_version: Publishes the current DRAFT as a new numbered version

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_dataset_versionR Documentation

Publishes the current DRAFT as a new numbered version

Description

Publishes the current DRAFT as a new numbered version.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_dataset_version/ for full documentation.

Usage

bedrockagentcorecontrol_create_dataset_version(datasetId, clientToken = NULL)

Arguments

datasetId

[required] The unique identifier of the dataset to publish a version for.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.