View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_evaluator | R Documentation |
Creates a custom evaluator for agent quality assessment. Custom evaluators can use either LLM-as-a-Judge configurations with user-defined prompts, rating scales, and model settings, or code-based configurations with customer-managed Lambda functions to evaluate agent performance at tool call, trace, or session levels.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_evaluator/ for full documentation.
bedrockagentcorecontrol_create_evaluator(
clientToken = NULL,
evaluatorName,
description = NULL,
evaluatorConfig,
level,
kmsKeyArn = NULL,
tags = NULL
)
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
evaluatorName |
[required] The name of the evaluator. Must be unique within your account. |
description |
The description of the evaluator that explains its purpose and evaluation criteria. |
evaluatorConfig |
[required] The configuration for the evaluator. Specify either LLM-as-a-Judge settings with instructions, rating scale, and model configuration, or code-based settings with a customer-managed Lambda function. |
level |
[required] The evaluation level that determines the scope of evaluation. Valid values are |
kmsKeyArn |
The Amazon Resource Name (ARN) of a customer managed KMS key to use for encrypting sensitive evaluator data, including instructions and rating scale. If you don't specify a KMS key, the evaluator data is encrypted with an Amazon Web Services owned key. Only symmetric encryption KMS keys are supported. For more information, see Encryption at rest for AgentCore Evaluations. |
tags |
A map of tag keys and values to assign to an AgentCore Evaluator. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.