View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_gateway | R Documentation |
Creates a gateway for Amazon Bedrock Agent. A gateway serves as an integration point between your agent and external services.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_gateway/ for full documentation.
bedrockagentcorecontrol_create_gateway(
name,
description = NULL,
clientToken = NULL,
roleArn,
protocolType = NULL,
protocolConfiguration = NULL,
authorizerType,
authorizerConfiguration = NULL,
kmsKeyArn = NULL,
interceptorConfigurations = NULL,
policyEngineConfiguration = NULL,
exceptionLevel = NULL,
tags = NULL
)
name |
[required] The name of the gateway. The name must be unique within your account. |
description |
The description of the gateway. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
roleArn |
[required] The Amazon Resource Name (ARN) of the IAM role that provides permissions for the gateway to access Amazon Web Services services. |
protocolType |
The protocol type for the gateway. |
protocolConfiguration |
The configuration settings for the protocol specified in the |
authorizerType |
[required] The type of authorizer to use for the gateway.
|
authorizerConfiguration |
The authorizer configuration for the gateway. Required if |
kmsKeyArn |
The Amazon Resource Name (ARN) of the KMS key used to encrypt data associated with the gateway. |
interceptorConfigurations |
A list of configuration settings for a gateway interceptor. Gateway interceptors allow custom code to be invoked during gateway invocations. |
policyEngineConfiguration |
The policy engine configuration for the gateway. A policy engine is a collection of policies that evaluates and authorizes agent tool calls. When associated with a gateway, the policy engine intercepts all agent requests and determines whether to allow or deny each action based on the defined policies. |
exceptionLevel |
The level of detail in error messages returned when invoking the gateway.
|
tags |
A map of key-value pairs to associate with the gateway as metadata tags. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.