bedrockagentcorecontrol_create_gateway_rate_limit: Creates a rate limit for a gateway

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_gateway_rate_limitR Documentation

Creates a rate limit for a gateway

Description

Creates a rate limit for a gateway. Rate limits define throttling rules for each dimension that control request rates, token consumption rates, and concurrent connections through the gateway.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_gateway_rate_limit/ for full documentation.

Usage

bedrockagentcorecontrol_create_gateway_rate_limit(
  gatewayIdentifier,
  clientToken = NULL,
  rateLimitId = NULL,
  description = NULL,
  dimensionKeys,
  entries
)

Arguments

gatewayIdentifier

[required] The unique identifier of the gateway to create the rate limit for.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.

rateLimitId

An optional customer-defined identifier for the rate limit. If not provided, the system generates one.

description

An optional human-readable description for this rate limit. If not provided, the rate limit is created without a description.

dimensionKeys

[required] The ordered list of dimension key names that define the scope of this rate limit. Must be unique per gateway—no two rate limits can share the same dimension keys.

entries

[required] The rule entries that map dimension values to rate configurations.


paws.machine.learning documentation built on Oct. 8, 2026, 9:06 a.m.