View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_gateway_target | R Documentation |
Creates a target for a gateway. A target defines an endpoint that the gateway can connect to.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_gateway_target/ for full documentation.
bedrockagentcorecontrol_create_gateway_target(
gatewayIdentifier,
name,
description = NULL,
clientToken = NULL,
targetConfiguration,
credentialProviderConfigurations = NULL,
metadataConfiguration = NULL,
privateEndpoint = NULL
)
gatewayIdentifier |
[required] The identifier of the gateway to create a target for. |
name |
[required] The name of the gateway target. The name must be unique within the gateway. |
description |
The description of the gateway target. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
targetConfiguration |
[required] The configuration settings for the target, including endpoint information and schema definitions. |
credentialProviderConfigurations |
The credential provider configurations for the target. These configurations specify how the gateway authenticates with the target endpoint. |
metadataConfiguration |
Optional configuration for HTTP header and query parameter propagation to and from the gateway target. |
privateEndpoint |
The private endpoint configuration for the gateway target. Use this to connect the gateway to private resources in your VPC. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.