bedrockagentcorecontrol_create_oauth_2_credential_provider: Creates a new OAuth2 credential provider

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_oauth_2_credential_providerR Documentation

Creates a new OAuth2 credential provider

Description

Creates a new OAuth2 credential provider.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_oauth_2_credential_provider/ for full documentation.

Usage

bedrockagentcorecontrol_create_oauth_2_credential_provider(
  name,
  credentialProviderVendor,
  oauth2ProviderConfigInput,
  tags = NULL
)

Arguments

name

[required] The name of the OAuth2 credential provider. The name must be unique within your account.

credentialProviderVendor

[required] The vendor of the OAuth2 credential provider. This specifies which OAuth2 implementation to use.

oauth2ProviderConfigInput

[required] The configuration settings for the OAuth2 provider, including client ID, client secret, and other vendor-specific settings.

tags

A map of tag keys and values to assign to the OAuth2 credential provider. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.