View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_payment_credential_provider | R Documentation |
Creates a new payment credential provider for storing authentication credentials used by payment connectors to communicate with external payment providers.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_payment_credential_provider/ for full documentation.
bedrockagentcorecontrol_create_payment_credential_provider(
name,
credentialProviderVendor,
providerConfigurationInput,
tags = NULL
)
name |
[required] Unique name for the payment credential provider. |
credentialProviderVendor |
[required] The vendor type for the payment credential provider (e.g., CoinbaseCDP, StripePrivy). |
providerConfigurationInput |
[required] Configuration specific to the vendor, including API credentials. |
tags |
Optional tags for resource organization. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.