View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_registry | R Documentation |
Creates a new registry in your Amazon Web Services account. A registry serves as a centralized catalog for organizing and managing registry records, including MCP servers, A2A agents, agent skills, and custom resource types.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_registry/ for full documentation.
bedrockagentcorecontrol_create_registry(
name,
description = NULL,
authorizerType = NULL,
authorizerConfiguration = NULL,
clientToken = NULL,
approvalConfiguration = NULL
)
name |
[required] The name of the registry. The name must be unique within your account and can contain alphanumeric characters and underscores. |
description |
A description of the registry. |
authorizerType |
The type of authorizer to use for the registry. This controls the authorization method for the Search and Invoke APIs used by consumers, and does not affect the standard CRUDL APIs for registry and registry record management used by administrators.
|
authorizerConfiguration |
The authorizer configuration for the registry. Required if |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
approvalConfiguration |
The approval configuration for registry records. Controls whether records require explicit approval before becoming active. See the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.