View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_registry_record | R Documentation |
Creates a new registry record within the specified registry. A registry record represents an individual AI resource's metadata in the registry. This could be an MCP server (and associated tools), A2A agent, agent skill, or a custom resource with a custom schema.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_registry_record/ for full documentation.
bedrockagentcorecontrol_create_registry_record(
registryId,
name,
description = NULL,
descriptorType,
descriptors = NULL,
recordVersion = NULL,
synchronizationType = NULL,
synchronizationConfiguration = NULL,
clientToken = NULL
)
registryId |
[required] The identifier of the registry where the record will be created. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
name |
[required] The name of the registry record. |
description |
A description of the registry record. |
descriptorType |
[required] The descriptor type of the registry record.
|
descriptors |
The descriptor-type-specific configuration containing the resource schema and metadata. The structure of this field depends on the |
recordVersion |
The version of the registry record. Use this to track different versions of the record's content. |
synchronizationType |
The type of synchronization to use for keeping the record metadata up to date from an external source. Possible values include |
synchronizationConfiguration |
The configuration for synchronizing registry record metadata from an external source, such as a URL-based MCP server. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.