bedrockagentcorecontrol_create_workload_identity: Creates a new workload identity

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_create_workload_identityR Documentation

Creates a new workload identity

Description

Creates a new workload identity.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_workload_identity/ for full documentation.

Usage

bedrockagentcorecontrol_create_workload_identity(
  name,
  allowedResourceOauth2ReturnUrls = NULL,
  tags = NULL
)

Arguments

name

[required] The name of the workload identity. The name must be unique within your account.

allowedResourceOauth2ReturnUrls

The list of allowed OAuth2 return URLs for resources associated with this workload identity.

tags

A map of tag keys and values to assign to the workload identity. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.