bedrockagentcorecontrol_delete_configuration_bundle: Deletes a configuration bundle and all of its versions

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_configuration_bundleR Documentation

Deletes a configuration bundle and all of its versions

Description

Deletes a configuration bundle and all of its versions.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_configuration_bundle/ for full documentation.

Usage

bedrockagentcorecontrol_delete_configuration_bundle(bundleId)

Arguments

bundleId

[required] The unique identifier of the configuration bundle to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.