bedrockagentcorecontrol_delete_dataset_examples: Deletes specific examples by ID from DRAFT

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_dataset_examplesR Documentation

Deletes specific examples by ID from DRAFT

Description

Deletes specific examples by ID from DRAFT.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_dataset_examples/ for full documentation.

Usage

bedrockagentcorecontrol_delete_dataset_examples(
  datasetId,
  clientToken = NULL,
  exampleIds
)

Arguments

datasetId

[required] The unique identifier of the dataset.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.

exampleIds

[required] The IDs of the examples to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.