bedrockagentcorecontrol_delete_gateway_target: Deletes a gateway target

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_gateway_targetR Documentation

Deletes a gateway target

Description

Deletes a gateway target.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_gateway_target/ for full documentation.

Usage

bedrockagentcorecontrol_delete_gateway_target(gatewayIdentifier, targetId)

Arguments

gatewayIdentifier

[required] The unique identifier of the gateway associated with the target.

targetId

[required] The unique identifier of the gateway target to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.