bedrockagentcorecontrol_delete_memory: Deletes an Amazon Bedrock AgentCore Memory resource

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_memoryR Documentation

Deletes an Amazon Bedrock AgentCore Memory resource

Description

Deletes an Amazon Bedrock AgentCore Memory resource.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_memory/ for full documentation.

Usage

bedrockagentcorecontrol_delete_memory(clientToken = NULL, memoryId)

Arguments

clientToken

A client token is used for keeping track of idempotent requests. It can contain a session id which can be around 250 chars, combined with a unique AWS identifier.

memoryId

[required] The unique identifier of the memory to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.