bedrockagentcorecontrol_delete_online_evaluation_config: Deletes an online evaluation configuration and stops any...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_online_evaluation_configR Documentation

Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it

Description

Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_online_evaluation_config/ for full documentation.

Usage

bedrockagentcorecontrol_delete_online_evaluation_config(
  onlineEvaluationConfigId
)

Arguments

onlineEvaluationConfigId

[required] The unique identifier of the online evaluation configuration to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.