View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_payment_manager | R Documentation |
Deletes a payment manager. All payment connectors associated with the payment manager must be deleted before the payment manager can be deleted. This operation initiates the deletion process asynchronously.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_payment_manager/ for full documentation.
bedrockagentcorecontrol_delete_payment_manager(
paymentManagerId,
clientToken = NULL
)
paymentManagerId |
[required] The unique identifier of the payment manager to delete. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.