bedrockagentcorecontrol_delete_policy_engine: Deletes an existing policy engine from the AgentCore Policy...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_policy_engineR Documentation

Deletes an existing policy engine from the AgentCore Policy system

Description

Deletes an existing policy engine from the AgentCore Policy system. The policy engine must not have any associated policies before deletion. Once deleted, the policy engine and all its configurations become unavailable for policy management and evaluation. This is an asynchronous operation. Use the get_policy_engine operation to poll the status field to track completion.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_policy_engine/ for full documentation.

Usage

bedrockagentcorecontrol_delete_policy_engine(policyEngineId)

Arguments

policyEngineId

[required] The unique identifier of the policy engine to be deleted. This must be a valid policy engine ID that exists within the account.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.