View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_registry | R Documentation |
Deletes a registry. The registry must contain zero records before it can be deleted. This operation initiates the deletion process asynchronously.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_registry/ for full documentation.
bedrockagentcorecontrol_delete_registry(registryId)
registryId |
[required] The identifier of the registry to delete. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.