bedrockagentcorecontrol_delete_registry_record: Deletes a registry record

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_delete_registry_recordR Documentation

Deletes a registry record

Description

Deletes a registry record. The record's status transitions to DELETING and the record is removed asynchronously.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_registry_record/ for full documentation.

Usage

bedrockagentcorecontrol_delete_registry_record(registryId, recordId)

Arguments

registryId

[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

recordId

[required] The identifier of the registry record to delete. You can specify either the Amazon Resource Name (ARN) or the ID of the record.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.