bedrockagentcorecontrol_get_configuration_bundle: Gets the latest version of a configuration bundle

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_get_configuration_bundleR Documentation

Gets the latest version of a configuration bundle

Description

Gets the latest version of a configuration bundle. By default, returns the latest version on the mainline branch. Use get_configuration_bundle_version to retrieve a specific historical version.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_configuration_bundle/ for full documentation.

Usage

bedrockagentcorecontrol_get_configuration_bundle(bundleId, branchName = NULL)

Arguments

bundleId

[required] The unique identifier of the configuration bundle to retrieve.

branchName

The branch name to get the latest version from. If not specified, returns the latest version on the mainline branch.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.