View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_get_configuration_bundle_version | R Documentation |
Gets a specific version of a configuration bundle by its version identifier.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_configuration_bundle_version/ for full documentation.
bedrockagentcorecontrol_get_configuration_bundle_version(bundleId, versionId)
bundleId |
[required] The unique identifier of the configuration bundle. |
versionId |
[required] The version identifier of the configuration bundle version to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.