bedrockagentcorecontrol_get_online_evaluation_config: Retrieves detailed information about an online evaluation...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_get_online_evaluation_configR Documentation

Retrieves detailed information about an online evaluation configuration, including its rules, data sources, evaluators, and execution status

Description

Retrieves detailed information about an online evaluation configuration, including its rules, data sources, evaluators, and execution status.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_online_evaluation_config/ for full documentation.

Usage

bedrockagentcorecontrol_get_online_evaluation_config(onlineEvaluationConfigId)

Arguments

onlineEvaluationConfigId

[required] The unique identifier of the online evaluation configuration to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.