bedrockagentcorecontrol_get_registry_record: Retrieves information about a specific registry record

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_get_registry_recordR Documentation

Retrieves information about a specific registry record

Description

Retrieves information about a specific registry record.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_registry_record/ for full documentation.

Usage

bedrockagentcorecontrol_get_registry_record(registryId, recordId)

Arguments

registryId

[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

recordId

[required] The identifier of the registry record to retrieve. You can specify either the Amazon Resource Name (ARN) or the ID of the record.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.