bedrockagentcorecontrol_list_agent_runtime_endpoints: Lists all endpoints for a specific Amazon Secure Agent

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_agent_runtime_endpointsR Documentation

Lists all endpoints for a specific Amazon Secure Agent

Description

Lists all endpoints for a specific Amazon Secure Agent.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_agent_runtime_endpoints/ for full documentation.

Usage

bedrockagentcorecontrol_list_agent_runtime_endpoints(
  agentRuntimeId,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

agentRuntimeId

[required] The unique identifier of the AgentCore Runtime to list endpoints for.

maxResults

The maximum number of results to return in the response.

nextToken

A token to retrieve the next page of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.