View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_configuration_bundle_versions | R Documentation |
Lists all versions of a configuration bundle, with optional filtering by branch name or creation source.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_configuration_bundle_versions/ for full documentation.
bedrockagentcorecontrol_list_configuration_bundle_versions(
bundleId,
nextToken = NULL,
maxResults = NULL,
filter = NULL
)
bundleId |
[required] The unique identifier of the configuration bundle to list versions for. |
nextToken |
If the total number of results is greater than the |
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
filter |
An optional filter for listing versions, including branch name, creation source, and whether to return only the latest version per branch. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.