bedrockagentcorecontrol_list_configuration_bundles: Lists all configuration bundles in the account

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_configuration_bundlesR Documentation

Lists all configuration bundles in the account

Description

Lists all configuration bundles in the account.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_configuration_bundles/ for full documentation.

Usage

bedrockagentcorecontrol_list_configuration_bundles(
  nextToken = NULL,
  maxResults = NULL
)

Arguments

nextToken

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.