bedrockagentcorecontrol_list_dataset_examples: Returns paginated examples from the dataset

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_dataset_examplesR Documentation

Returns paginated examples from the dataset

Description

Returns paginated examples from the dataset.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_dataset_examples/ for full documentation.

Usage

bedrockagentcorecontrol_list_dataset_examples(
  datasetId,
  datasetVersion = NULL,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

datasetId

[required] The unique identifier of the dataset.

datasetVersion

Version to paginate: "DRAFT" or a version number. Defaults to DRAFT if absent. Only used on the first request (when nextToken is absent). For subsequent pages, the version is extracted from the nextToken and this parameter is ignored.

maxResults

Maximum number of examples to return per page. Default: 1000. Min: 1, max: 1000. Response size is validated against 5 MB limit after reading. For bulk access to all examples, use the downloadUrl field from GetDataset.

nextToken

The token for the next page of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.