View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_dataset_versions | R Documentation |
Lists all published versions of a dataset, sorted by version number descending (newest first). Does not include the DRAFT working copy.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_dataset_versions/ for full documentation.
bedrockagentcorecontrol_list_dataset_versions(
datasetId,
nextToken = NULL,
maxResults = NULL
)
datasetId |
[required] The unique identifier of the dataset. |
nextToken |
The token for the next page of results. |
maxResults |
The maximum number of versions to return per page. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.