bedrockagentcorecontrol_list_evaluators: Lists all available evaluators, including both builtin...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_evaluatorsR Documentation

Lists all available evaluators, including both builtin evaluators provided by the service and custom evaluators created by the user

Description

Lists all available evaluators, including both builtin evaluators provided by the service and custom evaluators created by the user.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_evaluators/ for full documentation.

Usage

bedrockagentcorecontrol_list_evaluators(nextToken = NULL, maxResults = NULL)

Arguments

nextToken

The pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of evaluators to return in a single response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.