bedrockagentcorecontrol_list_gateway_rules: Lists all rules for a gateway

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_gateway_rulesR Documentation

Lists all rules for a gateway

Description

Lists all rules for a gateway.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_gateway_rules/ for full documentation.

Usage

bedrockagentcorecontrol_list_gateway_rules(
  gatewayIdentifier,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

gatewayIdentifier

[required] The identifier of the gateway to list rules for.

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

nextToken

The pagination token from a previous request.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.