bedrockagentcorecontrol_list_gateway_targets: Lists all targets for a specific gateway

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_gateway_targetsR Documentation

Lists all targets for a specific gateway

Description

Lists all targets for a specific gateway.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_gateway_targets/ for full documentation.

Usage

bedrockagentcorecontrol_list_gateway_targets(
  gatewayIdentifier,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

gatewayIdentifier

[required] The identifier of the gateway to list targets for.

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

nextToken

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.