bedrockagentcorecontrol_list_memories: Lists the available Amazon Bedrock AgentCore Memory resources...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_memoriesR Documentation

Lists the available Amazon Bedrock AgentCore Memory resources in the current Amazon Web Services Region

Description

Lists the available Amazon Bedrock AgentCore Memory resources in the current Amazon Web Services Region.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_memories/ for full documentation.

Usage

bedrockagentcorecontrol_list_memories(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of results to return in a single call. The default value is 10. The maximum value is 50.

nextToken

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.