bedrockagentcorecontrol_list_online_evaluation_configs: Lists all online evaluation configurations in the account,...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_online_evaluation_configsR Documentation

Lists all online evaluation configurations in the account, providing summary information about each configuration's status and settings

Description

Lists all online evaluation configurations in the account, providing summary information about each configuration's status and settings.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_online_evaluation_configs/ for full documentation.

Usage

bedrockagentcorecontrol_list_online_evaluation_configs(
  nextToken = NULL,
  maxResults = NULL
)

Arguments

nextToken

The pagination token from a previous request to retrieve the next page of results.

maxResults

The maximum number of online evaluation configurations to return in a single response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.