bedrockagentcorecontrol_list_payment_connectors: Lists all payment connectors for a specified payment manager

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_payment_connectorsR Documentation

Lists all payment connectors for a specified payment manager

Description

Lists all payment connectors for a specified payment manager.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_payment_connectors/ for full documentation.

Usage

bedrockagentcorecontrol_list_payment_connectors(
  paymentManagerId,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

paymentManagerId

[required] The unique identifier of the payment manager whose connectors to list.

maxResults

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

nextToken

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.