bedrockagentcorecontrol_list_policy_engines: Retrieves a list of policy engines within the AgentCore...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_policy_enginesR Documentation

Retrieves a list of policy engines within the AgentCore Policy system

Description

Retrieves a list of policy engines within the AgentCore Policy system. This operation supports pagination to help administrators discover and manage policy engines across their account. Each policy engine serves as a container for related policies.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_policy_engines/ for full documentation.

Usage

bedrockagentcorecontrol_list_policy_engines(
  nextToken = NULL,
  maxResults = NULL
)

Arguments

nextToken

A pagination token returned from a previous list_policy_engines call. Use this token to retrieve the next page of results when the response is paginated.

maxResults

The maximum number of policy engines to return in a single response. If not specified, the default is 10 policy engines per page, with a maximum of 100 per page.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.