bedrockagentcorecontrol_list_policy_generations: Retrieves a list of policy generation requests within the...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_list_policy_generationsR Documentation

Retrieves a list of policy generation requests within the AgentCore Policy system

Description

Retrieves a list of policy generation requests within the AgentCore Policy system. This operation supports pagination and filtering to help track and manage AI-powered policy generation operations.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_policy_generations/ for full documentation.

Usage

bedrockagentcorecontrol_list_policy_generations(
  nextToken = NULL,
  maxResults = NULL,
  policyEngineId
)

Arguments

nextToken

A pagination token for retrieving additional policy generations when results are paginated.

maxResults

The maximum number of policy generations to return in a single response.

policyEngineId

[required] The identifier of the policy engine whose policy generations to retrieve.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.