View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_registries | R Documentation |
Lists all registries in the account. You can optionally filter results by status using the status parameter, or by authorizer type using the authorizerType parameter.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_registries/ for full documentation.
bedrockagentcorecontrol_list_registries(
maxResults = NULL,
nextToken = NULL,
status = NULL,
authorizerType = NULL
)
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
status |
Filter registries by their current status. Possible values include |
authorizerType |
Filter registries by their authorizer type. Possible values are |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.