View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_registry_records | R Documentation |
Lists registry records within a registry. You can optionally filter results using the name, status, and descriptorType parameters. When multiple filters are specified, they are combined using AND logic.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_registry_records/ for full documentation.
bedrockagentcorecontrol_list_registry_records(
registryId,
maxResults = NULL,
nextToken = NULL,
name = NULL,
status = NULL,
descriptorType = NULL
)
registryId |
[required] The identifier of the registry to list records from. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
name |
Filter registry records by name. |
status |
Filter registry records by their current status. Possible values include |
descriptorType |
Filter registry records by their descriptor type. Possible values are |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.