bedrockagentcorecontrol_put_resource_policy: Creates or updates a resource-based policy for a resource...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_put_resource_policyR Documentation

Creates or updates a resource-based policy for a resource with the specified resourceArn

Description

Creates or updates a resource-based policy for a resource with the specified resourceArn.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_put_resource_policy/ for full documentation.

Usage

bedrockagentcorecontrol_put_resource_policy(resourceArn, policy)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) of the resource for which to create or update the resource policy.

policy

[required] The resource policy to create or update.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.