bedrockagentcorecontrol_set_token_vault_cmk: Sets the customer master key (CMK) for a token vault

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_set_token_vault_cmkR Documentation

Sets the customer master key (CMK) for a token vault

Description

Sets the customer master key (CMK) for a token vault.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_set_token_vault_cmk/ for full documentation.

Usage

bedrockagentcorecontrol_set_token_vault_cmk(
  tokenVaultId = NULL,
  kmsConfiguration
)

Arguments

tokenVaultId

The unique identifier of the token vault to update.

kmsConfiguration

[required] The KMS configuration for the token vault, including the key type and KMS key ARN.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.