bedrockagentcorecontrol_submit_registry_record_for_approval: Submits a registry record for approval

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_submit_registry_record_for_approvalR Documentation

Submits a registry record for approval

Description

Submits a registry record for approval. This transitions the record from DRAFT status to PENDING_APPROVAL status. If the registry has auto-approval enabled, the record is automatically approved.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_submit_registry_record_for_approval/ for full documentation.

Usage

bedrockagentcorecontrol_submit_registry_record_for_approval(
  registryId,
  recordId
)

Arguments

registryId

[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

recordId

[required] The identifier of the registry record to submit for approval. You can specify either the Amazon Resource Name (ARN) or the ID of the record.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.