bedrockagentcorecontrol_synchronize_gateway_targets: Synchronizes the gateway targets by fetching the latest tool...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_synchronize_gateway_targetsR Documentation

Synchronizes the gateway targets by fetching the latest tool definitions from the target endpoints

Description

Synchronizes the gateway targets by fetching the latest tool definitions from the target endpoints.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_synchronize_gateway_targets/ for full documentation.

Usage

bedrockagentcorecontrol_synchronize_gateway_targets(
  gatewayIdentifier,
  targetIdList
)

Arguments

gatewayIdentifier

[required] The gateway Identifier.

targetIdList

[required] The target ID list.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.