View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_agent_runtime | R Documentation |
Updates an existing Amazon Secure Agent.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_agent_runtime/ for full documentation.
bedrockagentcorecontrol_update_agent_runtime(
agentRuntimeId,
agentRuntimeArtifact,
roleArn,
networkConfiguration,
description = NULL,
authorizerConfiguration = NULL,
requestHeaderConfiguration = NULL,
protocolConfiguration = NULL,
lifecycleConfiguration = NULL,
metadataConfiguration = NULL,
environmentVariables = NULL,
filesystemConfigurations = NULL,
clientToken = NULL
)
agentRuntimeId |
[required] The unique identifier of the AgentCore Runtime to update. |
agentRuntimeArtifact |
[required] The updated artifact of the AgentCore Runtime. |
roleArn |
[required] The updated IAM role ARN that provides permissions for the AgentCore Runtime. |
networkConfiguration |
[required] The updated network configuration for the AgentCore Runtime. |
description |
The updated description of the AgentCore Runtime. |
authorizerConfiguration |
The updated authorizer configuration for the AgentCore Runtime. |
requestHeaderConfiguration |
The updated configuration for HTTP request headers that will be passed through to the runtime. |
protocolConfiguration |
The protocol configuration for an agent runtime. This structure defines how the agent runtime communicates with clients. |
lifecycleConfiguration |
The updated life cycle configuration for the AgentCore Runtime. |
metadataConfiguration |
The updated configuration for microVM Metadata Service (MMDS) settings for the AgentCore Runtime. |
environmentVariables |
Updated environment variables to set in the AgentCore Runtime environment. |
filesystemConfigurations |
The updated filesystem configurations to mount into the AgentCore Runtime. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.