View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_configuration_bundle | R Documentation |
Updates a configuration bundle by creating a new version with the specified changes. Each update creates a new version in the version history.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_configuration_bundle/ for full documentation.
bedrockagentcorecontrol_update_configuration_bundle(
clientToken = NULL,
bundleId,
bundleName = NULL,
description = NULL,
components = NULL,
parentVersionIds = NULL,
branchName = NULL,
commitMessage = NULL,
createdBy = NULL
)
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
bundleId |
[required] The unique identifier of the configuration bundle to update. |
bundleName |
The updated name for the configuration bundle. |
description |
The updated description for the configuration bundle. |
components |
The updated component configurations. Creates a new version of the bundle. |
parentVersionIds |
A list of parent version identifiers for lineage tracking. Regular commits have a single parent. Merge commits have two parents: the target branch parent and the source branch parent. If the branch already exists, the first parent must be the latest version on that branch. |
branchName |
The branch name for this version. If not specified, inherits the parent's branch or defaults to |
commitMessage |
A commit message describing the changes in this version. |
createdBy |
The source that created this version, including the source name and optional ARN. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.