View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_gateway | R Documentation |
Updates an existing gateway.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_gateway/ for full documentation.
bedrockagentcorecontrol_update_gateway(
gatewayIdentifier,
name,
description = NULL,
roleArn,
protocolType = NULL,
protocolConfiguration = NULL,
authorizerType,
authorizerConfiguration = NULL,
kmsKeyArn = NULL,
interceptorConfigurations = NULL,
policyEngineConfiguration = NULL,
exceptionLevel = NULL
)
gatewayIdentifier |
[required] The identifier of the gateway to update. |
name |
[required] The name of the gateway. This name must be the same as the one when the gateway was created. |
description |
The updated description for the gateway. |
roleArn |
[required] The updated IAM role ARN that provides permissions for the gateway. |
protocolType |
The updated protocol type for the gateway. |
protocolConfiguration |
The configuration for a gateway protocol. This structure defines how the gateway communicates with external services. |
authorizerType |
[required] The updated authorizer type for the gateway. |
authorizerConfiguration |
The updated authorizer configuration for the gateway. |
kmsKeyArn |
The updated ARN of the KMS key used to encrypt the gateway. |
interceptorConfigurations |
The updated interceptor configurations for the gateway. |
policyEngineConfiguration |
The updated policy engine configuration for the gateway. A policy engine is a collection of policies that evaluates and authorizes agent tool calls. When associated with a gateway, the policy engine intercepts all agent requests and determines whether to allow or deny each action based on the defined policies. |
exceptionLevel |
The level of detail in error messages returned when invoking the gateway.
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.