View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_online_evaluation_config | R Documentation |
Updates an online evaluation configuration's settings, including rules, data sources, evaluators, and execution status. Changes take effect immediately for ongoing evaluations.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_online_evaluation_config/ for full documentation.
bedrockagentcorecontrol_update_online_evaluation_config(
clientToken = NULL,
onlineEvaluationConfigId,
description = NULL,
rule = NULL,
dataSourceConfig = NULL,
evaluators = NULL,
evaluationExecutionRoleArn = NULL,
executionStatus = NULL
)
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
onlineEvaluationConfigId |
[required] The unique identifier of the online evaluation configuration to update. |
description |
The updated description of the online evaluation configuration. |
rule |
The updated evaluation rule containing sampling configuration, filters, and session settings. |
dataSourceConfig |
The updated data source configuration specifying CloudWatch log groups and service names to monitor. |
evaluators |
The updated list of evaluators to apply during online evaluation. |
evaluationExecutionRoleArn |
The updated Amazon Resource Name (ARN) of the IAM role used for evaluation execution. |
executionStatus |
The updated execution status to enable or disable the online evaluation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.