bedrockagentcorecontrol_update_payment_connector: Updates an existing payment connector

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_update_payment_connectorR Documentation

Updates an existing payment connector

Description

Updates an existing payment connector. This operation uses PATCH semantics, so you only need to specify the fields you want to change.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_payment_connector/ for full documentation.

Usage

bedrockagentcorecontrol_update_payment_connector(
  paymentManagerId,
  paymentConnectorId,
  description = NULL,
  type = NULL,
  credentialProviderConfigurations = NULL,
  clientToken = NULL
)

Arguments

paymentManagerId

[required] The unique identifier of the parent payment manager.

paymentConnectorId

[required] The unique identifier of the payment connector to update.

description

The updated description of the payment connector.

type

The updated type of the payment connector.

credentialProviderConfigurations

The updated credential provider configurations for the payment connector.

clientToken

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.