bedrockagentcorecontrol_update_payment_credential_provider: Updates an existing payment credential provider with new...

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_update_payment_credential_providerR Documentation

Updates an existing payment credential provider with new authentication credentials

Description

Updates an existing payment credential provider with new authentication credentials.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_payment_credential_provider/ for full documentation.

Usage

bedrockagentcorecontrol_update_payment_credential_provider(
  name,
  credentialProviderVendor,
  providerConfigurationInput
)

Arguments

name

[required] The name of the payment credential provider to update.

credentialProviderVendor

[required] The vendor type for the payment credential provider (e.g., CoinbaseCDP, StripePrivy).

providerConfigurationInput

[required] Configuration specific to the vendor, including API credentials.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.