View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_payment_manager | R Documentation |
Updates an existing payment manager. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_payment_manager/ for full documentation.
bedrockagentcorecontrol_update_payment_manager(
paymentManagerId,
description = NULL,
authorizerType = NULL,
authorizerConfiguration = NULL,
roleArn = NULL,
clientToken = NULL
)
paymentManagerId |
[required] The unique identifier of the payment manager to update. |
description |
The updated description of the payment manager. |
authorizerType |
The updated authorizer type for the payment manager. |
authorizerConfiguration |
The updated authorizer configuration for the payment manager. |
roleArn |
The updated Amazon Resource Name (ARN) of the IAM role for the payment manager. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.