View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_policy_engine | R Documentation |
Updates an existing policy engine within the AgentCore Policy system. This operation allows modification of the policy engine description while maintaining its identity. This is an asynchronous operation. Use the get_policy_engine operation to poll the status field to track completion.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_policy_engine/ for full documentation.
bedrockagentcorecontrol_update_policy_engine(
policyEngineId,
description = NULL
)
policyEngineId |
[required] The unique identifier of the policy engine to be updated. |
description |
The new description for the policy engine. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.