View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_registry | R Documentation |
Updates an existing registry. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_registry/ for full documentation.
bedrockagentcorecontrol_update_registry(
registryId,
name = NULL,
description = NULL,
authorizerConfiguration = NULL,
approvalConfiguration = NULL
)
registryId |
[required] The identifier of the registry to update. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
name |
The updated name of the registry. |
description |
The updated description of the registry. To clear the description, include the |
authorizerConfiguration |
The updated authorizer configuration for the registry. Changing the authorizer configuration can break existing consumers of the registry who are using the authorization type prior to the update. |
approvalConfiguration |
The updated approval configuration for registry records. The updated configuration only affects new records that move to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.