View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_registry_record | R Documentation |
Updates an existing registry record. This operation uses PATCH semantics, so you only need to specify the fields you want to change. The update is processed asynchronously and returns HTTP 202 Accepted.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_registry_record/ for full documentation.
bedrockagentcorecontrol_update_registry_record(
registryId,
recordId,
name = NULL,
description = NULL,
descriptorType = NULL,
descriptors = NULL,
recordVersion = NULL,
synchronizationType = NULL,
synchronizationConfiguration = NULL,
triggerSynchronization = NULL
)
registryId |
[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
recordId |
[required] The identifier of the registry record to update. You can specify either the Amazon Resource Name (ARN) or the ID of the record. |
name |
The updated name for the registry record. |
description |
The updated description for the registry record. To clear the description, include the |
descriptorType |
The updated descriptor type for the registry record. Changing the descriptor type may require updating the |
descriptors |
The updated descriptor-type-specific configuration containing the resource schema and metadata. Uses PATCH semantics where individual descriptor fields can be updated independently. |
recordVersion |
The version of the registry record for optimistic locking. If provided, it must match the current version of the record. The service automatically increments the version after a successful update. |
synchronizationType |
The updated synchronization type for the registry record. |
synchronizationConfiguration |
The updated synchronization configuration for the registry record. |
triggerSynchronization |
Whether to trigger synchronization using the stored or provided configuration. When set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.