bedrockagentcorecontrol_update_registry_record_status: Updates the status of a registry record

View source: R/bedrockagentcorecontrol_operations.R

bedrockagentcorecontrol_update_registry_record_statusR Documentation

Updates the status of a registry record

Description

Updates the status of a registry record. Use this operation to approve, reject, or deprecate a registry record.

See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_registry_record_status/ for full documentation.

Usage

bedrockagentcorecontrol_update_registry_record_status(
  registryId,
  recordId,
  status,
  statusReason
)

Arguments

registryId

[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry.

recordId

[required] The identifier of the registry record to update the status for. You can specify either the Amazon Resource Name (ARN) or the ID of the record.

status

[required] The target status for the registry record.

statusReason

[required] The reason for the status change, such as why the record was approved or rejected.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.