View source: R/bedrockagentruntime_service.R
| bedrockagentruntime | R Documentation |
Contains APIs related to model invocation and querying of knowledge bases.
bedrockagentruntime(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- bedrockagentruntime(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| create_invocation | Creates a new invocation within a session |
| create_session | Creates a session to temporarily store conversations for generative AI (GenAI) applications built with open-source frameworks such as LangGraph and LlamaIndex |
| delete_agent_memory | Deletes memory from the specified memory identifier |
| delete_session | Deletes a session that you ended |
| end_session | Ends the session |
| generate_query | Generates an SQL query from a natural language query |
| get_agent_memory | Gets the sessions stored in the memory of the agent |
| get_execution_flow_snapshot | Retrieves the flow definition snapshot used for a flow execution |
| get_flow_execution | Retrieves details about a specific flow execution, including its status, start and end times, and any errors that occurred during execution |
| get_invocation_step | Retrieves the details of a specific invocation step within an invocation in a session |
| get_session | Retrieves details about a specific session |
| invoke_agent | Sends a prompt for the agent to process and respond to |
| invoke_flow | Invokes an alias of a flow to run the inputs that you specify and return the output of each node as a stream |
| invoke_inline_agent | Invokes an inline Amazon Bedrock agent using the configurations you provide with the request |
| list_flow_execution_events | Lists events that occurred during a flow execution |
| list_flow_executions | Lists all executions of a flow |
| list_invocations | Lists all invocations associated with a specific session |
| list_invocation_steps | Lists all invocation steps associated with a session and optionally, an invocation within the session |
| list_sessions | Lists all sessions in your Amazon Web Services account |
| list_tags_for_resource | List all the tags for the resource you specify |
| optimize_prompt | Optimizes a prompt for the task that you specify |
| put_invocation_step | Add an invocation step to an invocation in a session |
| rerank | Reranks the relevance of sources based on queries |
| retrieve | Queries a knowledge base and retrieves information from it |
| retrieve_and_generate | Queries a knowledge base and generates responses based on the retrieved results and using the specified foundation model or inference profile |
| retrieve_and_generate_stream | Queries a knowledge base and generates responses based on the retrieved results, with output in streaming format |
| start_flow_execution | Starts an execution of an Amazon Bedrock flow |
| stop_flow_execution | Stops an Amazon Bedrock flow's execution |
| tag_resource | Associate tags with a resource |
| untag_resource | Remove tags from a resource |
| update_session | Updates the metadata or encryption settings of a session |
## Not run:
svc <- bedrockagentruntime()
svc$create_invocation(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.