bedrockagentruntime_create_invocation: Creates a new invocation within a session

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_create_invocationR Documentation

Creates a new invocation within a session

Description

Creates a new invocation within a session. An invocation groups the related invocation steps that store the content from a conversation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_create_invocation/ for full documentation.

Usage

bedrockagentruntime_create_invocation(
  description = NULL,
  invocationId = NULL,
  sessionIdentifier
)

Arguments

description

A description for the interactions in the invocation. For example, "User asking about weather in Seattle".

invocationId

A unique identifier for the invocation in UUID format.

sessionIdentifier

[required] The unique identifier for the associated session for the invocation. You can specify either the session's sessionId or its Amazon Resource Name (ARN).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.