bedrockagentruntime_delete_session: Deletes a session that you ended

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_delete_sessionR Documentation

Deletes a session that you ended

Description

Deletes a session that you ended. You can't delete a session with an ACTIVE status. To delete an active session, you must first end it with the end_session API operation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_delete_session/ for full documentation.

Usage

bedrockagentruntime_delete_session(sessionIdentifier)

Arguments

sessionIdentifier

[required] The unique identifier for the session to be deleted. You can specify either the session's sessionId or its Amazon Resource Name (ARN).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.