bedrockagentruntime_end_session: Ends the session

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_end_sessionR Documentation

Ends the session

Description

Ends the session. After you end a session, you can still access its content but you can’t add to it. To delete the session and it's content, you use the DeleteSession API operation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_end_session/ for full documentation.

Usage

bedrockagentruntime_end_session(sessionIdentifier)

Arguments

sessionIdentifier

[required] The unique identifier for the session to end. You can specify either the session's sessionId or its Amazon Resource Name (ARN).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.