bedrockagentruntime_get_flow_execution: Retrieves details about a specific flow execution, including...

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_get_flow_executionR Documentation

Retrieves details about a specific flow execution, including its status, start and end times, and any errors that occurred during execution

Description

Retrieves details about a specific flow execution, including its status, start and end times, and any errors that occurred during execution.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_flow_execution/ for full documentation.

Usage

bedrockagentruntime_get_flow_execution(
  executionIdentifier,
  flowAliasIdentifier,
  flowIdentifier
)

Arguments

executionIdentifier

[required] The unique identifier of the flow execution to retrieve.

flowAliasIdentifier

[required] The unique identifier of the flow alias used for the execution.

flowIdentifier

[required] The unique identifier of the flow.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.