bedrockagentruntime_get_session: Retrieves details about a specific session

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_get_sessionR Documentation

Retrieves details about a specific session

Description

Retrieves details about a specific session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_session/ for full documentation.

Usage

bedrockagentruntime_get_session(sessionIdentifier)

Arguments

sessionIdentifier

[required] A unique identifier for the session to retrieve. You can specify either the session's sessionId or its Amazon Resource Name (ARN).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.