bedrockagentruntime_invoke_inline_agent: Invokes an inline Amazon Bedrock agent using the...

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_invoke_inline_agentR Documentation

Invokes an inline Amazon Bedrock agent using the configurations you provide with the request

Description

Invokes an inline Amazon Bedrock agent using the configurations you provide with the request.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_invoke_inline_agent/ for full documentation.

Usage

bedrockagentruntime_invoke_inline_agent(
  actionGroups = NULL,
  agentCollaboration = NULL,
  agentName = NULL,
  bedrockModelConfigurations = NULL,
  collaboratorConfigurations = NULL,
  collaborators = NULL,
  customOrchestration = NULL,
  customerEncryptionKeyArn = NULL,
  enableTrace = NULL,
  endSession = NULL,
  foundationModel,
  guardrailConfiguration = NULL,
  idleSessionTTLInSeconds = NULL,
  inlineSessionState = NULL,
  inputText = NULL,
  instruction,
  knowledgeBases = NULL,
  orchestrationType = NULL,
  promptCreationConfigurations = NULL,
  promptOverrideConfiguration = NULL,
  sessionId,
  streamingConfigurations = NULL
)

Arguments

actionGroups

A list of action groups with each action group defining the action the inline agent needs to carry out.

agentCollaboration

Defines how the inline collaborator agent handles information across multiple collaborator agents to coordinate a final response. The inline collaborator agent can also be the supervisor.

agentName

The name for the agent.

bedrockModelConfigurations

Model settings for the request.

collaboratorConfigurations

Settings for an inline agent collaborator called with invoke_inline_agent.

collaborators

List of collaborator inline agents.

customOrchestration

Contains details of the custom orchestration configured for the agent.

customerEncryptionKeyArn

The Amazon Resource Name (ARN) of the Amazon Web Services KMS key to use to encrypt your inline agent.

enableTrace

Specifies whether to turn on the trace or not to track the agent's reasoning process. For more information, see Using trace.

endSession

Specifies whether to end the session with the inline agent or not.

foundationModel

[required] The model identifier (ID) of the model to use for orchestration by the inline agent. For example, ⁠meta.llama3-1-70b-instruct-v1:0⁠.

guardrailConfiguration

The guardrails to assign to the inline agent.

idleSessionTTLInSeconds

The number of seconds for which the inline agent should maintain session information. After this time expires, the subsequent invoke_inline_agent request begins a new session.

A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and the data provided before the timeout is deleted.

inlineSessionState

Parameters that specify the various attributes of a sessions. You can include attributes for the session or prompt or, if you configured an action group to return control, results from invocation of the action group. For more information, see Control session context.

If you include returnControlInvocationResults in the sessionState field, the inputText field will be ignored.

inputText

The prompt text to send to the agent.

If you include returnControlInvocationResults in the sessionState field, the inputText field will be ignored.

instruction

[required] The instructions that tell the inline agent what it should do and how it should interact with users.

knowledgeBases

Contains information of the knowledge bases to associate with.

orchestrationType

Specifies the type of orchestration strategy for the agent. This is set to DEFAULT orchestration type, by default.

promptCreationConfigurations

Specifies parameters that control how the service populates the agent prompt for an invoke_inline_agent request. You can control which aspects of previous invocations in the same agent session the service uses to populate the agent prompt. This gives you more granular control over the contextual history that is used to process the current request.

promptOverrideConfiguration

Configurations for advanced prompts used to override the default prompts to enhance the accuracy of the inline agent.

sessionId

[required] The unique identifier of the session. Use the same value across requests to continue the same conversation.

streamingConfigurations

Specifies the configurations for streaming.

To use agent streaming, you need permissions to perform the bedrock:InvokeModelWithResponseStream action.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.