bedrockagentruntime_list_flow_execution_events: Lists events that occurred during a flow execution

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_list_flow_execution_eventsR Documentation

Lists events that occurred during a flow execution

Description

Lists events that occurred during a flow execution. Events provide detailed information about the execution progress, including node inputs and outputs, flow inputs and outputs, condition results, and failure events.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_list_flow_execution_events/ for full documentation.

Usage

bedrockagentruntime_list_flow_execution_events(
  eventType,
  executionIdentifier,
  flowAliasIdentifier,
  flowIdentifier,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

eventType

[required] The type of events to retrieve. Specify Node for node-level events or Flow for flow-level events.

executionIdentifier

[required] The unique identifier of the flow execution.

flowAliasIdentifier

[required] The unique identifier of the flow alias used for the execution.

flowIdentifier

[required] The unique identifier of the flow.

maxResults

The maximum number of events to return in a single response. If more events exist than the specified maxResults value, a token is included in the response so that the remaining results can be retrieved.

nextToken

A token to retrieve the next set of results. This value is returned in the response if more results are available.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.