View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_list_invocation_steps | R Documentation |
Lists all invocation steps associated with a session and optionally, an invocation within the session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_list_invocation_steps/ for full documentation.
bedrockagentruntime_list_invocation_steps(
invocationIdentifier = NULL,
maxResults = NULL,
nextToken = NULL,
sessionIdentifier
)
invocationIdentifier |
The unique identifier (in UUID format) for the invocation to list invocation steps for. |
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
sessionIdentifier |
[required] The unique identifier for the session associated with the invocation steps. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.