View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_list_invocations | R Documentation |
Lists all invocations associated with a specific session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_list_invocations/ for full documentation.
bedrockagentruntime_list_invocations(
maxResults = NULL,
nextToken = NULL,
sessionIdentifier
)
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
sessionIdentifier |
[required] The unique identifier for the session to list invocations for. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.