View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_list_sessions | R Documentation |
Lists all sessions in your Amazon Web Services account. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_list_sessions/ for full documentation.
bedrockagentruntime_list_sessions(maxResults = NULL, nextToken = NULL)
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.