bedrockagentruntime_put_invocation_step: Add an invocation step to an invocation in a session

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_put_invocation_stepR Documentation

Add an invocation step to an invocation in a session

Description

Add an invocation step to an invocation in a session. An invocation step stores fine-grained state checkpoints, including text and images, for each interaction. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_put_invocation_step/ for full documentation.

Usage

bedrockagentruntime_put_invocation_step(
  invocationIdentifier,
  invocationStepId = NULL,
  invocationStepTime,
  payload,
  sessionIdentifier
)

Arguments

invocationIdentifier

[required] The unique identifier (in UUID format) of the invocation to add the invocation step to.

invocationStepId

The unique identifier of the invocation step in UUID format.

invocationStepTime

[required] The timestamp for when the invocation step occurred.

payload

[required] The payload for the invocation step, including text and images for the interaction.

sessionIdentifier

[required] The unique identifier for the session to add the invocation step to. You can specify either the session's sessionId or its Amazon Resource Name (ARN).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.