bedrockagentruntime_start_flow_execution: Starts an execution of an Amazon Bedrock flow

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_start_flow_executionR Documentation

Starts an execution of an Amazon Bedrock flow

Description

Starts an execution of an Amazon Bedrock flow. Unlike flows that run until completion or time out after five minutes, flow executions let you run flows asynchronously for longer durations. Flow executions also yield control so that your application can perform other tasks.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_start_flow_execution/ for full documentation.

Usage

bedrockagentruntime_start_flow_execution(
  flowAliasIdentifier,
  flowExecutionName = NULL,
  flowIdentifier,
  inputs,
  modelPerformanceConfiguration = NULL
)

Arguments

flowAliasIdentifier

[required] The unique identifier of the flow alias to use for the flow execution.

flowExecutionName

The unique name for the flow execution. If you don't provide one, a system-generated name is used.

flowIdentifier

[required] The unique identifier of the flow to execute.

inputs

[required] The input data required for the flow execution. This must match the input schema defined in the flow.

modelPerformanceConfiguration

The performance settings for the foundation model used in the flow execution.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.