bedrockagentruntime_stop_flow_execution: Stops an Amazon Bedrock flow's execution

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_stop_flow_executionR Documentation

Stops an Amazon Bedrock flow's execution

Description

Stops an Amazon Bedrock flow's execution. This operation prevents further processing of the flow and changes the execution status to Aborted.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_stop_flow_execution/ for full documentation.

Usage

bedrockagentruntime_stop_flow_execution(
  executionIdentifier,
  flowAliasIdentifier,
  flowIdentifier
)

Arguments

executionIdentifier

[required] The unique identifier of the flow execution to stop.

flowAliasIdentifier

[required] The unique identifier of the flow alias used for the execution.

flowIdentifier

[required] The unique identifier of the flow.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.