bedrockagentruntime_update_session: Updates the metadata or encryption settings of a session

View source: R/bedrockagentruntime_operations.R

bedrockagentruntime_update_sessionR Documentation

Updates the metadata or encryption settings of a session

Description

Updates the metadata or encryption settings of a session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.

See https://www.paws-r-sdk.com/docs/bedrockagentruntime_update_session/ for full documentation.

Usage

bedrockagentruntime_update_session(sessionIdentifier, sessionMetadata = NULL)

Arguments

sessionIdentifier

[required] The unique identifier of the session to modify. You can specify either the session's sessionId or its Amazon Resource Name (ARN).

sessionMetadata

A map of key-value pairs containing attributes to be persisted across the session. For example the user's ID, their language preference, and the type of device they are using.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.