| bedrockdataautomation_get_data_automation_library_ingestion_job | R Documentation |
API used to get status of data automation library ingestion job
See https://www.paws-r-sdk.com/docs/bedrockdataautomation_get_data_automation_library_ingestion_job/ for full documentation.
bedrockdataautomation_get_data_automation_library_ingestion_job(
libraryArn,
jobArn
)
libraryArn |
[required] ARN generated at the server side when a DataAutomationLibrary is created |
jobArn |
[required] ARN of the DataAutomationLibraryIngestionJob |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.