bedrockdataautomation_get_data_automation_library_entity: Gets an existing entity based on entity type from the library

View source: R/bedrockdataautomation_operations.R

bedrockdataautomation_get_data_automation_library_entityR Documentation

Gets an existing entity based on entity type from the library

Description

Gets an existing entity based on entity type from the library

See https://www.paws-r-sdk.com/docs/bedrockdataautomation_get_data_automation_library_entity/ for full documentation.

Usage

bedrockdataautomation_get_data_automation_library_entity(
  libraryArn,
  entityType,
  entityId
)

Arguments

libraryArn

[required] ARN generated at the server side when a DataAutomationLibrary is created

entityType

[required] The entity type for which the entity is requested

entityId

[required] Unique identifier for the entity


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.