bedrockdataautomation_list_data_auto_libr_inge_jobs: Lists all data automation library ingestion jobs

bedrockdataautomation_list_data_automation_library_ingestion_jobsR Documentation

Lists all data automation library ingestion jobs

Description

Lists all data automation library ingestion jobs

See https://www.paws-r-sdk.com/docs/bedrockdataautomation_list_data_automation_library_ingestion_jobs/ for full documentation.

Usage

bedrockdataautomation_list_data_automation_library_ingestion_jobs(
  libraryArn,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

libraryArn

[required] ARN generated at the server side when a DataAutomationLibrary is created

maxResults

Max Results

nextToken

Pagination token for retrieving the next set of results


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.