bedrockruntime_apply_guardrail: The action to apply a guardrail

View source: R/bedrockruntime_operations.R

bedrockruntime_apply_guardrailR Documentation

The action to apply a guardrail

Description

The action to apply a guardrail.

See https://www.paws-r-sdk.com/docs/bedrockruntime_apply_guardrail/ for full documentation.

Usage

bedrockruntime_apply_guardrail(
  guardrailIdentifier,
  guardrailVersion,
  source,
  content,
  outputScope = NULL
)

Arguments

guardrailIdentifier

[required] The guardrail identifier used in the request to apply the guardrail.

guardrailVersion

[required] The guardrail version used in the request to apply the guardrail.

source

[required] The source of data used in the request to apply the guardrail.

content

[required] The content details used in the request to apply the guardrail.

outputScope

Specifies the scope of the output that you get in the response. Set to FULL to return the entire output, including any detected and non-detected entries in the response for enhanced debugging.

Note that the full output scope doesn't apply to word filters or regex in sensitive information filters. It does apply to all other filtering policies, including sensitive information with filters that can detect personally identifiable information (PII).


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.