View source: R/bedrockruntime_operations.R
| bedrockruntime_invoke_model_with_bidirectional_stream | R Documentation |
Invoke the specified Amazon Bedrock model to run inference using the bidirectional stream. The response is returned in a stream that remains open for 8 minutes. A single session can contain multiple prompts and responses from the model. The prompts to the model are provided as audio files and the model's responses are spoken back to the user and transcribed.
See https://www.paws-r-sdk.com/docs/bedrockruntime_invoke_model_with_bidirectional_stream/ for full documentation.
bedrockruntime_invoke_model_with_bidirectional_stream(modelId, body)
modelId |
[required] The model ID or ARN of the model ID to use. Currently, only |
body |
[required] The prompt and inference parameters in the format specified in the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.