Gets a list of the topic detection jobs that you have submitted.
See https://www.paws-r-sdk.com/docs/comprehend_list_topics_detection_jobs/ for full documentation.
comprehend_list_topics_detection_jobs(
Filter = NULL,
NextToken = NULL,
MaxResults = NULL
)Filters the jobs that are returned. Jobs can be filtered on their name, status, or the date and time that they were submitted. You can set only one filter at a time.
Identifies the next page of results to return.
The maximum number of results to return in each page. The default is 100.