View source: R/forecastservice_operations.R
| forecastservice_create_explainability | R Documentation |
Explainability is only available for Forecasts and Predictors generated from an AutoPredictor (create_auto_predictor)
See https://www.paws-r-sdk.com/docs/forecastservice_create_explainability/ for full documentation.
forecastservice_create_explainability(
ExplainabilityName,
ResourceArn,
ExplainabilityConfig,
DataSource = NULL,
Schema = NULL,
EnableVisualization = NULL,
StartDateTime = NULL,
EndDateTime = NULL,
Tags = NULL
)
ExplainabilityName |
[required] A unique name for the Explainability. |
ResourceArn |
[required] The Amazon Resource Name (ARN) of the Predictor or Forecast used to create the Explainability. |
ExplainabilityConfig |
[required] The configuration settings that define the granularity of time series and time points for the Explainability. |
DataSource |
The source of your data, an Identity and Access Management (IAM) role that allows Amazon Forecast to access the data and, optionally, an Key Management Service (KMS) key. |
Schema |
Defines the fields of a dataset. |
EnableVisualization |
Create an Explainability visualization that is viewable within the Amazon Web Services console. |
StartDateTime |
If Use the following timestamp format: yyyy-MM-ddTHH:mm:ss (example: 2015-01-01T20:00:00) |
EndDateTime |
If Use the following timestamp format: yyyy-MM-ddTHH:mm:ss (example: 2015-01-01T20:00:00) |
Tags |
Optional metadata to help you categorize and organize your resources. Each tag consists of a key and an optional value, both of which you define. Tag keys and values are case sensitive. The following restrictions apply to tags:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.