View source: R/forecastservice_operations.R
| forecastservice_create_explainability_export | R Documentation |
Exports an Explainability resource created by the create_explainability operation. Exported files are exported to an Amazon Simple Storage Service (Amazon S3) bucket.
See https://www.paws-r-sdk.com/docs/forecastservice_create_explainability_export/ for full documentation.
forecastservice_create_explainability_export(
ExplainabilityExportName,
ExplainabilityArn,
Destination,
Tags = NULL,
Format = NULL
)
ExplainabilityExportName |
[required] A unique name for the Explainability export. |
ExplainabilityArn |
[required] The Amazon Resource Name (ARN) of the Explainability to export. |
Destination |
[required] The destination for an export job. Provide an S3 path, an Identity and Access Management (IAM) role that allows Amazon Forecast to access the location, and an Key Management Service (KMS) key (optional). |
Tags |
Optional metadata to help you categorize and organize your resources. Each tag consists of a key and an optional value, both of which you define. Tag keys and values are case sensitive. The following restrictions apply to tags:
|
Format |
The format of the exported data, CSV or PARQUET. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.