View source: R/forecastservice_operations.R
| forecastservice_create_predictor_backtest_export_job | R Documentation |
Exports backtest forecasts and accuracy metrics generated by the create_auto_predictor or create_predictor operations. Two folders containing CSV or Parquet files are exported to your specified S3 bucket.
See https://www.paws-r-sdk.com/docs/forecastservice_create_predictor_backtest_export_job/ for full documentation.
forecastservice_create_predictor_backtest_export_job(
PredictorBacktestExportJobName,
PredictorArn,
Destination,
Tags = NULL,
Format = NULL
)
PredictorBacktestExportJobName |
[required] The name for the backtest export job. |
PredictorArn |
[required] The Amazon Resource Name (ARN) of the predictor that you want to export. |
Destination |
[required] The destination for an export job. Provide an S3 path, an Identity and Access Management (IAM) role that allows Amazon Forecast to access the location, and an Key Management Service (KMS) key (optional). |
Tags |
Optional metadata to help you categorize and organize your backtests. Each tag consists of a key and an optional value, both of which you define. Tag keys and values are case sensitive. The following restrictions apply to tags:
|
Format |
The format of the exported data, CSV or PARQUET. The default value is CSV. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.