Deletes a dataset import job created using the create_dataset_import_job operation. You can delete only dataset import jobs that have a status of ACTIVE or CREATE_FAILED. To get the status, use the describe_dataset_import_job operation.
See https://www.paws-r-sdk.com/docs/forecastservice_delete_dataset_import_job/ for full documentation.
forecastservice_delete_dataset_import_job(DatasetImportJobArn)[required] The Amazon Resource Name (ARN) of the dataset import job to delete.