lexmodelsv2_delete_bot_analyzer_recommendation: Permanently deletes the recommendations and analysis results...

View source: R/lexmodelsv2_operations.R

lexmodelsv2_delete_bot_analyzer_recommendationR Documentation

Permanently deletes the recommendations and analysis results for a specific bot analysis request

Description

Permanently deletes the recommendations and analysis results for a specific bot analysis request. This operation is provided for GDPR compliance and cannot be undone.

See https://www.paws-r-sdk.com/docs/lexmodelsv2_delete_bot_analyzer_recommendation/ for full documentation.

Usage

lexmodelsv2_delete_bot_analyzer_recommendation(botId, botAnalyzerRequestId)

Arguments

botId

[required] The unique identifier of the bot.

botAnalyzerRequestId

[required] The unique identifier of the analysis request whose recommendations should be deleted.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.