lexmodelsv2_describe_bot_analyzer_recommendation: Retrieves the analysis results and recommendations for bot...

View source: R/lexmodelsv2_operations.R

lexmodelsv2_describe_bot_analyzer_recommendationR Documentation

Retrieves the analysis results and recommendations for bot optimization

Description

Retrieves the analysis results and recommendations for bot optimization. The analysis must be in Available status before recommendations can be retrieved.

See https://www.paws-r-sdk.com/docs/lexmodelsv2_describe_bot_analyzer_recommendation/ for full documentation.

Usage

lexmodelsv2_describe_bot_analyzer_recommendation(
  botId,
  botAnalyzerRequestId,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

botId

[required] The unique identifier of the bot.

botAnalyzerRequestId

[required] The unique identifier of the analysis request.

nextToken

If the response from a previous request was truncated, the nextToken value is used to retrieve the next page of recommendations.

maxResults

The maximum number of recommendations to return in the response. The default is 5.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.