lexmodelsv2_list_bot_analyzer_history: Retrieves a list of historical bot analysis executions for a...

View source: R/lexmodelsv2_operations.R

lexmodelsv2_list_bot_analyzer_historyR Documentation

Retrieves a list of historical bot analysis executions for a specific bot

Description

Retrieves a list of historical bot analysis executions for a specific bot. You can filter the results by locale and bot version.

See https://www.paws-r-sdk.com/docs/lexmodelsv2_list_bot_analyzer_history/ for full documentation.

Usage

lexmodelsv2_list_bot_analyzer_history(
  botId,
  localeId = NULL,
  botVersion = NULL,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

botId

[required] The unique identifier of the bot.

localeId

The locale identifier to filter the history. If not specified, returns history for all locales.

botVersion

The bot version to filter the history. If not specified, defaults to DRAFT.

nextToken

If the response from a previous request was truncated, the nextToken value is used to retrieve the next page of history entries.

maxResults

The maximum number of history entries to return in the response. The default is 10.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.