lexmodelsv2_start_bot_analyzer: Initiates an asynchronous analysis of your bot configuration...

View source: R/lexmodelsv2_operations.R

lexmodelsv2_start_bot_analyzerR Documentation

Initiates an asynchronous analysis of your bot configuration using AI-powered analysis to identify potential issues and recommend improvements based on AWS best practices

Description

Initiates an asynchronous analysis of your bot configuration using AI-powered analysis to identify potential issues and recommend improvements based on AWS best practices.

See https://www.paws-r-sdk.com/docs/lexmodelsv2_start_bot_analyzer/ for full documentation.

Usage

lexmodelsv2_start_bot_analyzer(
  botId,
  analysisScope,
  localeId = NULL,
  botVersion = NULL
)

Arguments

botId

[required] The unique identifier of the bot to analyze.

analysisScope

[required] The scope of analysis to perform. Currently only BotLocale scope is supported.

Valid Values: BotLocale

localeId

The locale identifier for the bot locale to analyze. Required when analysisScope is BotLocale.

botVersion

The version of the bot to analyze. Defaults to DRAFT if not specified.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.