lexmodelsv2_stop_bot_analyzer: Cancels an ongoing bot analysis execution

View source: R/lexmodelsv2_operations.R

lexmodelsv2_stop_bot_analyzerR Documentation

Cancels an ongoing bot analysis execution

Description

Cancels an ongoing bot analysis execution. Once stopped, the analysis cannot be resumed and no recommendations will be generated.

See https://www.paws-r-sdk.com/docs/lexmodelsv2_stop_bot_analyzer/ for full documentation.

Usage

lexmodelsv2_stop_bot_analyzer(botId, botAnalyzerRequestId)

Arguments

botId

[required] The unique identifier of the bot.

botAnalyzerRequestId

[required] The unique identifier of the analysis request to stop.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.