View source: R/lexmodelsv2_operations.R
| lexmodelsv2_update_bot | R Documentation |
Updates the configuration of an existing bot.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_update_bot/ for full documentation.
lexmodelsv2_update_bot(
botId,
botName,
description = NULL,
roleArn,
dataPrivacy,
idleSessionTTLInSeconds,
botType = NULL,
botMembers = NULL,
errorLogSettings = NULL
)
botId |
[required] The unique identifier of the bot to update. This identifier is returned by the |
botName |
[required] The new name of the bot. The name must be unique in the account that creates the bot. |
description |
A description of the bot. |
roleArn |
[required] The Amazon Resource Name (ARN) of an IAM role that has permissions to access the bot. |
dataPrivacy |
[required] Provides information on additional privacy protections Amazon Lex should use with the bot's data. |
idleSessionTTLInSeconds |
[required] The time, in seconds, that Amazon Lex should keep information about a user's conversation with the bot. A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout. You can specify between 60 (1 minute) and 86,400 (24 hours) seconds. |
botType |
The type of the bot to be updated. |
botMembers |
The list of bot members in the network associated with the update action. |
errorLogSettings |
Allows you to modify how Amazon Lex logs errors during bot interactions, including destinations for error logs and the types of errors to be captured. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.