View source: R/lexmodelsv2_operations.R
| lexmodelsv2_update_bot_locale | R Documentation |
Updates the settings that a bot has for a specific locale.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_update_bot_locale/ for full documentation.
lexmodelsv2_update_bot_locale(
botId,
botVersion,
localeId,
description = NULL,
nluIntentConfidenceThreshold,
voiceSettings = NULL,
unifiedSpeechSettings = NULL,
audioFillerSettings = NULL,
speechRecognitionSettings = NULL,
generativeAISettings = NULL,
speechDetectionSensitivity = NULL
)
botId |
[required] The unique identifier of the bot that contains the locale. |
botVersion |
[required] The version of the bot that contains the locale to be updated. The version can only be the |
localeId |
[required] The identifier of the language and locale to update. The string must match one of the supported locales. For more information, see Supported languages. |
description |
The new description of the locale. |
nluIntentConfidenceThreshold |
[required] The new confidence threshold where Amazon Lex inserts the |
voiceSettings |
The new Amazon Polly voice Amazon Lex should use for voice interaction with the user. |
unifiedSpeechSettings |
Updated unified speech settings to apply to the bot locale. |
audioFillerSettings |
Updated audio filler settings to apply to the bot locale. When enabled, requires |
speechRecognitionSettings |
Updated speech-to-text settings to apply to the bot locale. |
generativeAISettings |
Contains settings for generative AI features powered by Amazon Bedrock for your bot locale. Use this object to turn generative AI features on and off. Pricing may differ if you turn a feature on. For more information, see LINK. |
speechDetectionSensitivity |
The new sensitivity level for voice activity detection (VAD) in the bot locale. This setting helps optimize speech recognition accuracy by adjusting how the system responds to background noise during voice interactions. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.