Lists all datasets currently available in your account, filtering on the dataset name.
See https://www.paws-r-sdk.com/docs/lookoutequipment_list_datasets/ for full documentation.
lookoutequipment_list_datasets(
NextToken = NULL,
MaxResults = NULL,
DatasetNameBeginsWith = NULL
)An opaque pagination token indicating where to continue the listing of datasets.
Specifies the maximum number of datasets to list.
The beginning of the name of the datasets to be listed.