View source: R/personalize_operations.R
| personalize_update_solution | R Documentation |
Updates an Amazon Personalize solution to use a different automatic training configuration. When you update a solution, you can change whether the solution uses automatic training, and you can change the training frequency. For more information about updating a solution, see Updating a solution.
See https://www.paws-r-sdk.com/docs/personalize_update_solution/ for full documentation.
personalize_update_solution(
solutionArn,
performAutoTraining = NULL,
performIncrementalUpdate = NULL,
solutionUpdateConfig = NULL
)
solutionArn |
[required] The Amazon Resource Name (ARN) of the solution to update. |
performAutoTraining |
Whether the solution uses automatic training to create new solution versions (trained models). You can change the training frequency by specifying a If you turn on automatic training, the first automatic training starts within one hour after the solution update completes. If you manually create a solution version within the hour, the solution skips the first automatic training. For more information about automatic training, see Configuring automatic training. After training starts, you can get the solution version's Amazon Resource Name (ARN) with the |
performIncrementalUpdate |
Whether to perform incremental training updates on your model. When enabled, this allows the model to learn from new data more frequently without requiring full retraining, which enables near real-time personalization. This parameter is supported only for solutions that use the semantic-similarity recipe. |
solutionUpdateConfig |
The new configuration details of the solution. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.