View source: R/rekognition_operations.R
| rekognition_associate_faces | R Documentation |
Associates one or more faces with an existing UserID. Takes an array of FaceIds. Each FaceId that are present in the FaceIds list is associated with the provided UserID. The number of FaceIds that can be used as input in a single request is limited to 100.
See https://www.paws-r-sdk.com/docs/rekognition_associate_faces/ for full documentation.
rekognition_associate_faces(
CollectionId,
UserId,
FaceIds,
UserMatchThreshold = NULL,
ClientRequestToken = NULL
)
CollectionId |
[required] The ID of an existing collection containing the UserID. |
UserId |
[required] The ID for the existing UserID. |
FaceIds |
[required] An array of FaceIDs to associate with the UserID. |
UserMatchThreshold |
An optional value specifying the minimum confidence in the UserID match to return. The default value is 75. |
ClientRequestToken |
Idempotent token used to identify the request to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.