View source: R/rekognition_operations.R
| rekognition_detect_custom_labels | R Documentation |
This operation applies only to Amazon Rekognition Custom Labels.
See https://www.paws-r-sdk.com/docs/rekognition_detect_custom_labels/ for full documentation.
rekognition_detect_custom_labels(
ProjectVersionArn,
Image,
MaxResults = NULL,
MinConfidence = NULL
)
ProjectVersionArn |
[required] The ARN of the model version that you want to use. Only models associated with Custom Labels projects accepted by the operation. If a provided ARN refers to a model version associated with a project for a different feature type, then an InvalidParameterException is returned. |
Image |
[required] Provides the input image either as bytes or an S3 object. You pass image bytes to an Amazon Rekognition API operation by using the For more information, see Analyzing an Image Loaded from a Local File System in the Amazon Rekognition Developer Guide. You pass images stored in an S3 bucket to an Amazon Rekognition API operation by using the The region for the S3 bucket containing the S3 object must match the region you use for Amazon Rekognition operations. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes using the Bytes property is not supported. You must first upload the image to an Amazon S3 bucket and then call the operation using the S3Object property. For Amazon Rekognition to process an S3 object, the user must have permission to access the S3 object. For more information, see How Amazon Rekognition works with IAM in the Amazon Rekognition Developer Guide. |
MaxResults |
Maximum number of results you want the service to return in the response. The service returns the specified number of highest confidence labels ranked from highest confidence to lowest. |
MinConfidence |
Specifies the minimum confidence level for the labels to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.