View source: R/rekognition_operations.R
| rekognition_start_content_moderation | R Documentation |
Starts asynchronous detection of inappropriate, unwanted, or offensive content in a stored video. For a list of moderation labels in Amazon Rekognition, see Using the image and video moderation APIs.
See https://www.paws-r-sdk.com/docs/rekognition_start_content_moderation/ for full documentation.
rekognition_start_content_moderation(
Video,
MinConfidence = NULL,
ClientRequestToken = NULL,
NotificationChannel = NULL,
JobTag = NULL
)
Video |
[required] The video in which you want to detect inappropriate, unwanted, or offensive content. The video must be stored in an Amazon S3 bucket. |
MinConfidence |
Specifies the minimum confidence that Amazon Rekognition must have in order to return a moderated content label. Confidence represents how certain Amazon Rekognition is that the moderated content is correctly identified. 0 is the lowest confidence. 100 is the highest confidence. Amazon Rekognition doesn't return any moderated content labels with a confidence level lower than this specified value. If you don't specify |
ClientRequestToken |
Idempotent token used to identify the start request. If you use the same token with multiple |
NotificationChannel |
The Amazon SNS topic ARN that you want Amazon Rekognition Video to publish the completion status of the content analysis to. The Amazon SNS topic must have a topic name that begins with AmazonRekognition if you are using the AmazonRekognitionServiceRole permissions policy to access the topic. |
JobTag |
An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.