rekognition_start_person_tracking: End of support notice: On October 31, 2025, AWS will...

View source: R/rekognition_operations.R

rekognition_start_person_trackingR Documentation

End of support notice: On October 31, 2025, AWS will discontinue support for Amazon Rekognition People Pathing

Description

End of support notice: On October 31, 2025, AWS will discontinue support for Amazon Rekognition People Pathing. After October 31, 2025, you will no longer be able to use the Rekognition People Pathing capability. For more information, visit this blog post.

See https://www.paws-r-sdk.com/docs/rekognition_start_person_tracking/ for full documentation.

Usage

rekognition_start_person_tracking(
  Video,
  ClientRequestToken = NULL,
  NotificationChannel = NULL,
  JobTag = NULL
)

Arguments

Video

[required] The video in which you want to detect people. The video must be stored in an Amazon S3 bucket.

ClientRequestToken

Idempotent token used to identify the start request. If you use the same token with multiple start_person_tracking requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once.

NotificationChannel

The Amazon SNS topic ARN you want Amazon Rekognition Video to publish the completion status of the people detection operation to. The Amazon SNS topic must have a topic name that begins with AmazonRekognition if you are using the AmazonRekognitionServiceRole permissions policy.

JobTag

An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.