View source: R/rekognition_operations.R
| rekognition_start_segment_detection | R Documentation |
Starts asynchronous detection of segment detection in a stored video.
See https://www.paws-r-sdk.com/docs/rekognition_start_segment_detection/ for full documentation.
rekognition_start_segment_detection(
Video,
ClientRequestToken = NULL,
NotificationChannel = NULL,
JobTag = NULL,
Filters = NULL,
SegmentTypes
)
Video |
[required] Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as |
ClientRequestToken |
Idempotent token used to identify the start request. If you use the same token with multiple |
NotificationChannel |
The ARN of the Amazon SNS topic to which you want Amazon Rekognition Video to publish the completion status of the segment detection operation. Note that the Amazon SNS topic must have a topic name that begins with AmazonRekognition if you are using the AmazonRekognitionServiceRole permissions policy to access the topic. |
JobTag |
An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use |
Filters |
Filters for technical cue or shot detection. |
SegmentTypes |
[required] An array of segment types to detect in the video. Valid values are TECHNICAL_CUE and SHOT. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.