rekognition_start_text_detection: Starts asynchronous detection of text in a stored video

View source: R/rekognition_operations.R

rekognition_start_text_detectionR Documentation

Starts asynchronous detection of text in a stored video

Description

Starts asynchronous detection of text in a stored video.

See https://www.paws-r-sdk.com/docs/rekognition_start_text_detection/ for full documentation.

Usage

rekognition_start_text_detection(
  Video,
  ClientRequestToken = NULL,
  NotificationChannel = NULL,
  JobTag = NULL,
  Filters = NULL
)

Arguments

Video

[required] Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as start_label_detection use Video to specify a video for analysis. The supported file formats are .mp4, .mov and .avi.

ClientRequestToken

Idempotent token used to identify the start request. If you use the same token with multiple start_text_detection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentaly started more than once.

NotificationChannel

The Amazon Simple Notification Service topic to which Amazon Rekognition publishes the completion status of a video analysis operation. For more information, see Calling Amazon Rekognition Video operations. Note that the Amazon SNS topic must have a topic name that begins with AmazonRekognition if you are using the AmazonRekognitionServiceRole permissions policy to access the topic. For more information, see Giving access to multiple Amazon SNS topics.

JobTag

An identifier returned in the completion status published by your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification.

Filters

Optional parameters that let you set criteria the text must meet to be included in your response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.