sagemaker_attach_cluster_node_volume: Attaches your Amazon Elastic Block Store (Amazon EBS) volume...

View source: R/sagemaker_operations.R

sagemaker_attach_cluster_node_volumeR Documentation

Attaches your Amazon Elastic Block Store (Amazon EBS) volume to a node in your EKS orchestrated HyperPod cluster

Description

Attaches your Amazon Elastic Block Store (Amazon EBS) volume to a node in your EKS orchestrated HyperPod cluster.

See https://www.paws-r-sdk.com/docs/sagemaker_attach_cluster_node_volume/ for full documentation.

Usage

sagemaker_attach_cluster_node_volume(ClusterArn, NodeId, VolumeId)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node. Your cluster must use EKS as the orchestration and be in the InService state.

NodeId

[required] The unique identifier of the cluster node to which you want to attach the volume. The node must belong to your specified HyperPod cluster and cannot be part of a Restricted Instance Group (RIG).

VolumeId

[required] The unique identifier of your EBS volume to attach. The volume must be in the available state.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.