sagemaker_batch_add_cluster_nodes: Adds nodes to a HyperPod cluster by incrementing the target...

View source: R/sagemaker_operations.R

sagemaker_batch_add_cluster_nodesR Documentation

Adds nodes to a HyperPod cluster by incrementing the target count for one or more instance groups

Description

Adds nodes to a HyperPod cluster by incrementing the target count for one or more instance groups. This operation returns a unique NodeLogicalId for each node being added, which can be used to track the provisioning status of the node. This API provides a safer alternative to update_cluster for scaling operations by avoiding unintended configuration changes.

See https://www.paws-r-sdk.com/docs/sagemaker_batch_add_cluster_nodes/ for full documentation.

Usage

sagemaker_batch_add_cluster_nodes(ClusterName, ClientToken = NULL, NodesToAdd)

Arguments

ClusterName

[required] The name of the HyperPod cluster to which you want to add nodes.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This token is valid for 8 hours. If you retry the request with the same client token within this timeframe and the same parameters, the API returns the same set of NodeLogicalIds with their latest status.

NodesToAdd

[required] A list of instance groups and the number of nodes to add to each. You can specify up to 5 instance groups in a single request, with a maximum of 50 nodes total across all instance groups.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.