sagemaker_batch_delete_cluster_nodes: Deletes specific nodes within a SageMaker HyperPod cluster

View source: R/sagemaker_operations.R

sagemaker_batch_delete_cluster_nodesR Documentation

Deletes specific nodes within a SageMaker HyperPod cluster

Description

Deletes specific nodes within a SageMaker HyperPod cluster. batch_delete_cluster_nodes accepts a cluster name and a list of node IDs.

See https://www.paws-r-sdk.com/docs/sagemaker_batch_delete_cluster_nodes/ for full documentation.

Usage

sagemaker_batch_delete_cluster_nodes(
  ClusterName,
  NodeIds = NULL,
  NodeLogicalIds = NULL
)

Arguments

ClusterName

[required] The name of the SageMaker HyperPod cluster from which to delete the specified nodes.

NodeIds

A list of node IDs to be deleted from the specified cluster.

  • For SageMaker HyperPod clusters using the Slurm workload manager, you cannot remove instances that are configured as Slurm controller nodes.

  • If you need to delete more than 99 instances, contact Support for assistance.

NodeLogicalIds

A list of NodeLogicalIds identifying the nodes to be deleted. You can specify up to 50 NodeLogicalIds. You must specify either NodeLogicalIds, InstanceIds, or both, with a combined maximum of 50 identifiers.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.