sagemaker_batch_reboot_cluster_nodes: Reboots specific nodes within a SageMaker HyperPod cluster...

View source: R/sagemaker_operations.R

sagemaker_batch_reboot_cluster_nodesR Documentation

Reboots specific nodes within a SageMaker HyperPod cluster using a soft recovery mechanism

Description

Reboots specific nodes within a SageMaker HyperPod cluster using a soft recovery mechanism. batch_reboot_cluster_nodes performs a graceful reboot of the specified nodes by calling the Amazon Elastic Compute Cloud RebootInstances API, which attempts to cleanly shut down the operating system before restarting the instance.

See https://www.paws-r-sdk.com/docs/sagemaker_batch_reboot_cluster_nodes/ for full documentation.

Usage

sagemaker_batch_reboot_cluster_nodes(
  ClusterName,
  NodeIds = NULL,
  NodeLogicalIds = NULL
)

Arguments

ClusterName

[required] The name or Amazon Resource Name (ARN) of the SageMaker HyperPod cluster containing the nodes to reboot.

NodeIds

A list of EC2 instance IDs to reboot using soft recovery. You can specify between 1 and 25 instance IDs.

  • Either NodeIds or NodeLogicalIds must be provided (or both), but at least one is required.

  • Each instance ID must follow the pattern ⁠i-⁠ followed by 17 hexadecimal characters (for example, ⁠i-0123456789abcdef0⁠).

NodeLogicalIds

A list of logical node IDs to reboot using soft recovery. You can specify between 1 and 25 logical node IDs.

The NodeLogicalId is a unique identifier that persists throughout the node's lifecycle and can be used to track nodes that are still being provisioned and don't yet have an EC2 instance ID assigned.

  • This parameter is only supported for clusters using Continuous as the NodeProvisioningMode. For clusters using the default provisioning mode, use NodeIds instead.

  • Either NodeIds or NodeLogicalIds must be provided (or both), but at least one is required.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.