View source: R/sagemaker_operations.R
| sagemaker_create_ai_benchmark_job | R Documentation |
Creates a benchmark job that runs performance benchmarks against inference infrastructure using a predefined AI workload configuration. The benchmark job measures metrics such as latency, throughput, and cost for your generative AI inference endpoints.
See https://www.paws-r-sdk.com/docs/sagemaker_create_ai_benchmark_job/ for full documentation.
sagemaker_create_ai_benchmark_job(
AIBenchmarkJobName,
BenchmarkTarget,
OutputConfig,
AIWorkloadConfigIdentifier,
RoleArn,
NetworkConfig = NULL,
Tags = NULL
)
AIBenchmarkJobName |
[required] The name of the AI benchmark job. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region. |
BenchmarkTarget |
[required] The target endpoint to benchmark. Specify a SageMaker endpoint by providing its name or Amazon Resource Name (ARN). |
OutputConfig |
[required] The output configuration for the benchmark job, including the Amazon S3 location where benchmark results are stored. |
AIWorkloadConfigIdentifier |
[required] The name or Amazon Resource Name (ARN) of the AI workload configuration to use for this benchmark job. |
RoleArn |
[required] The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf. |
NetworkConfig |
The network configuration for the benchmark job, including VPC settings. |
Tags |
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.