View source: R/sagemaker_operations.R
| sagemaker_create_ai_workload_config | R Documentation |
Creates a reusable AI workload configuration that defines datasets, data sources, and benchmark tool settings for consistent performance testing of generative AI inference deployments on Amazon SageMaker AI.
See https://www.paws-r-sdk.com/docs/sagemaker_create_ai_workload_config/ for full documentation.
sagemaker_create_ai_workload_config(
AIWorkloadConfigName,
DatasetConfig = NULL,
AIWorkloadConfigs = NULL,
Tags = NULL
)
AIWorkloadConfigName |
[required] The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region. |
DatasetConfig |
The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads. |
AIWorkloadConfigs |
The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string. |
Tags |
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see Tagging Amazon Web Services Resources in the Amazon Web Services General Reference. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.