View source: R/sagemaker_operations.R
| sagemaker_create_cluster | R Documentation |
Creates an Amazon SageMaker HyperPod cluster. SageMaker HyperPod is a capability of SageMaker for creating and managing persistent clusters for developing large machine learning models, such as large language models (LLMs) and diffusion models. To learn more, see Amazon SageMaker HyperPod in the Amazon SageMaker Developer Guide.
See https://www.paws-r-sdk.com/docs/sagemaker_create_cluster/ for full documentation.
sagemaker_create_cluster(
ClusterName,
InstanceGroups = NULL,
RestrictedInstanceGroups = NULL,
RestrictedInstanceGroupsConfig = NULL,
VpcConfig = NULL,
Tags = NULL,
Orchestrator = NULL,
NodeRecovery = NULL,
TieredStorageConfig = NULL,
NodeProvisioningMode = NULL,
ClusterRole = NULL,
AutoScaling = NULL
)
ClusterName |
[required] The name for the new SageMaker HyperPod cluster. |
InstanceGroups |
The instance groups to be created in the SageMaker HyperPod cluster. |
RestrictedInstanceGroups |
The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster. |
RestrictedInstanceGroupsConfig |
The configuration for the restricted instance groups (RIG) in the SageMaker HyperPod cluster. |
VpcConfig |
Specifies the Amazon Virtual Private Cloud (VPC) that is associated with the Amazon SageMaker HyperPod cluster. You can control access to and from your resources by configuring your VPC. For more information, see Give SageMaker access to resources in your Amazon VPC. When your Amazon VPC and subnets support IPv6, network communications differ based on the cluster orchestration platform:
Additional resources for IPv6 configuration:
|
Tags |
Custom tags for managing the SageMaker HyperPod cluster as an Amazon Web Services resource. You can add tags to your cluster in the same way you add them in other Amazon Web Services services that support tagging. To learn more about tagging Amazon Web Services resources in general, see Tagging Amazon Web Services Resources User Guide. |
Orchestrator |
The type of orchestrator to use for the SageMaker HyperPod cluster. Currently, supported values are If you specify the |
NodeRecovery |
The node recovery mode for the SageMaker HyperPod cluster. When set to |
TieredStorageConfig |
The configuration for managed tier checkpointing on the HyperPod cluster. When enabled, this feature uses a multi-tier storage approach for storing model checkpoints, providing faster checkpoint operations and improved fault tolerance across cluster nodes. |
NodeProvisioningMode |
The mode for provisioning nodes in the cluster. You can specify the following modes:
|
ClusterRole |
The Amazon Resource Name (ARN) of the IAM role that HyperPod assumes to perform cluster autoscaling operations. This role must have permissions for |
AutoScaling |
The autoscaling configuration for the cluster. Enables automatic scaling of cluster nodes based on workload demand using a Karpenter-based system. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.