View source: R/sagemaker_operations.R
| sagemaker_create_data_quality_job_definition | R Documentation |
Creates a definition for a job that monitors data quality and drift. For information about model monitor, see Amazon SageMaker AI Model Monitor.
See https://www.paws-r-sdk.com/docs/sagemaker_create_data_quality_job_definition/ for full documentation.
sagemaker_create_data_quality_job_definition(
JobDefinitionName,
DataQualityBaselineConfig = NULL,
DataQualityAppSpecification,
DataQualityJobInput,
DataQualityJobOutputConfig,
JobResources,
NetworkConfig = NULL,
RoleArn,
StoppingCondition = NULL,
Tags = NULL
)
JobDefinitionName |
[required] The name for the monitoring job definition. |
DataQualityBaselineConfig |
Configures the constraints and baselines for the monitoring job. |
DataQualityAppSpecification |
[required] Specifies the container that runs the monitoring job. |
DataQualityJobInput |
[required] A list of inputs for the monitoring job. Currently endpoints are supported as monitoring inputs. |
DataQualityJobOutputConfig |
[required] The output configuration for monitoring jobs. |
JobResources |
[required] Identifies the resources to deploy for a monitoring job. |
NetworkConfig |
Specifies networking configuration for the monitoring job. |
RoleArn |
[required] The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker AI can assume to perform tasks on your behalf. |
StoppingCondition |
Specifies a limit to how long a job can run. When the job reaches the time limit, SageMaker ends the job. Use this API to cap costs. To stop a training job, SageMaker sends the algorithm the The training algorithms provided by SageMaker automatically save the intermediate results of a model training job when possible. This attempt to save artifacts is only a best effort case as model might not be in a state from which it can be saved. For example, if training has just started, the model might not be ready to save. When saved, this intermediate data is a valid model artifact. You can use it to create a model with The Neural Topic Model (NTM) currently does not support saving intermediate model artifacts. When training NTMs, make sure that the maximum runtime is sufficient for the training job to complete. |
Tags |
(Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.