View source: R/sagemaker_operations.R
| sagemaker_create_hub_content_presigned_urls | R Documentation |
Creates presigned URLs for accessing hub content artifacts. This operation generates time-limited, secure URLs that allow direct download of model artifacts and associated files from Amazon SageMaker hub content, including gated models that require end-user license agreement acceptance.
See https://www.paws-r-sdk.com/docs/sagemaker_create_hub_content_presigned_urls/ for full documentation.
sagemaker_create_hub_content_presigned_urls(
HubName,
HubContentType,
HubContentName,
HubContentVersion = NULL,
AccessConfig = NULL,
MaxResults = NULL,
NextToken = NULL
)
HubName |
[required] The name or Amazon Resource Name (ARN) of the hub that contains the content. For public content, use |
HubContentType |
[required] The type of hub content to access. Valid values include |
HubContentName |
[required] The name of the hub content for which to generate presigned URLs. This identifies the specific model or content within the hub. |
HubContentVersion |
The version of the hub content. If not specified, the latest version is used. |
AccessConfig |
Configuration settings for accessing the hub content, including end-user license agreement acceptance for gated models and expected S3 URL validation. |
MaxResults |
The maximum number of presigned URLs to return in the response. Default value is 100. Large models may contain hundreds of files, requiring pagination to retrieve all URLs. |
NextToken |
A token for pagination. Use this token to retrieve the next set of presigned URLs when the response is truncated. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.