sagemaker_create_notebook_instance_lifecycle_config: Creates a lifecycle configuration that you can associate with...

View source: R/sagemaker_operations.R

sagemaker_create_notebook_instance_lifecycle_configR Documentation

Creates a lifecycle configuration that you can associate with a notebook instance

Description

Creates a lifecycle configuration that you can associate with a notebook instance. A lifecycle configuration is a collection of shell scripts that run when you create or start a notebook instance.

See https://www.paws-r-sdk.com/docs/sagemaker_create_notebook_instance_lifecycle_config/ for full documentation.

Usage

sagemaker_create_notebook_instance_lifecycle_config(
  NotebookInstanceLifecycleConfigName,
  OnCreate = NULL,
  OnStart = NULL,
  Tags = NULL
)

Arguments

NotebookInstanceLifecycleConfigName

[required] The name of the lifecycle configuration.

OnCreate

A shell script that runs only once, when you create a notebook instance. The shell script must be a base64-encoded string.

OnStart

A shell script that runs every time you start a notebook instance, including when you create the notebook instance. The shell script must be a base64-encoded string.

Tags

An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.