View source: R/sagemaker_operations.R
| sagemaker_create_optimization_job | R Documentation |
Creates a job that optimizes a model for inference performance. To create the job, you provide the location of a source model, and you provide the settings for the optimization techniques that you want the job to apply. When the job completes successfully, SageMaker uploads the new optimized model to the output destination that you specify.
See https://www.paws-r-sdk.com/docs/sagemaker_create_optimization_job/ for full documentation.
sagemaker_create_optimization_job(
OptimizationJobName,
RoleArn,
ModelSource,
DeploymentInstanceType,
MaxInstanceCount = NULL,
OptimizationEnvironment = NULL,
OptimizationConfigs,
OutputConfig,
StoppingCondition,
Tags = NULL,
VpcConfig = NULL
)
OptimizationJobName |
[required] A custom name for the new optimization job. |
RoleArn |
[required] The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker AI to perform tasks on your behalf. During model optimization, Amazon SageMaker AI needs your permission to:
You grant permissions for all of these tasks to an IAM role. To pass this role to Amazon SageMaker AI, the caller of this API must have the |
ModelSource |
[required] The location of the source model to optimize with an optimization job. |
DeploymentInstanceType |
[required] The type of instance that hosts the optimized model that you create with the optimization job. |
MaxInstanceCount |
The maximum number of instances to use for the optimization job. |
OptimizationEnvironment |
The environment variables to set in the model container. |
OptimizationConfigs |
[required] Settings for each of the optimization techniques that the job applies. |
OutputConfig |
[required] Details for where to store the optimized model that you create with the optimization job. |
StoppingCondition |
[required] Specifies a limit to how long a job can run. When the job reaches the time limit, SageMaker ends the job. Use this API to cap costs. To stop a training job, SageMaker sends the algorithm the The training algorithms provided by SageMaker automatically save the intermediate results of a model training job when possible. This attempt to save artifacts is only a best effort case as model might not be in a state from which it can be saved. For example, if training has just started, the model might not be ready to save. When saved, this intermediate data is a valid model artifact. You can use it to create a model with The Neural Topic Model (NTM) currently does not support saving intermediate model artifacts. When training NTMs, make sure that the maximum runtime is sufficient for the training job to complete. |
Tags |
A list of key-value pairs associated with the optimization job. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide. |
VpcConfig |
A VPC in Amazon VPC that your optimized model has access to. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.