sagemaker_delete_processing_job: Deletes a processing job

View source: R/sagemaker_operations.R

sagemaker_delete_processing_jobR Documentation

Deletes a processing job

Description

Deletes a processing job. After Amazon SageMaker deletes a processing job, all of the metadata for the processing job is lost. You can delete only processing jobs that are in a terminal state (Stopped, Failed, or Completed). You cannot delete a job that is in the InProgress or Stopping state. After deleting the job, you can reuse its name to create another processing job.

See https://www.paws-r-sdk.com/docs/sagemaker_delete_processing_job/ for full documentation.

Usage

sagemaker_delete_processing_job(ProcessingJobName)

Arguments

ProcessingJobName

[required] The name of the processing job to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.