sagemaker_delete_training_job: Deletes a training job

View source: R/sagemaker_operations.R

sagemaker_delete_training_jobR Documentation

Deletes a training job

Description

Deletes a training job. After SageMaker deletes a training job, all of the metadata for the training job is lost. You can delete only training jobs that are in a terminal state (Stopped, Failed, or Completed) and don't retain an Available managed warm pool. You cannot delete a job that is in the InProgress or Stopping state. After deleting the job, you can reuse its name to create another training job.

See https://www.paws-r-sdk.com/docs/sagemaker_delete_training_job/ for full documentation.

Usage

sagemaker_delete_training_job(TrainingJobName)

Arguments

TrainingJobName

[required] The name of the training job to delete.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.