Learn R Programming

paws.machine.learning (version 0.7.0)

sagemaker_deregister_devices: Deregisters the specified devices

Description

Deregisters the specified devices. After you deregister a device, you will need to re-register the devices.

See https://www.paws-r-sdk.com/docs/sagemaker_deregister_devices/ for full documentation.

Usage

sagemaker_deregister_devices(DeviceFleetName, DeviceNames)

Arguments

DeviceFleetName

[required] The name of the fleet the devices belong to.

DeviceNames

[required] The unique IDs of the devices.