sagemaker_describe_ai_workload_config: Returns details of an AI workload configuration, including...

View source: R/sagemaker_operations.R

sagemaker_describe_ai_workload_configR Documentation

Returns details of an AI workload configuration, including the dataset configuration, benchmark tool settings, tags, and creation time

Description

Returns details of an AI workload configuration, including the dataset configuration, benchmark tool settings, tags, and creation time.

See https://www.paws-r-sdk.com/docs/sagemaker_describe_ai_workload_config/ for full documentation.

Usage

sagemaker_describe_ai_workload_config(AIWorkloadConfigName)

Arguments

AIWorkloadConfigName

[required] The name of the AI workload configuration to describe.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.