sagemaker_describe_cluster_event: Retrieves detailed information about a specific event for a...

View source: R/sagemaker_operations.R

sagemaker_describe_cluster_eventR Documentation

Retrieves detailed information about a specific event for a given HyperPod cluster

Description

Retrieves detailed information about a specific event for a given HyperPod cluster. This functionality is only supported when the NodeProvisioningMode is set to Continuous.

See https://www.paws-r-sdk.com/docs/sagemaker_describe_cluster_event/ for full documentation.

Usage

sagemaker_describe_cluster_event(EventId, ClusterName)

Arguments

EventId

[required] The unique identifier (UUID) of the event to describe. This ID can be obtained from the list_cluster_events operation.

ClusterName

[required] The name or Amazon Resource Name (ARN) of the HyperPod cluster associated with the event.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.