sagemaker_describe_cluster_node: Retrieves information of a node (also called a instance...

View source: R/sagemaker_operations.R

sagemaker_describe_cluster_nodeR Documentation

Retrieves information of a node (also called a instance interchangeably) of a SageMaker HyperPod cluster

Description

Retrieves information of a node (also called a instance interchangeably) of a SageMaker HyperPod cluster.

See https://www.paws-r-sdk.com/docs/sagemaker_describe_cluster_node/ for full documentation.

Usage

sagemaker_describe_cluster_node(
  ClusterName,
  NodeId = NULL,
  NodeLogicalId = NULL
)

Arguments

ClusterName

[required] The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster in which the node is.

NodeId

The ID of the SageMaker HyperPod cluster node.

NodeLogicalId

The logical identifier of the node to describe. You can specify either NodeLogicalId or InstanceId, but not both. NodeLogicalId can be used to describe nodes that are still being provisioned and don't yet have an InstanceId assigned.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.