sagemaker_describe_training_plan_extension_history: Retrieves the extension history for a specified training plan

View source: R/sagemaker_operations.R

sagemaker_describe_training_plan_extension_historyR Documentation

Retrieves the extension history for a specified training plan

Description

Retrieves the extension history for a specified training plan. The response includes details about each extension, such as the offering ID, start and end dates, status, payment status, and cost information.

See https://www.paws-r-sdk.com/docs/sagemaker_describe_training_plan_extension_history/ for full documentation.

Usage

sagemaker_describe_training_plan_extension_history(
  TrainingPlanArn,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

TrainingPlanArn

[required] The Amazon Resource Name (ARN); of the training plan to retrieve extension history for.

NextToken

A token to continue pagination if more results are available.

MaxResults

The maximum number of extensions to return in the response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.