sagemaker_detach_cluster_node_volume: Detaches your Amazon Elastic Block Store (Amazon EBS) volume...

View source: R/sagemaker_operations.R

sagemaker_detach_cluster_node_volumeR Documentation

Detaches your Amazon Elastic Block Store (Amazon EBS) volume from a node in your EKS orchestrated SageMaker HyperPod cluster

Description

Detaches your Amazon Elastic Block Store (Amazon EBS) volume from a node in your EKS orchestrated SageMaker HyperPod cluster.

See https://www.paws-r-sdk.com/docs/sagemaker_detach_cluster_node_volume/ for full documentation.

Usage

sagemaker_detach_cluster_node_volume(ClusterArn, NodeId, VolumeId)

Arguments

ClusterArn

[required] The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node. Your cluster must use EKS as the orchestration and be in the InService state.

NodeId

[required] The unique identifier of the cluster node from which you want to detach the volume.

VolumeId

[required] The unique identifier of your EBS volume that you want to detach. Your volume must be currently attached to the specified node.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.