sagemaker_extend_training_plan: Extends an existing training plan by purchasing an extension...

View source: R/sagemaker_operations.R

sagemaker_extend_training_planR Documentation

Extends an existing training plan by purchasing an extension offering

Description

Extends an existing training plan by purchasing an extension offering. This allows you to add additional compute capacity time to your training plan without creating a new plan or reconfiguring your workloads.

See https://www.paws-r-sdk.com/docs/sagemaker_extend_training_plan/ for full documentation.

Usage

sagemaker_extend_training_plan(TrainingPlanExtensionOfferingId)

Arguments

TrainingPlanExtensionOfferingId

[required] The unique identifier of the extension offering to purchase. You can retrieve this ID from the TrainingPlanExtensionOfferings in the response of the search_training_plan_offerings API.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.