sagemaker_list_ai_benchmark_jobs: Returns a list of AI benchmark jobs in your account

View source: R/sagemaker_operations.R

sagemaker_list_ai_benchmark_jobsR Documentation

Returns a list of AI benchmark jobs in your account

Description

Returns a list of AI benchmark jobs in your account. You can filter the results by name, status, and creation time, and sort the results. The response is paginated.

See https://www.paws-r-sdk.com/docs/sagemaker_list_ai_benchmark_jobs/ for full documentation.

Usage

sagemaker_list_ai_benchmark_jobs(
  MaxResults = NULL,
  NextToken = NULL,
  NameContains = NULL,
  StatusEquals = NULL,
  CreationTimeAfter = NULL,
  CreationTimeBefore = NULL,
  SortBy = NULL,
  SortOrder = NULL
)

Arguments

MaxResults

The maximum number of benchmark jobs to return in the response.

NextToken

If the previous call to list_ai_benchmark_jobs didn't return the full set of jobs, the call returns a token for getting the next set.

NameContains

A string in the job name. This filter returns only jobs whose name contains the specified string.

StatusEquals

A filter that returns only benchmark jobs with the specified status.

CreationTimeAfter

A filter that returns only jobs created after the specified time.

CreationTimeBefore

A filter that returns only jobs created before the specified time.

SortBy

The field to sort results by. The default is CreationTime.

SortOrder

The sort order for results. The default is Descending.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.