sagemaker_list_ai_workload_configs: Returns a list of AI workload configurations in your account

View source: R/sagemaker_operations.R

sagemaker_list_ai_workload_configsR Documentation

Returns a list of AI workload configurations in your account

Description

Returns a list of AI workload configurations in your account. You can filter the results by name and creation time, and sort the results. The response is paginated.

See https://www.paws-r-sdk.com/docs/sagemaker_list_ai_workload_configs/ for full documentation.

Usage

sagemaker_list_ai_workload_configs(
  MaxResults = NULL,
  NextToken = NULL,
  NameContains = NULL,
  CreationTimeAfter = NULL,
  CreationTimeBefore = NULL,
  SortBy = NULL,
  SortOrder = NULL
)

Arguments

MaxResults

The maximum number of AI workload configurations to return in the response.

NextToken

If the previous call to list_ai_workload_configs didn't return the full set of configurations, the call returns a token for getting the next set of configurations.

NameContains

A string in the configuration name. This filter returns only configurations whose name contains the specified string.

CreationTimeAfter

A filter that returns only configurations created after the specified time.

CreationTimeBefore

A filter that returns only configurations created before the specified time.

SortBy

The field to sort results by. The default is CreationTime.

SortOrder

The sort order for results. The default is Descending.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.