View source: R/sagemaker_operations.R
| sagemaker_list_cluster_events | R Documentation |
Retrieves a list of event summaries for a specified HyperPod cluster. The operation supports filtering, sorting, and pagination of results. This functionality is only supported when the NodeProvisioningMode is set to Continuous.
See https://www.paws-r-sdk.com/docs/sagemaker_list_cluster_events/ for full documentation.
sagemaker_list_cluster_events(
ClusterName,
InstanceGroupName = NULL,
NodeId = NULL,
EventTimeAfter = NULL,
EventTimeBefore = NULL,
SortBy = NULL,
SortOrder = NULL,
ResourceType = NULL,
MaxResults = NULL,
NextToken = NULL
)
ClusterName |
[required] The name or Amazon Resource Name (ARN) of the HyperPod cluster for which to list events. |
InstanceGroupName |
The name of the instance group to filter events. If specified, only events related to this instance group are returned. |
NodeId |
The EC2 instance ID to filter events. If specified, only events related to this instance are returned. |
EventTimeAfter |
The start of the time range for filtering events. Only events that occurred after this time are included in the results. |
EventTimeBefore |
The end of the time range for filtering events. Only events that occurred before this time are included in the results. |
SortBy |
The field to use for sorting the event list. Currently, the only supported value is |
SortOrder |
The order in which to sort the results. Valid values are |
ResourceType |
The type of resource for which to filter events. Valid values are |
MaxResults |
The maximum number of events to return in the response. Valid range is 1 to 100. |
NextToken |
A token to retrieve the next set of results. This token is obtained from the output of a previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.