View source: R/sagemaker_operations.R
| sagemaker_list_mlflow_apps | R Documentation |
Lists all MLflow Apps
See https://www.paws-r-sdk.com/docs/sagemaker_list_mlflow_apps/ for full documentation.
sagemaker_list_mlflow_apps(
CreatedAfter = NULL,
CreatedBefore = NULL,
Status = NULL,
MlflowVersion = NULL,
DefaultForDomainId = NULL,
AccountDefaultStatus = NULL,
SortBy = NULL,
SortOrder = NULL,
NextToken = NULL,
MaxResults = NULL
)
CreatedAfter |
Use the |
CreatedBefore |
Use the |
Status |
Filter for Mlflow apps with a specific creation status. |
MlflowVersion |
Filter for Mlflow Apps with the specified version. |
DefaultForDomainId |
Filter for MLflow Apps with the specified default SageMaker Domain ID. |
AccountDefaultStatus |
Filter for MLflow Apps with the specified |
SortBy |
Filter for MLflow Apps sorting by name, creation time, or creation status. |
SortOrder |
Change the order of the listed MLflow Apps. By default, MLflow Apps are listed in |
NextToken |
If the previous response was truncated, use this token in your next request to receive the next set of results. |
MaxResults |
The maximum number of MLflow Apps to list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.