sagemaker_list_pipeline_versions: Gets a list of all versions of the pipeline

View source: R/sagemaker_operations.R

sagemaker_list_pipeline_versionsR Documentation

Gets a list of all versions of the pipeline

Description

Gets a list of all versions of the pipeline.

See https://www.paws-r-sdk.com/docs/sagemaker_list_pipeline_versions/ for full documentation.

Usage

sagemaker_list_pipeline_versions(
  PipelineName,
  CreatedAfter = NULL,
  CreatedBefore = NULL,
  SortOrder = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

PipelineName

[required] The Amazon Resource Name (ARN) of the pipeline.

CreatedAfter

A filter that returns the pipeline versions that were created after a specified time.

CreatedBefore

A filter that returns the pipeline versions that were created before a specified time.

SortOrder

The sort order for the results.

NextToken

If the result of the previous list_pipeline_versions request was truncated, the response includes a NextToken. To retrieve the next set of pipeline versions, use this token in your next request.

MaxResults

The maximum number of pipeline versions to return in the response.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.