View source: R/sagemaker_operations.R
| sagemaker_list_ultra_servers_by_reserved_capacity | R Documentation |
Lists all UltraServers that are part of a specified reserved capacity.
See https://www.paws-r-sdk.com/docs/sagemaker_list_ultra_servers_by_reserved_capacity/ for full documentation.
sagemaker_list_ultra_servers_by_reserved_capacity(
ReservedCapacityArn,
MaxResults = NULL,
NextToken = NULL
)
ReservedCapacityArn |
[required] The ARN of the reserved capacity to list UltraServers for. |
MaxResults |
The maximum number of UltraServers to return in the response. The default value is 10. |
NextToken |
If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.