sagemaker_search_training_plan_offerings: Searches for available training plan offerings based on...

View source: R/sagemaker_operations.R

sagemaker_search_training_plan_offeringsR Documentation

Searches for available training plan offerings based on specified criteria

Description

Searches for available training plan offerings based on specified criteria.

See https://www.paws-r-sdk.com/docs/sagemaker_search_training_plan_offerings/ for full documentation.

Usage

sagemaker_search_training_plan_offerings(
  InstanceType = NULL,
  InstanceCount = NULL,
  UltraServerType = NULL,
  UltraServerCount = NULL,
  StartTimeAfter = NULL,
  EndTimeBefore = NULL,
  DurationHours = NULL,
  TargetResources = NULL,
  TrainingPlanArn = NULL
)

Arguments

InstanceType

The type of instance you want to search for in the available training plan offerings. This field allows you to filter the search results based on the specific compute resources you require for your SageMaker training jobs or SageMaker HyperPod clusters. When searching for training plan offerings, specifying the instance type helps you find Reserved Instances that match your computational needs.

InstanceCount

The number of instances you want to reserve in the training plan offerings. This allows you to specify the quantity of compute resources needed for your SageMaker training jobs or SageMaker HyperPod clusters, helping you find reserved capacity offerings that match your requirements.

UltraServerType

The type of UltraServer to search for, such as ml.u-p6e-gb200x72.

UltraServerCount

The number of UltraServers to search for.

StartTimeAfter

A filter to search for training plan offerings with a start time after a specified date.

EndTimeBefore

A filter to search for reserved capacity offerings with an end time before a specified date.

DurationHours

The desired duration in hours for the training plan offerings.

TargetResources

The target resources (e.g., SageMaker Training Jobs, SageMaker HyperPod, SageMaker Endpoints, Studio apps) to search for in the offerings.

Training plans are specific to their target resource.

  • A training plan designed for SageMaker training jobs can only be used to schedule and run training jobs.

  • A training plan for HyperPod clusters can be used exclusively to provide compute resources to a cluster's instance group.

  • A training plan for SageMaker endpoints can be used exclusively to provide compute resources to SageMaker endpoints for model deployment.

  • A training plan for Studio apps can be used to launch JupyterLab and Code Editor apps on reserved training plan capacity.

TrainingPlanArn

The Amazon Resource Name (ARN); of an existing training plan to search for extension offerings. When specified, the API returns extension offerings that can be used to extend the specified training plan.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.