sagemaker_start_cluster_health_check: Start deep health checks for a SageMaker HyperPod cluster

View source: R/sagemaker_operations.R

sagemaker_start_cluster_health_checkR Documentation

Start deep health checks for a SageMaker HyperPod cluster

Description

Start deep health checks for a SageMaker HyperPod cluster. You can use describe_cluster_node API to track progress of the deep health checks. The unhealthy nodes will be automatically rebooted or replaced. Please see Resilience-related Kubernetes labels by SageMaker HyperPod for details.

See https://www.paws-r-sdk.com/docs/sagemaker_start_cluster_health_check/ for full documentation.

Usage

sagemaker_start_cluster_health_check(
  ClusterName,
  DeepHealthCheckConfigurations
)

Arguments

ClusterName

[required] The string name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster.

DeepHealthCheckConfigurations

[required] A list of configurations containing instance group names, EC2 instance IDs, and deep health checks to perform.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.