sagemaker_start_session: Initiates a remote connection session between a local...

View source: R/sagemaker_operations.R

sagemaker_start_sessionR Documentation

Initiates a remote connection session between a local integrated development environments (IDEs) and a remote SageMaker space

Description

Initiates a remote connection session between a local integrated development environments (IDEs) and a remote SageMaker space.

See https://www.paws-r-sdk.com/docs/sagemaker_start_session/ for full documentation.

Usage

sagemaker_start_session(ResourceIdentifier)

Arguments

ResourceIdentifier

[required] The Amazon Resource Name (ARN) of the resource to which the remote connection will be established. For example, this identifies the specific ARN space application you want to connect to from your local IDE.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.