sagemaker_update_cluster: Updates a SageMaker HyperPod cluster

View source: R/sagemaker_operations.R

sagemaker_update_clusterR Documentation

Updates a SageMaker HyperPod cluster

Description

Updates a SageMaker HyperPod cluster.

See https://www.paws-r-sdk.com/docs/sagemaker_update_cluster/ for full documentation.

Usage

sagemaker_update_cluster(
  ClusterName,
  InstanceGroups = NULL,
  RestrictedInstanceGroups = NULL,
  RestrictedInstanceGroupsConfig = NULL,
  TieredStorageConfig = NULL,
  NodeRecovery = NULL,
  InstanceGroupsToDelete = NULL,
  NodeProvisioningMode = NULL,
  ClusterRole = NULL,
  AutoScaling = NULL,
  Orchestrator = NULL
)

Arguments

ClusterName

[required] Specify the name of the SageMaker HyperPod cluster you want to update.

InstanceGroups

Specify the instance groups to update.

RestrictedInstanceGroups

The specialized instance groups for training models like Amazon Nova to be created in the SageMaker HyperPod cluster.

RestrictedInstanceGroupsConfig

The configuration for the restricted instance groups (RIG) in the SageMaker HyperPod cluster.

TieredStorageConfig

Updates the configuration for managed tier checkpointing on the HyperPod cluster. For example, you can enable or disable the feature and modify the percentage of cluster memory allocated for checkpoint storage.

NodeRecovery

The node recovery mode to be applied to the SageMaker HyperPod cluster.

InstanceGroupsToDelete

Specify the names of the instance groups to delete. Use a single ⁠,⁠ as the separator between multiple names.

NodeProvisioningMode

Determines how instance provisioning is handled during cluster operations. In Continuous mode, the cluster provisions available instances incrementally and retries until the target count is reached. The cluster becomes operational once cluster-level resources are ready. Use CurrentCount and TargetCount in describe_cluster to track provisioning progress.

ClusterRole

The Amazon Resource Name (ARN) of the IAM role that HyperPod assumes for cluster autoscaling operations. Cannot be updated while autoscaling is enabled.

AutoScaling

Updates the autoscaling configuration for the cluster. Use to enable or disable automatic node scaling.

Orchestrator

The type of orchestrator used for the SageMaker HyperPod cluster.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.