sagemaker_update_domain: Updates the default settings for new user profiles in the...

View source: R/sagemaker_operations.R

sagemaker_update_domainR Documentation

Updates the default settings for new user profiles in the domain

Description

Updates the default settings for new user profiles in the domain.

See https://www.paws-r-sdk.com/docs/sagemaker_update_domain/ for full documentation.

Usage

sagemaker_update_domain(
  DomainId,
  DefaultUserSettings = NULL,
  DomainSettingsForUpdate = NULL,
  AppSecurityGroupManagement = NULL,
  DefaultSpaceSettings = NULL,
  SubnetIds = NULL,
  AppNetworkAccessType = NULL,
  TagPropagation = NULL,
  HomeEfsFileSystemCreation = NULL,
  VpcId = NULL
)

Arguments

DomainId

[required] The ID of the domain to be updated.

DefaultUserSettings

A collection of settings.

DomainSettingsForUpdate

A collection of DomainSettings configuration values to update.

AppSecurityGroupManagement

The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided. If setting up the domain for use with RStudio, this value must be set to Service.

DefaultSpaceSettings

The default settings for shared spaces that users create in the domain.

SubnetIds

The VPC subnets that Studio uses for communication.

If removing subnets, ensure there are no apps in the InService, Pending, or Deleting state.

AppNetworkAccessType

Specifies the VPC used for non-EFS traffic.

  • PublicInternetOnly - Non-EFS traffic is through a VPC managed by Amazon SageMaker AI, which allows direct internet access.

  • VpcOnly - All Studio traffic is through the specified VPC and subnets.

This configuration can only be modified if there are no apps in the InService, Pending, or Deleting state. The configuration cannot be updated if DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is already set or DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided as part of the same request.

TagPropagation

Indicates whether custom tag propagation is supported for the domain. Defaults to DISABLED.

HomeEfsFileSystemCreation

Indicates whether to create a home EFS file system for the domain. You can change from Disabled to Enabled to provision EFS on demand, but you cannot change from Enabled to Disabled.

VpcId

The identifier for the VPC used by the domain for network communication. Use this field only when adding VPC configuration to a SageMaker AI domain used in Amazon SageMaker Unified Studio that was created without VPC settings. SageMaker AI doesn't automatically apply VPC updates to existing applications. Stop and restart your applications to apply the changes.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.