sagemaker_update_feature_group: Updates the feature group by either adding features or...

View source: R/sagemaker_operations.R

sagemaker_update_feature_groupR Documentation

Updates the feature group by either adding features or updating the online store configuration

Description

Updates the feature group by either adding features or updating the online store configuration. Use one of the following request parameters at a time while using the update_feature_group API.

See https://www.paws-r-sdk.com/docs/sagemaker_update_feature_group/ for full documentation.

Usage

sagemaker_update_feature_group(
  FeatureGroupName,
  FeatureAdditions = NULL,
  OnlineStoreConfig = NULL,
  ThroughputConfig = NULL
)

Arguments

FeatureGroupName

[required] The name or Amazon Resource Name (ARN) of the feature group that you're updating.

FeatureAdditions

Updates the feature group. Updating a feature group is an asynchronous operation. When you get an HTTP 200 response, you've made a valid request. It takes some time after you've made a valid request for Feature Store to update the feature group.

OnlineStoreConfig

Updates the feature group online store configuration.

ThroughputConfig

Used to set feature group throughput configuration. There are two modes: ON_DEMAND and PROVISIONED. With on-demand mode, you are charged for data reads and writes that your application performs on your feature group. You do not need to specify read and write throughput because Feature Store accommodates your workloads as they ramp up and down. You can switch a feature group to on-demand only once in a 24 hour period. With provisioned throughput mode, you specify the read and write capacity per second that you expect your application to require, and you are billed based on those limits. Exceeding provisioned throughput will result in your requests being throttled.

Note: PROVISIONED throughput mode is supported only for feature groups that are offline-only, or use the Standard tier online store.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.