sagemaker_update_hub_content: Updates SageMaker hub content (either a Model or Notebook...

View source: R/sagemaker_operations.R

sagemaker_update_hub_contentR Documentation

Updates SageMaker hub content (either a Model or Notebook resource)

Description

Updates SageMaker hub content (either a Model or Notebook resource).

See https://www.paws-r-sdk.com/docs/sagemaker_update_hub_content/ for full documentation.

Usage

sagemaker_update_hub_content(
  HubName,
  HubContentName,
  HubContentType,
  HubContentVersion,
  HubContentDisplayName = NULL,
  HubContentDescription = NULL,
  HubContentMarkdown = NULL,
  HubContentSearchKeywords = NULL,
  SupportStatus = NULL
)

Arguments

HubName

[required] The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead.

HubContentName

[required] The name of the hub content resource that you want to update.

HubContentType

[required] The content type of the resource that you want to update. Only specify a Model or Notebook resource for this API. To update a ModelReference, use the update_hub_content_reference API instead.

HubContentVersion

[required] The hub content version that you want to update. For example, if you have two versions of a resource in your hub, you can update the second version.

HubContentDisplayName

The display name of the hub content.

HubContentDescription

The description of the hub content.

HubContentMarkdown

A string that provides a description of the hub content. This string can include links, tables, and standard markdown formatting.

HubContentSearchKeywords

The searchable keywords of the hub content.

SupportStatus

Indicates the current status of the hub content resource.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.