sagemaker_update_hub_content_reference: Updates the contents of a SageMaker hub for a ModelReference...

View source: R/sagemaker_operations.R

sagemaker_update_hub_content_referenceR Documentation

Updates the contents of a SageMaker hub for a ModelReference resource

Description

Updates the contents of a SageMaker hub for a ModelReference resource. A ModelReference allows you to access public SageMaker JumpStart models from within your private hub.

See https://www.paws-r-sdk.com/docs/sagemaker_update_hub_content_reference/ for full documentation.

Usage

sagemaker_update_hub_content_reference(
  HubName,
  HubContentName,
  HubContentType,
  MinVersion = NULL
)

Arguments

HubName

[required] The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead.

HubContentName

[required] The name of the hub content resource that you want to update.

HubContentType

[required] The content type of the resource that you want to update. Only specify a ModelReference resource for this API. To update a Model or Notebook resource, use the update_hub_content API instead.

MinVersion

The minimum hub content version of the referenced model that you want to use. The minimum version must be older than the latest available version of the referenced model. To support all versions of a model, set the value to ⁠1.0.0⁠.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.