sagemaker_update_inference_component: Updates an inference component

View source: R/sagemaker_operations.R

sagemaker_update_inference_componentR Documentation

Updates an inference component

Description

Updates an inference component.

See https://www.paws-r-sdk.com/docs/sagemaker_update_inference_component/ for full documentation.

Usage

sagemaker_update_inference_component(
  InferenceComponentName,
  Specification = NULL,
  Specifications = NULL,
  RuntimeConfig = NULL,
  DeploymentConfig = NULL
)

Arguments

InferenceComponentName

[required] The name of the inference component.

Specification

Details about the resources to deploy with this inference component, including the model, container, and compute resources.

Specifications

A list of specification objects for the inference component, one per instance type. Use this parameter when you want to specify different model or resource configurations for the inference component on each instance type. You can use either this parameter or the singular Specification parameter, but not both.

RuntimeConfig

Runtime settings for a model that is deployed with an inference component.

DeploymentConfig

The deployment configuration for the inference component. The configuration contains the desired deployment strategy and rollback settings.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.