sagemaker_update_mlflow_app: Updates an MLflow App

View source: R/sagemaker_operations.R

sagemaker_update_mlflow_appR Documentation

Updates an MLflow App

Description

Updates an MLflow App.

See https://www.paws-r-sdk.com/docs/sagemaker_update_mlflow_app/ for full documentation.

Usage

sagemaker_update_mlflow_app(
  Arn,
  Name = NULL,
  ArtifactStoreUri = NULL,
  ModelRegistrationMode = NULL,
  WeeklyMaintenanceWindowStart = NULL,
  DefaultDomainIdList = NULL,
  AccountDefaultStatus = NULL
)

Arguments

Arn

[required] The ARN of the MLflow App to update.

Name

The name of the MLflow App to update.

ArtifactStoreUri

The new S3 URI for the general purpose bucket to use as the artifact store for the MLflow App.

ModelRegistrationMode

Whether to enable or disable automatic registration of new MLflow models to the SageMaker Model Registry. To enable automatic model registration, set this value to AutoModelRegistrationEnabled. To disable automatic model registration, set this value to AutoModelRegistrationDisabled. If not specified, AutomaticModelRegistration defaults to AutoModelRegistrationEnabled

WeeklyMaintenanceWindowStart

The new weekly maintenance window start day and time to update. The maintenance window day and time should be in Coordinated Universal Time (UTC) 24-hour standard time. For example: TUE:03:30.

DefaultDomainIdList

List of SageMaker Domain IDs for which this MLflow App is the default.

AccountDefaultStatus

Indicates whether this this MLflow App is the default for the account.


paws.machine.learning documentation built on May 31, 2026, 1:07 a.m.