Use to check if a device is registered with SageMaker Edge Manager.
See https://www.paws-r-sdk.com/docs/sagemakeredgemanager_get_device_registration/ for full documentation.
sagemakeredgemanager_get_device_registration(DeviceName, DeviceFleetName)[required] The unique name of the device you want to get the registration status from.
[required] The name of the fleet that the device belongs to.