Use to get the current status of devices registered on SageMaker Edge Manager.
See https://www.paws-r-sdk.com/docs/sagemakeredgemanager_send_heartbeat/ for full documentation.
sagemakeredgemanager_send_heartbeat(
AgentMetrics = NULL,
Models = NULL,
AgentVersion,
DeviceName,
DeviceFleetName,
DeploymentResult = NULL
)For internal use. Returns a list of SageMaker Edge Manager agent operating metrics.
Returns a list of models deployed on the the device.
[required] Returns the version of the agent.
[required] The unique name of the device.
[required] The name of the fleet that the device belongs to.
Returns the result of a deployment on the device.