View source: R/textract_operations.R
| textract_analyze_expense | R Documentation |
analyze_expense synchronously analyzes an input document for financially related relationships between text.
See https://www.paws-r-sdk.com/docs/textract_analyze_expense/ for full documentation.
textract_analyze_expense(Document)
Document |
[required] The input document, either as bytes or as an S3 object. You pass image bytes to an Amazon Textract API operation by using the You pass images stored in an S3 bucket to an Amazon Textract API operation by using the The AWS Region for the S3 bucket that contains the S3 object must match the AWS Region that you use for Amazon Textract operations. If you use the AWS CLI to call Amazon Textract operations, passing image bytes using the Bytes property isn't supported. You must first upload the document to an Amazon S3 bucket, and then call the operation using the S3Object property. For Amazon Textract to process an S3 object, the user must have permission to access the S3 object. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.