View source: R/textract_operations.R
| textract_start_lending_analysis | R Documentation |
Starts the classification and analysis of an input document. start_lending_analysis initiates the classification and analysis of a packet of lending documents. start_lending_analysis operates on a document file located in an Amazon S3 bucket.
See https://www.paws-r-sdk.com/docs/textract_start_lending_analysis/ for full documentation.
textract_start_lending_analysis(
DocumentLocation,
ClientRequestToken = NULL,
JobTag = NULL,
NotificationChannel = NULL,
OutputConfig = NULL,
KMSKeyId = NULL
)
DocumentLocation |
[required] The Amazon S3 bucket that contains the document to be processed. It's used by asynchronous operations. The input document can be an image file in JPEG or PNG format. It can also be a file in PDF format. |
ClientRequestToken |
The idempotent token that you use to identify the start request. If you use the same token with multiple |
JobTag |
An identifier that you specify to be included in the completion notification published to the Amazon SNS topic. For example, you can use |
NotificationChannel |
The Amazon Simple Notification Service (Amazon SNS) topic to which Amazon Textract publishes the completion status of an asynchronous document operation. |
OutputConfig |
Sets whether or not your output will go to a user created bucket. Used to set the name of the bucket, and the prefix on the output file.
Decryption of Customer Content is necessary for processing of the documents by Amazon Textract. If your account is opted out under an AI services opt out policy then all unencrypted Customer Content is immediately and permanently deleted after the Customer Content has been processed by the service. No copy of of the output is retained by Amazon Textract. For information about how to opt out, see Managing AI services opt-out policy. For more information on data privacy, see the Data Privacy FAQ. |
KMSKeyId |
The KMS key used to encrypt the inference results. This can be in either Key ID or Key Alias format. When a KMS key is provided, the KMS key will be used for server-side encryption of the objects in the customer bucket. When this parameter is not enabled, the result will be encrypted server side, using SSE-S3. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.