View source: R/transcribeservice_operations.R
| transcribeservice_start_call_analytics_job | R Documentation |
Transcribes the audio from a customer service call and applies any additional Request Parameters you choose to include in your request.
See https://www.paws-r-sdk.com/docs/transcribeservice_start_call_analytics_job/ for full documentation.
transcribeservice_start_call_analytics_job(
CallAnalyticsJobName,
Media,
OutputLocation = NULL,
OutputEncryptionKMSKeyId = NULL,
DataAccessRoleArn = NULL,
Settings = NULL,
Tags = NULL,
ChannelDefinitions = NULL
)
CallAnalyticsJobName |
[required] A unique name, chosen by you, for your Call Analytics job. This name is case sensitive, cannot contain spaces, and must be unique within an Amazon Web Services account. If you try to create a new job with the same name as an existing job, you get a |
Media |
[required] Describes the Amazon S3 location of the media file you want to use in your Call Analytics request. |
OutputLocation |
The Amazon S3 location where you want your Call Analytics transcription output stored. You can use any of the following formats to specify the output location:
Unless you specify a file name (option 3), the name of your output file has a default value that matches the name you specified for your transcription job using the You can specify a KMS key to encrypt your output using the If you do not specify |
OutputEncryptionKMSKeyId |
The Amazon Resource Name (ARN) of a KMS key that you want to use to encrypt your Call Analytics output. KMS key ARNs have the format If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3). Note that the role making the request and the role specified in the |
DataAccessRoleArn |
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files. If the role that you specify doesn’t have the appropriate permissions to access the specified Amazon S3 location, your request fails. IAM role ARNs have the format For more information, see IAM ARNs. |
Settings |
Specify additional optional settings in your request, including content redaction; allows you to apply custom language models, vocabulary filters, and custom vocabularies to your Call Analytics job. |
Tags |
Adds one or more custom tags, each in the form of a key:value pair, to a new call analytics job at the time you start this new job. To learn more about using tags with Amazon Transcribe, refer to Tagging resources. |
ChannelDefinitions |
Makes it possible to specify which speaker is on which channel. For example, if your agent is the first participant to speak, you would set |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.