View source: R/transcribeservice_operations.R
| transcribeservice_start_medical_scribe_job | R Documentation |
Transcribes patient-clinician conversations and generates clinical notes.
See https://www.paws-r-sdk.com/docs/transcribeservice_start_medical_scribe_job/ for full documentation.
transcribeservice_start_medical_scribe_job(
MedicalScribeJobName,
Media,
OutputBucketName,
OutputEncryptionKMSKeyId = NULL,
KMSEncryptionContext = NULL,
DataAccessRoleArn,
Settings,
ChannelDefinitions = NULL,
Tags = NULL,
MedicalScribeContext = NULL
)
MedicalScribeJobName |
[required] A unique name, chosen by you, for your Medical Scribe job. This name is case sensitive, cannot contain spaces, and must be unique within an Amazon Web Services account. If you try to create a new job with the same name as an existing job, you get a |
Media |
[required] Describes the Amazon S3 location of the media file you want to use in your request. For information on supported media formats, refer to the |
OutputBucketName |
[required] The name of the Amazon S3 bucket where you want your Medical Scribe output stored. Do not include the Note that the role specified in the |
OutputEncryptionKMSKeyId |
The Amazon Resource Name (ARN) of a KMS key that you want to use to encrypt your Medical Scribe output. KMS key ARNs have the format If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3). Note that the role making the request and the role specified in the |
KMSEncryptionContext |
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data. For more information, see KMS encryption context and Asymmetric keys in KMS. |
DataAccessRoleArn |
[required] The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files, write to the output bucket, and use your KMS key if supplied. If the role that you specify doesn’t have the appropriate permissions your request fails. IAM role ARNs have the format For more information, see IAM ARNs. |
Settings |
[required] Makes it possible to control how your Medical Scribe job is processed using a |
ChannelDefinitions |
Makes it possible to specify which speaker is on which channel. For example, if the clinician is the first participant to speak, you would set |
Tags |
Adds one or more custom tags, each in the form of a key:value pair, to the Medical Scribe job. To learn more about using tags with Amazon Transcribe, refer to Tagging resources. |
MedicalScribeContext |
The |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.