View source: R/transcribeservice_operations.R
| transcribeservice_start_transcription_job | R Documentation |
Transcribes the audio from a media file and applies any additional Request Parameters you choose to include in your request.
See https://www.paws-r-sdk.com/docs/transcribeservice_start_transcription_job/ for full documentation.
transcribeservice_start_transcription_job(
TranscriptionJobName,
LanguageCode = NULL,
MediaSampleRateHertz = NULL,
MediaFormat = NULL,
Media,
OutputBucketName = NULL,
OutputKey = NULL,
OutputEncryptionKMSKeyId = NULL,
KMSEncryptionContext = NULL,
Settings = NULL,
ModelSettings = NULL,
JobExecutionSettings = NULL,
ContentRedaction = NULL,
IdentifyLanguage = NULL,
IdentifyMultipleLanguages = NULL,
LanguageOptions = NULL,
Subtitles = NULL,
Tags = NULL,
LanguageIdSettings = NULL,
ToxicityDetection = NULL
)
TranscriptionJobName |
[required] A unique name, chosen by you, for your transcription job. The name that you specify is also used as the default name of your transcription output file. If you want to specify a different name for your transcription output, use the This name is case sensitive, cannot contain spaces, and must be unique within an Amazon Web Services account. If you try to create a new job with the same name as an existing job, you get a |
LanguageCode |
The language code that represents the language spoken in the input media file. If you're unsure of the language spoken in your media file, consider using Note that you must include one of For a list of supported languages and their associated language codes, refer to the Supported languages table. To transcribe speech in Modern Standard Arabic ( |
MediaSampleRateHertz |
The sample rate, in hertz, of the audio track in your input media file. If you do not specify the media sample rate, Amazon Transcribe determines it for you. If you specify the sample rate, it must match the rate detected by Amazon Transcribe. If there's a mismatch between the value that you specify and the value detected, your job fails. In most cases, you can omit |
MediaFormat |
Specify the format of your input media file. |
Media |
[required] Describes the Amazon S3 location of the media file you want to use in your request. |
OutputBucketName |
The name of the Amazon S3 bucket where you want your transcription output stored. Do not include the If you want your output to go to a sub-folder of this bucket, specify it using the For example, if you want your output stored in Note that Amazon Transcribe must have permission to use the specified location. You can change Amazon S3 permissions using the Amazon Web Services Management Console. See also Permissions Required for IAM User Roles. If you do not specify |
OutputKey |
Use in combination with Here are some examples of how you can use
If you specify the name of an Amazon S3 bucket sub-folder that doesn't exist, one is created for you. |
OutputEncryptionKMSKeyId |
The Amazon Resource Name (ARN) of a KMS key that you want to use to encrypt your transcription output. KMS key ARNs have the format If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3). Note that the role making the request and the role specified in the |
KMSEncryptionContext |
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data. For more information, see KMS encryption context and Asymmetric keys in KMS. |
Settings |
Specify additional optional settings in your request, including channel identification, alternative transcriptions, speaker partitioning. You can use that to apply custom vocabularies and vocabulary filters. If you want to include a custom vocabulary or a custom vocabulary filter (or both) with your request but do not want to use automatic language identification, use If you're using automatic language identification with your request and want to include a custom language model, a custom vocabulary, or a custom vocabulary filter, use instead the “ parameter with the |
ModelSettings |
Specify the custom language model you want to include with your transcription job. If you include For more information, see Custom language models. |
JobExecutionSettings |
Makes it possible to control how your transcription job is processed. Currently, the only If you include |
ContentRedaction |
Makes it possible to redact or flag specified personally identifiable information (PII) in your transcript. If you use |
IdentifyLanguage |
Enables automatic language identification in your transcription job request. Use this parameter if your media file contains only one language. If your media contains multiple languages, use If you include If you want to apply a custom language model, a custom vocabulary, or a custom vocabulary filter to your automatic language identification request, include Note that you must include one of |
IdentifyMultipleLanguages |
Enables automatic multi-language identification in your transcription job request. Use this parameter if your media file contains more than one language. If your media contains only one language, use If you include If you want to apply a custom vocabulary or a custom vocabulary filter to your automatic language identification request, include Note that you must include one of |
LanguageOptions |
You can specify two or more language codes that represent the languages you think may be present in your media. Including more than five is not recommended. If you're unsure what languages are present, do not include this parameter. If you include For more information, refer to Supported languages. To transcribe speech in Modern Standard Arabic ( |
Subtitles |
Produces subtitle files for your input media. You can specify WebVTT (.vtt) and SubRip (.srt) formats. |
Tags |
Adds one or more custom tags, each in the form of a key:value pair, to a new transcription job at the time you start this new job. To learn more about using tags with Amazon Transcribe, refer to Tagging resources. |
LanguageIdSettings |
If using automatic language identification in your request and you want to apply a custom language model, a custom vocabulary, or a custom vocabulary filter, include
It's recommended that you include If you want to include a custom language model with your request but do not want to use automatic language identification, use instead the |
ToxicityDetection |
Enables toxic speech detection in your transcript. If you include For information on the types of toxic speech Amazon Transcribe can detect, see Detecting toxic speech. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.