View source: R/bedrock_operations.R
| bedrock_cancel_automated_reasoning_policy_build_workflow | R Documentation |
Cancels a running Automated Reasoning policy build workflow. This stops the policy generation process and prevents further processing of the source documents.
See https://www.paws-r-sdk.com/docs/bedrock_cancel_automated_reasoning_policy_build_workflow/ for full documentation.
bedrock_cancel_automated_reasoning_policy_build_workflow(
policyArn,
buildWorkflowId
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to cancel. |
buildWorkflowId |
[required] The unique identifier of the build workflow to cancel. You can get this ID from the StartAutomatedReasoningPolicyBuildWorkflow response or by listing build workflows. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.