View source: R/bedrock_operations.R
| bedrock_create_custom_model | R Documentation |
Creates a new custom model in Amazon Bedrock. After the model is active, you can use it for inference.
See https://www.paws-r-sdk.com/docs/bedrock_create_custom_model/ for full documentation.
bedrock_create_custom_model(
modelName,
modelSourceConfig,
modelKmsKeyArn = NULL,
roleArn = NULL,
modelTags = NULL,
clientRequestToken = NULL
)
modelName |
[required] A unique name for the custom model. |
modelSourceConfig |
[required] The data source for the model. The Amazon S3 URI in the model source must be for the Amazon-managed Amazon S3 bucket containing your model artifacts. |
modelKmsKeyArn |
The Amazon Resource Name (ARN) of the customer managed KMS key to encrypt the custom model. If you don't provide a KMS key, Amazon Bedrock uses an Amazon Web Services-managed KMS key to encrypt the model. If you provide a customer managed KMS key, your Amazon Bedrock service role must have permissions to use it. For more information see Encryption of imported models. |
roleArn |
The Amazon Resource Name (ARN) of an IAM service role that Amazon Bedrock assumes to perform tasks on your behalf. This role must have permissions to access the Amazon S3 bucket containing your model artifacts and the KMS key (if specified). For more information, see Setting up an IAM service role for importing models in the Amazon Bedrock User Guide. |
modelTags |
A list of key-value pairs to associate with the custom model resource. You can use these tags to organize and identify your resources. For more information, see Tagging resources in the Amazon Bedrock User Guide. |
clientRequestToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.