View source: R/bedrock_operations.R
| bedrock_create_foundation_model_agreement | R Documentation |
Request a model access agreement for the specified model.
See https://www.paws-r-sdk.com/docs/bedrock_create_foundation_model_agreement/ for full documentation.
bedrock_create_foundation_model_agreement(offerToken, modelId)
offerToken |
[required] An offer token encapsulates the information for an offer. |
modelId |
[required] Model Id of the model for the access request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.