View source: R/bedrock_operations.R
| bedrock_delete_automated_reasoning_policy_test_case | R Documentation |
Deletes an Automated Reasoning policy test. This operation is idempotent; if you delete a test more than once, each call succeeds.
See https://www.paws-r-sdk.com/docs/bedrock_delete_automated_reasoning_policy_test_case/ for full documentation.
bedrock_delete_automated_reasoning_policy_test_case(
policyArn,
testCaseId,
lastUpdatedAt
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test. |
testCaseId |
[required] The unique identifier of the test to delete. |
lastUpdatedAt |
[required] The timestamp when the test was last updated. This is used as a concurrency token to prevent conflicting modifications. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.