Deregisters an endpoint for a model from Amazon Bedrock Marketplace. This operation removes the endpoint's association with Amazon Bedrock but does not delete the underlying Amazon SageMaker endpoint.
See https://www.paws-r-sdk.com/docs/bedrock_deregister_marketplace_model_endpoint/ for full documentation.
bedrock_deregister_marketplace_model_endpoint(endpointArn)[required] The Amazon Resource Name (ARN) of the endpoint you want to deregister.