View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy | R Documentation |
Retrieves details about an Automated Reasoning policy or policy version. Returns information including the policy definition, metadata, and timestamps.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy/ for full documentation.
bedrock_get_automated_reasoning_policy(policyArn)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to retrieve. Can be either the unversioned ARN for the draft policy or an ARN for a specific policy version. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.