View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy_annotations | R Documentation |
Retrieves the current annotations for an Automated Reasoning policy build workflow. Annotations contain corrections to the rules, variables and types to be applied to the policy.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_annotations/ for full documentation.
bedrock_get_automated_reasoning_policy_annotations(policyArn, buildWorkflowId)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose annotations you want to retrieve. |
buildWorkflowId |
[required] The unique identifier of the build workflow whose annotations you want to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.