View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy_build_workflow | R Documentation |
Retrieves detailed information about an Automated Reasoning policy build workflow, including its status, configuration, and metadata.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_build_workflow/ for full documentation.
bedrock_get_automated_reasoning_policy_build_workflow(
policyArn,
buildWorkflowId
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose build workflow you want to retrieve. |
buildWorkflowId |
[required] The unique identifier of the build workflow to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.