View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy_next_scenario | R Documentation |
Retrieves the next test scenario for validating an Automated Reasoning policy. This is used during the interactive policy refinement process to test policy behavior.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_next_scenario/ for full documentation.
bedrock_get_automated_reasoning_policy_next_scenario(
policyArn,
buildWorkflowId
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy for which you want to get the next test scenario. |
buildWorkflowId |
[required] The unique identifier of the build workflow associated with the test scenarios. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.