View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy_test_case | R Documentation |
Retrieves details about a specific Automated Reasoning policy test.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_test_case/ for full documentation.
bedrock_get_automated_reasoning_policy_test_case(policyArn, testCaseId)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy that contains the test. |
testCaseId |
[required] The unique identifier of the test to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.