View source: R/bedrock_operations.R
| bedrock_get_automated_reasoning_policy_test_result | R Documentation |
Retrieves the test result for a specific Automated Reasoning policy test. Returns detailed validation findings and execution status.
See https://www.paws-r-sdk.com/docs/bedrock_get_automated_reasoning_policy_test_result/ for full documentation.
bedrock_get_automated_reasoning_policy_test_result(
policyArn,
buildWorkflowId,
testCaseId
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy. |
buildWorkflowId |
[required] The build workflow identifier. The build workflow must display a |
testCaseId |
[required] The unique identifier of the test for which to retrieve results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.