View source: R/bedrock_operations.R
| bedrock_get_resource_policy | R Documentation |
Gets the resource policy document for a Bedrock resource
See https://www.paws-r-sdk.com/docs/bedrock_get_resource_policy/ for full documentation.
bedrock_get_resource_policy(resourceArn)
resourceArn |
[required] The ARN of the Bedrock resource to which this resource policy applies. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.