View source: R/bedrock_operations.R
| bedrock_list_automated_reasoning_policy_test_results | R Documentation |
Lists test results for an Automated Reasoning policy, showing how the policy performed against various test scenarios and validation checks.
See https://www.paws-r-sdk.com/docs/bedrock_list_automated_reasoning_policy_test_results/ for full documentation.
bedrock_list_automated_reasoning_policy_test_results(
policyArn,
buildWorkflowId,
nextToken = NULL,
maxResults = NULL
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy whose test results you want to list. |
buildWorkflowId |
[required] The unique identifier of the build workflow whose test results you want to list. |
nextToken |
A pagination token from a previous request to continue listing test results from where the previous request left off. |
maxResults |
The maximum number of test results to return in a single response. Valid range is 1-100. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.