View source: R/bedrock_operations.R
| bedrock_start_automated_reasoning_policy_test_workflow | R Documentation |
Initiates a test workflow to validate Automated Reasoning policy tests. The workflow executes the specified tests against the policy and generates validation results.
See https://www.paws-r-sdk.com/docs/bedrock_start_automated_reasoning_policy_test_workflow/ for full documentation.
bedrock_start_automated_reasoning_policy_test_workflow(
policyArn,
buildWorkflowId,
testCaseIds = NULL,
clientRequestToken = NULL
)
policyArn |
[required] The Amazon Resource Name (ARN) of the Automated Reasoning policy to test. |
buildWorkflowId |
[required] The build workflow identifier. The build workflow must show a |
testCaseIds |
The list of test identifiers to run. If not provided, all tests for the policy are run. |
clientRequestToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request but doesn't return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.