View source: R/bedrock_operations.R
| bedrock_update_custom_model_deployment | R Documentation |
Updates a custom model deployment with a new custom model. This allows you to deploy updated models without creating new deployment endpoints.
See https://www.paws-r-sdk.com/docs/bedrock_update_custom_model_deployment/ for full documentation.
bedrock_update_custom_model_deployment(
modelArn,
customModelDeploymentIdentifier
)
modelArn |
[required] ARN of the new custom model to deploy. This replaces the currently deployed model. |
customModelDeploymentIdentifier |
[required] Identifier of the custom model deployment to update with the new custom model. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.