View source: R/bedrockagent_service.R
| bedrockagent | R Documentation |
Amazon Bedrock Agents (now Amazon Bedrock Agents Classic) is no longer open to new customers. For capabilities similar to Bedrock Agents Classic, explore Amazon Bedrock AgentCore. Existing customers can continue to use the service as normal. For more information, see Amazon Bedrock Agents Classic availability change.
Describes the API operations for creating and managing Amazon Bedrock agents.
bedrockagent(
config = list(),
credentials = list(),
endpoint = NULL,
region = NULL
)
config |
Optional configuration of credentials, endpoint, and/or region.
|
credentials |
Optional credentials shorthand for the config parameter
|
endpoint |
Optional shorthand for complete URL to use for the constructed client. |
region |
Optional shorthand for AWS Region used in instantiating the client. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- bedrockagent(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string",
close_connection = "logical",
timeout = "numeric",
s3_force_path_style = "logical",
sts_regional_endpoint = "string",
use_dual_stack = "logical"
),
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string",
anonymous = "logical"
),
endpoint = "string",
region = "string"
)
| associate_agent_collaborator | Makes an agent a collaborator for another agent |
| associate_agent_knowledge_base | Associates a knowledge base with an agent |
| create_agent | Amazon Bedrock Agents (now Amazon Bedrock Agents Classic) is no longer open to new customers |
| create_agent_action_group | Creates an action group for an agent |
| create_agent_alias | Creates an alias of an agent that can be used to deploy the agent |
| create_data_source | Connects a knowledge base to a data source |
| create_flow | Creates a prompt flow that you can use to send an input through various steps to yield an output |
| create_flow_alias | Creates an alias of a flow for deployment |
| create_flow_version | Creates a version of the flow that you can deploy |
| create_knowledge_base | Creates a knowledge base |
| create_prompt | Creates a prompt in your prompt library that you can add to a flow |
| create_prompt_version | Creates a static snapshot of your prompt that can be deployed to production |
| create_vpc_configuration | Creates a VPC configuration that lets a knowledge base connect to a resource in your private VPC |
| delete_agent | Deletes an agent |
| delete_agent_action_group | Deletes an action group in an agent |
| delete_agent_alias | Deletes an alias of an agent |
| delete_agent_version | Deletes a version of an agent |
| delete_data_source | Deletes a data source from a knowledge base |
| delete_flow | Deletes a flow |
| delete_flow_alias | Deletes an alias of a flow |
| delete_flow_version | Deletes a version of a flow |
| delete_knowledge_base | Deletes a knowledge base |
| delete_knowledge_base_documents | Deletes documents from a data source and syncs the changes to the knowledge base that is connected to it |
| delete_prompt | Deletes a prompt or a version of it, depending on whether you include the promptVersion field or not |
| delete_resource_policy | Removes the resource policy associated with a knowledge base |
| delete_vpc_configuration | Deletes a VPC configuration |
| disassociate_agent_collaborator | Disassociates an agent collaborator |
| disassociate_agent_knowledge_base | Disassociates a knowledge base from an agent |
| get_agent | Gets information about an agent |
| get_agent_action_group | Gets information about an action group for an agent |
| get_agent_alias | Gets information about an alias of an agent |
| get_agent_collaborator | Retrieves information about an agent's collaborator |
| get_agent_knowledge_base | Gets information about a knowledge base associated with an agent |
| get_agent_version | Gets details about a version of an agent |
| get_data_source | Gets information about a data source |
| get_flow | Retrieves information about a flow |
| get_flow_alias | Retrieves information about a flow |
| get_flow_version | Retrieves information about a version of a flow |
| get_ingestion_job | Gets information about a data ingestion job |
| get_knowledge_base | Gets information about a knowledge base |
| get_knowledge_base_documents | Retrieves specific documents from a data source that is connected to a knowledge base |
| get_prompt | Retrieves information about the working draft (DRAFT version) of a prompt or a version of it, depending on whether you include the promptVersion field or not |
| get_resource_policy | Retrieves the resource policy associated with a knowledge base |
| get_vpc_configuration | Returns the details and current status of a single VPC configuration |
| ingest_knowledge_base_documents | Ingests documents directly into the knowledge base that is connected to the data source |
| list_agent_action_groups | Lists the action groups for an agent and information about each one |
| list_agent_aliases | Lists the aliases of an agent and information about each one |
| list_agent_collaborators | Retrieve a list of an agent's collaborators |
| list_agent_knowledge_bases | Lists knowledge bases associated with an agent and information about each one |
| list_agents | Lists the agents belonging to an account and information about each agent |
| list_agent_versions | Lists the versions of an agent and information about each version |
| list_data_sources | Lists the data sources in a knowledge base and information about each one |
| list_flow_aliases | Returns a list of aliases for a flow |
| list_flows | Returns a list of flows and information about each flow |
| list_flow_versions | Returns a list of information about each flow |
| list_ingestion_jobs | Lists the data ingestion jobs for a data source |
| list_knowledge_base_documents | Retrieves all the documents contained in a data source that is connected to a knowledge base |
| list_knowledge_bases | Lists the knowledge bases in an account |
| list_prompts | Returns either information about the working draft (DRAFT version) of each prompt in an account, or information about of all versions of a prompt, depending on whether you include the promptIdentifier field or not |
| list_tags_for_resource | List all the tags for the resource you specify |
| list_vpc_configurations | Returns a paginated list of the VPC configurations for a knowledge base |
| prepare_agent | Creates a DRAFT version of the agent that can be used for internal testing |
| prepare_flow | Prepares the DRAFT version of a flow so that it can be invoked |
| put_resource_policy | Associates a resource policy with a knowledge base |
| start_ingestion_job | Begins a data ingestion job |
| stop_ingestion_job | Stops a currently running data ingestion job |
| tag_resource | Associate tags with a resource |
| untag_resource | Remove tags from a resource |
| update_agent | Updates the configuration of an agent |
| update_agent_action_group | Updates the configuration for an action group for an agent |
| update_agent_alias | Updates configurations for an alias of an agent |
| update_agent_collaborator | Updates an agent's collaborator |
| update_agent_knowledge_base | Updates the configuration for a knowledge base that has been associated with an agent |
| update_data_source | Updates the configurations for a data source connector |
| update_flow | Modifies a flow |
| update_flow_alias | Modifies the alias of a flow |
| update_knowledge_base | Updates the configuration of a knowledge base with the fields that you specify |
| update_prompt | Modifies a prompt in your prompt library |
| validate_flow_definition | Validates the definition of a flow |
## Not run:
svc <- bedrockagent()
svc$associate_agent_collaborator(
Foo = 123
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.