View source: R/bedrockagent_operations.R
| bedrockagent_create_agent_action_group | R Documentation |
Creates an action group for an agent. An action group represents the actions that an agent can carry out for the customer by defining the APIs that an agent can call and the logic for calling them.
See https://www.paws-r-sdk.com/docs/bedrockagent_create_agent_action_group/ for full documentation.
bedrockagent_create_agent_action_group(
agentId,
agentVersion,
actionGroupName,
clientToken = NULL,
description = NULL,
parentActionGroupSignature = NULL,
parentActionGroupSignatureParams = NULL,
actionGroupExecutor = NULL,
apiSchema = NULL,
actionGroupState = NULL,
functionSchema = NULL
)
agentId |
[required] The unique identifier of the agent for which to create the action group. |
agentVersion |
[required] The version of the agent for which to create the action group. |
actionGroupName |
[required] The name to give the action group. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency. |
description |
A description of the action group. |
parentActionGroupSignature |
Specify a built-in or computer use action for this action group. If you specify a value, you must leave the
|
parentActionGroupSignatureParams |
The configuration settings for a computer use action. Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools. |
actionGroupExecutor |
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action or the custom control method for handling the information elicited from the user. |
apiSchema |
Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema. For more information, see Action group OpenAPI schemas. |
actionGroupState |
Specifies whether the action group is available for the agent to invoke or not when sending an InvokeAgent request. |
functionSchema |
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.