View source: R/bedrockagent_operations.R
| bedrockagent_update_flow_alias | R Documentation |
Modifies the alias of a flow. Include both fields that you want to keep and ones that you want to change. For more information, see Deploy a flow in Amazon Bedrock in the Amazon Bedrock User Guide.
See https://www.paws-r-sdk.com/docs/bedrockagent_update_flow_alias/ for full documentation.
bedrockagent_update_flow_alias(
name,
description = NULL,
routingConfiguration,
concurrencyConfiguration = NULL,
flowIdentifier,
aliasIdentifier
)
name |
[required] The name of the alias. |
description |
A description for the alias. |
routingConfiguration |
[required] Contains information about the version to which to map the alias. |
concurrencyConfiguration |
The configuration that specifies how nodes in the flow are executed in parallel. |
flowIdentifier |
[required] The unique identifier of the flow. |
aliasIdentifier |
[required] The unique identifier of the alias. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.