View source: R/bedrockagentcore_operations.R
| bedrockagentcore_batch_create_memory_records | R Documentation |
Creates multiple memory records in a single batch operation for the specified memory with custom content.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_create_memory_records/ for full documentation.
bedrockagentcore_batch_create_memory_records(
memoryId,
records,
clientToken = NULL
)
memoryId |
[required] The unique ID of the memory resource where records will be created. |
records |
[required] A list of memory record creation inputs to be processed in the batch operation. |
clientToken |
A unique, case-sensitive identifier to ensure idempotent processing of the batch request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.