View source: R/bedrockagentcore_operations.R
| bedrockagentcore_batch_delete_memory_records | R Documentation |
Deletes multiple memory records in a single batch operation from the specified memory.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_delete_memory_records/ for full documentation.
bedrockagentcore_batch_delete_memory_records(memoryId, records)
memoryId |
[required] The unique ID of the memory resource where records will be deleted. |
records |
[required] A list of memory record deletion inputs to be processed in the batch operation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.