View source: R/bedrockagentcore_operations.R
| bedrockagentcore_batch_update_memory_records | R Documentation |
Updates multiple memory records with custom content in a single batch operation within the specified memory.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_batch_update_memory_records/ for full documentation.
bedrockagentcore_batch_update_memory_records(memoryId, records)
memoryId |
[required] The unique ID of the memory resource where records will be updated. |
records |
[required] A list of memory record update inputs to be processed in the batch operation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.