View source: R/bedrockagentcore_operations.R
| bedrockagentcore_complete_resource_token_auth | R Documentation |
Confirms the user authentication session for obtaining OAuth2.0 tokens for a resource.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_complete_resource_token_auth/ for full documentation.
bedrockagentcore_complete_resource_token_auth(userIdentifier, sessionUri)
userIdentifier |
[required] The OAuth2.0 token or user ID that was used to generate the workload access token used for initiating the user authorization flow to retrieve OAuth2.0 tokens. |
sessionUri |
[required] Unique identifier for the user's authentication session for retrieving OAuth2 tokens. This ID tracks the authorization flow state across multiple requests and responses during the OAuth2 authentication process. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.