View source: R/bedrockagentcore_operations.R
| bedrockagentcore_create_payment_instrument | R Documentation |
Create a new payment instrument for a connector.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_create_payment_instrument/ for full documentation.
bedrockagentcore_create_payment_instrument(
userId = NULL,
agentName = NULL,
paymentManagerArn,
paymentConnectorId,
paymentInstrumentType,
paymentInstrumentDetails,
clientToken = NULL
)
userId |
The user ID associated with this payment instrument. |
agentName |
The agent name associated with this request, used for observability. |
paymentManagerArn |
[required] The ARN of the payment manager that owns this payment instrument. |
paymentConnectorId |
[required] The ID of the payment connector to use for this instrument. |
paymentInstrumentType |
[required] The type of payment instrument being created. |
paymentInstrumentDetails |
[required] The details of the payment instrument. |
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.