View source: R/bedrockagentcore_operations.R
| bedrockagentcore_create_payment_session | R Documentation |
Create a new payment session.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_create_payment_session/ for full documentation.
bedrockagentcore_create_payment_session(
userId = NULL,
agentName = NULL,
paymentManagerArn,
limits = NULL,
expiryTimeInMinutes,
clientToken = NULL
)
userId |
The user ID associated with this payment session. |
agentName |
The agent name associated with this request, used for observability. |
paymentManagerArn |
[required] The ARN of the payment manager that owns this session. |
limits |
The spending limits for this payment session. |
expiryTimeInMinutes |
[required] The session expiry time in minutes. Must be between 15 and 480 minutes. |
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.