View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_agent_card | R Documentation |
Retrieves the A2A agent card associated with an AgentCore Runtime agent.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_agent_card/ for full documentation.
bedrockagentcore_get_agent_card(
runtimeSessionId = NULL,
agentRuntimeArn,
qualifier = NULL
)
runtimeSessionId |
The session ID that the AgentCore Runtime agent is using. |
agentRuntimeArn |
[required] The ARN of the AgentCore Runtime agent for which you want to get the A2A agent card. |
qualifier |
Optional qualifier to specify an agent alias, such as |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.