View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_browser_session | R Documentation |
Retrieves detailed information about a specific browser session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, associated streams, and metadata.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_browser_session/ for full documentation.
bedrockagentcore_get_browser_session(browserIdentifier, sessionId)
browserIdentifier |
[required] The unique identifier of the browser associated with the session. |
sessionId |
[required] The unique identifier of the browser session to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.