View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_code_interpreter_session | R Documentation |
Retrieves detailed information about a specific code interpreter session in Amazon Bedrock AgentCore. This operation returns the session's configuration, current status, and metadata.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_code_interpreter_session/ for full documentation.
bedrockagentcore_get_code_interpreter_session(
codeInterpreterIdentifier,
sessionId
)
codeInterpreterIdentifier |
[required] The unique identifier of the code interpreter associated with the session. |
sessionId |
[required] The unique identifier of the code interpreter session to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.