View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_event | R Documentation |
Retrieves information about a specific event in an AgentCore Memory resource.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_event/ for full documentation.
bedrockagentcore_get_event(memoryId, sessionId, actorId, eventId)
memoryId |
[required] The identifier of the AgentCore Memory resource containing the event. |
sessionId |
[required] The identifier of the session containing the event. |
actorId |
[required] The identifier of the actor associated with the event. |
eventId |
[required] The identifier of the event to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.