View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_payment_instrument | R Documentation |
Get a payment instrument by ID.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_payment_instrument/ for full documentation.
bedrockagentcore_get_payment_instrument(
userId = NULL,
agentName = NULL,
paymentManagerArn,
paymentConnectorId = NULL,
paymentInstrumentId
)
userId |
The user ID associated with this payment instrument. |
agentName |
The agent name associated with this request, used for observability. |
paymentManagerArn |
[required] The ARN of the payment manager that owns this payment instrument. |
paymentConnectorId |
The ID of the payment connector. |
paymentInstrumentId |
[required] The ID of the payment instrument to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.