View source: R/bedrockagentcore_operations.R
| bedrockagentcore_get_resource_api_key | R Documentation |
Retrieves the API key associated with an API key credential provider.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_get_resource_api_key/ for full documentation.
bedrockagentcore_get_resource_api_key(
workloadIdentityToken,
resourceCredentialProviderName
)
workloadIdentityToken |
[required] The identity token of the workload from which you want to retrieve the API key. |
resourceCredentialProviderName |
[required] The credential provider name for the resource from which you are retrieving the API key. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.