View source: R/bedrockagentcore_operations.R
| bedrockagentcore_invoke_browser | R Documentation |
Invokes an operating system-level action on a browser session in Amazon Bedrock AgentCore. This operation provides direct OS-level control over browser sessions, enabling mouse actions, keyboard input, and screenshots that the WebSocket-based Chrome DevTools Protocol (CDP) cannot handle — such as interacting with print dialogs, context menus, and JavaScript alerts.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_invoke_browser/ for full documentation.
bedrockagentcore_invoke_browser(browserIdentifier, sessionId, action)
browserIdentifier |
[required] The unique identifier of the browser associated with the session. This must match the identifier used when creating the session with |
sessionId |
[required] The unique identifier of the browser session on which to perform the action. This must be an active session created with |
action |
[required] The browser action to perform. Exactly one member of the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.