View source: R/bedrockagentcore_operations.R
| bedrockagentcore_list_code_interpreter_sessions | R Documentation |
Retrieves a list of code interpreter sessions in Amazon Bedrock AgentCore that match the specified criteria. This operation returns summary information about each session, including identifiers, status, and timestamps.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_code_interpreter_sessions/ for full documentation.
bedrockagentcore_list_code_interpreter_sessions(
codeInterpreterIdentifier,
maxResults = NULL,
nextToken = NULL,
status = NULL
)
codeInterpreterIdentifier |
[required] The unique identifier of the code interpreter to list sessions for. If specified, only sessions for this code interpreter are returned. If not specified, sessions for all code interpreters are returned. |
maxResults |
The maximum number of results to return in a single call. The default value is 10. Valid values range from 1 to 100. To retrieve the remaining results, make another call with the returned |
nextToken |
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. If not specified, Amazon Bedrock AgentCore returns the first page of results. |
status |
The status of the code interpreter sessions to list. Valid values include ACTIVE, STOPPING, and STOPPED. If not specified, sessions with any status are returned. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.