View source: R/bedrockagentcore_operations.R
| bedrockagentcore_list_events | R Documentation |
Lists events in an AgentCore Memory resource based on specified criteria. We recommend using pagination to ensure that the operation returns quickly and successfully.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_events/ for full documentation.
bedrockagentcore_list_events(
memoryId,
sessionId,
actorId,
includePayloads = NULL,
filter = NULL,
maxResults = NULL,
nextToken = NULL
)
memoryId |
[required] The identifier of the AgentCore Memory resource for which to list events. |
sessionId |
[required] The identifier of the session for which to list events. |
actorId |
[required] The identifier of the actor for which to list events. |
includePayloads |
Specifies whether to include event payloads in the response. Set to true to include payloads, or false to exclude them. |
filter |
Filter criteria to apply when listing events. |
maxResults |
The maximum number of results to return in a single call. The default value is 20. |
nextToken |
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.