View source: R/bedrockagentcore_operations.R
| bedrockagentcore_list_recommendations | R Documentation |
Lists all recommendations in the account, with optional filtering by status.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_list_recommendations/ for full documentation.
bedrockagentcore_list_recommendations(
maxResults = NULL,
nextToken = NULL,
statusFilter = NULL
)
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
statusFilter |
Optional filter to return only recommendations with the specified status. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.