View source: R/bedrockagentcore_operations.R
| bedrockagentcore_process_payment | R Documentation |
Processes a payment using a payment instrument within a payment session.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_process_payment/ for full documentation.
bedrockagentcore_process_payment(
userId = NULL,
agentName = NULL,
paymentManagerArn,
paymentSessionId,
paymentInstrumentId,
paymentType,
paymentInput,
clientToken = NULL
)
userId |
The user ID associated with this payment. |
agentName |
The agent name associated with this request, used for observability. |
paymentManagerArn |
[required] The ARN of the payment manager. |
paymentSessionId |
[required] The ID of the payment session. |
paymentInstrumentId |
[required] The ID of the payment instrument to use. |
paymentType |
[required] The type of payment to process. |
paymentInput |
[required] The payment input details specific to the payment type. |
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.