View source: R/bedrockagentcore_operations.R
| bedrockagentcore_start_memory_extraction_job | R Documentation |
Starts a memory extraction job that processes events that failed extraction previously in an AgentCore Memory resource and produces structured memory records. When earlier extraction attempts have left events unprocessed, this job will pick up and extract those as well.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_start_memory_extraction_job/ for full documentation.
bedrockagentcore_start_memory_extraction_job(
memoryId,
extractionJob,
clientToken = NULL
)
memoryId |
[required] The unique identifier of the memory for which to start extraction jobs. |
extractionJob |
[required] Extraction job to start in this operation. |
clientToken |
A unique, case-sensitive identifier to ensure idempotent processing of the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.