View source: R/bedrockagentcore_operations.R
| bedrockagentcore_start_recommendation | R Documentation |
Starts a recommendation job that analyzes agent traces and generates optimization suggestions for system prompts or tool descriptions to improve agent performance.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_start_recommendation/ for full documentation.
bedrockagentcore_start_recommendation(
name,
description = NULL,
type,
recommendationConfig,
clientToken = NULL
)
name |
[required] The name of the recommendation. Must be unique within your account. |
description |
The description of the recommendation. |
type |
[required] The type of recommendation to generate. Valid values are |
recommendationConfig |
[required] The configuration for the recommendation, including the input to optimize, agent traces to analyze, and evaluation settings. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.