View source: R/bedrockagentcore_operations.R
| bedrockagentcore_stop_batch_evaluation | R Documentation |
Stops a running batch evaluation. Sessions that have already been evaluated retain their results.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_batch_evaluation/ for full documentation.
bedrockagentcore_stop_batch_evaluation(batchEvaluationId)
batchEvaluationId |
[required] The unique identifier of the batch evaluation to stop. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.