View source: R/bedrockagentcore_operations.R
| bedrockagentcore_stop_code_interpreter_session | R Documentation |
Terminates an active code interpreter session in Amazon Bedrock AgentCore. This operation stops the session, releases associated resources, and makes the session unavailable for further use.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_stop_code_interpreter_session/ for full documentation.
bedrockagentcore_stop_code_interpreter_session(
traceId = NULL,
traceParent = NULL,
codeInterpreterIdentifier,
sessionId,
clientToken = NULL
)
traceId |
The trace identifier for request tracking. |
traceParent |
The parent trace information for distributed tracing. |
codeInterpreterIdentifier |
[required] The unique identifier of the code interpreter associated with the session. |
sessionId |
[required] The unique identifier of the code interpreter session to stop. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock AgentCore ignores the request, but does not return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.