View source: R/bedrockagentcore_operations.R
| bedrockagentcore_update_browser_stream | R Documentation |
Updates a browser stream. To use this operation, you must have permissions to perform the bedrock:UpdateBrowserStream action.
See https://www.paws-r-sdk.com/docs/bedrockagentcore_update_browser_stream/ for full documentation.
bedrockagentcore_update_browser_stream(
browserIdentifier,
sessionId,
streamUpdate,
clientToken = NULL
)
browserIdentifier |
[required] The identifier of the browser. |
sessionId |
[required] The identifier of the browser session. |
streamUpdate |
[required] The update to apply to the browser stream. |
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.