View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_agent_runtime_endpoint | R Documentation |
Creates an AgentCore Runtime endpoint.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_agent_runtime_endpoint/ for full documentation.
bedrockagentcorecontrol_create_agent_runtime_endpoint(
agentRuntimeId,
name,
agentRuntimeVersion = NULL,
description = NULL,
clientToken = NULL,
tags = NULL
)
agentRuntimeId |
[required] The unique identifier of the AgentCore Runtime to create an endpoint for. |
name |
[required] The name of the AgentCore Runtime endpoint. |
agentRuntimeVersion |
The version of the AgentCore Runtime to use for the endpoint. |
description |
The description of the AgentCore Runtime endpoint. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
tags |
A map of tag keys and values to assign to the agent runtime endpoint. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.