View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_api_key_credential_provider | R Documentation |
Creates a new API key credential provider.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_api_key_credential_provider/ for full documentation.
bedrockagentcorecontrol_create_api_key_credential_provider(
name,
apiKey,
tags = NULL
)
name |
[required] The name of the API key credential provider. The name must be unique within your account. |
apiKey |
[required] The API key to use for authentication. This value is encrypted and stored securely. |
tags |
A map of tag keys and values to assign to the API key credential provider. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.