View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_consent_portal | R Documentation |
Creates a new consent portal.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_consent_portal/ for full documentation.
bedrockagentcorecontrol_create_consent_portal(
executionRoleArn,
idpConfig,
name,
sources,
description = NULL,
tags = NULL
)
executionRoleArn |
[required] The Amazon Resource Name (ARN) of the IAM role that the consent portal assumes to access the resources defined in its sources. |
idpConfig |
[required] The identity provider configuration that the consent portal uses to authenticate end users. |
name |
[required] The name of the consent portal. The name must be unique within your account. |
sources |
[required] The resources served by the consent portal. Currently, we only support type |
description |
The description of the consent portal. |
tags |
A map of tag keys and values to assign to the consent portal. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.