View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_dataset_version | R Documentation |
Publishes the current DRAFT as a new numbered version.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_dataset_version/ for full documentation.
bedrockagentcorecontrol_create_dataset_version(datasetId, clientToken = NULL)
datasetId |
[required] The unique identifier of the dataset to publish a version for. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.