View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_gateway_rule | R Documentation |
Creates a rule for a gateway. Rules define conditions and actions that control how requests are routed and processed through the gateway, including principal-based access control and path-based routing.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_gateway_rule/ for full documentation.
bedrockagentcorecontrol_create_gateway_rule(
gatewayIdentifier,
clientToken = NULL,
priority,
conditions = NULL,
actions,
description = NULL
)
gatewayIdentifier |
[required] The identifier of the gateway to create a rule for. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
priority |
[required] The priority of the rule. Rules are evaluated in order of priority, with lower numbers evaluated first. Must be between 1 and 1,000,000. |
conditions |
The conditions that must be met for the rule to apply. Conditions can match on principals (IAM ARNs) or request paths. |
actions |
[required] The actions to take when the rule conditions are met. Actions can route to a specific target or apply a configuration bundle override. |
description |
The description of the gateway rule. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.