View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_harness_endpoint | R Documentation |
Operation to create a harness endpoint.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_harness_endpoint/ for full documentation.
bedrockagentcorecontrol_create_harness_endpoint(
harnessId,
endpointName,
targetVersion = NULL,
description = NULL,
clientToken = NULL,
tags = NULL
)
harnessId |
[required] The ID of the harness to create an endpoint for. |
endpointName |
[required] The name of the endpoint. Must start with a letter and contain only alphanumeric characters and underscores. |
targetVersion |
The harness version that the endpoint points to and serves invocations from. |
description |
A description of the endpoint. |
clientToken |
A unique, case-sensitive identifier to ensure idempotency of the request. |
tags |
Tags to apply to the endpoint resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.