View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_memory | R Documentation |
Creates a new Amazon Bedrock AgentCore Memory resource.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_memory/ for full documentation.
bedrockagentcorecontrol_create_memory(
clientToken = NULL,
name,
description = NULL,
encryptionKeyArn = NULL,
memoryExecutionRoleArn = NULL,
eventExpiryDuration,
memoryStrategies = NULL,
indexedKeys = NULL,
streamDeliveryResources = NULL,
tags = NULL
)
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request but does not return an error. |
name |
[required] The name of the memory. The name must be unique within your account. |
description |
The description of the memory. |
encryptionKeyArn |
The Amazon Resource Name (ARN) of the KMS key used to encrypt the memory data. |
memoryExecutionRoleArn |
The Amazon Resource Name (ARN) of the IAM role that provides permissions for the memory to access Amazon Web Services services. |
eventExpiryDuration |
[required] The duration after which memory events expire. Specified as an ISO 8601 duration. |
memoryStrategies |
The memory strategies to use for this memory. Strategies define how information is extracted, processed, and consolidated. |
indexedKeys |
Metadata keys to index for filtering. Once declared, indexed keys cannot be removed. |
streamDeliveryResources |
Configuration for streaming memory record data to external resources. |
tags |
A map of tag keys and values to assign to an AgentCore Memory. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.