View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_oauth_2_credential_provider | R Documentation |
Creates a new OAuth2 credential provider.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_oauth_2_credential_provider/ for full documentation.
bedrockagentcorecontrol_create_oauth_2_credential_provider(
name,
credentialProviderVendor,
oauth2ProviderConfigInput,
tags = NULL
)
name |
[required] The name of the OAuth2 credential provider. The name must be unique within your account. |
credentialProviderVendor |
[required] The vendor of the OAuth2 credential provider. This specifies which OAuth2 implementation to use. |
oauth2ProviderConfigInput |
[required] The configuration settings for the OAuth2 provider, including client ID, client secret, and other vendor-specific settings. |
tags |
A map of tag keys and values to assign to the OAuth2 credential provider. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.