View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_payment_connector | R Documentation |
Creates a new payment connector for a payment manager. A payment connector integrates with a supported payment provider to enable payment processing capabilities.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_payment_connector/ for full documentation.
bedrockagentcorecontrol_create_payment_connector(
paymentManagerId,
name,
description = NULL,
type,
credentialProviderConfigurations,
clientToken = NULL
)
paymentManagerId |
[required] The unique identifier of the payment manager to create the connector for. |
name |
[required] The name of the payment connector. |
description |
A description of the payment connector. |
type |
[required] The type of payment connector, which determines the payment provider integration. |
credentialProviderConfigurations |
[required] The credential provider configurations for the payment connector. These configurations specify how the connector authenticates with the payment provider. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.