View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_payment_manager | R Documentation |
Creates a new payment manager in your Amazon Web Services account. A payment manager serves as the top-level resource for managing payment processing capabilities, including payment connectors that integrate with supported payment providers.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_payment_manager/ for full documentation.
bedrockagentcorecontrol_create_payment_manager(
name,
description = NULL,
authorizerType,
authorizerConfiguration = NULL,
roleArn,
clientToken = NULL,
tags = NULL
)
name |
[required] The name of the payment manager. |
description |
A description of the payment manager. |
authorizerType |
[required] The type of authorizer to use for the payment manager.
|
authorizerConfiguration |
The authorizer configuration for the payment manager. |
roleArn |
[required] The Amazon Resource Name (ARN) of the IAM role that the payment manager assumes to access resources on your behalf. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
tags |
A map of tag keys and values to assign to the payment manager. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.