View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_create_workload_identity | R Documentation |
Creates a new workload identity.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_create_workload_identity/ for full documentation.
bedrockagentcorecontrol_create_workload_identity(
name,
allowedResourceOauth2ReturnUrls = NULL,
tags = NULL
)
name |
[required] The name of the workload identity. The name must be unique within your account. |
allowedResourceOauth2ReturnUrls |
The list of allowed OAuth2 return URLs for resources associated with this workload identity. |
tags |
A map of tag keys and values to assign to the workload identity. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.