View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_agent_runtime | R Documentation |
Deletes an Amazon Bedrock AgentCore Runtime.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_agent_runtime/ for full documentation.
bedrockagentcorecontrol_delete_agent_runtime(
agentRuntimeId,
clientToken = NULL
)
agentRuntimeId |
[required] The unique identifier of the AgentCore Runtime to delete. |
clientToken |
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.