View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_configuration_bundle | R Documentation |
Deletes a configuration bundle and all of its versions.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_configuration_bundle/ for full documentation.
bedrockagentcorecontrol_delete_configuration_bundle(bundleId)
bundleId |
[required] The unique identifier of the configuration bundle to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.