View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_gateway_target | R Documentation |
Deletes a gateway target.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_gateway_target/ for full documentation.
bedrockagentcorecontrol_delete_gateway_target(gatewayIdentifier, targetId)
gatewayIdentifier |
[required] The unique identifier of the gateway associated with the target. |
targetId |
[required] The unique identifier of the gateway target to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.