View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_memory | R Documentation |
Deletes an Amazon Bedrock AgentCore Memory resource.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_memory/ for full documentation.
bedrockagentcorecontrol_delete_memory(clientToken = NULL, memoryId)
clientToken |
A client token is used for keeping track of idempotent requests. It can contain a session id which can be around 250 chars, combined with a unique AWS identifier. |
memoryId |
[required] The unique identifier of the memory to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.