View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_online_evaluation_config | R Documentation |
Deletes an online evaluation configuration and stops any ongoing evaluation processes associated with it.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_online_evaluation_config/ for full documentation.
bedrockagentcorecontrol_delete_online_evaluation_config(
onlineEvaluationConfigId
)
onlineEvaluationConfigId |
[required] The unique identifier of the online evaluation configuration to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.