View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_delete_policy | R Documentation |
Deletes an existing policy from the AgentCore Policy system. Once deleted, the policy can no longer be used for agent behavior control and all references to it become invalid. This is an asynchronous operation. Use the get_policy operation to poll the status field to track completion.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_delete_policy/ for full documentation.
bedrockagentcorecontrol_delete_policy(policyEngineId, policyId)
policyEngineId |
[required] The identifier of the policy engine that manages the policy to be deleted. This ensures the policy is deleted from the correct policy engine context. |
policyId |
[required] The unique identifier of the policy to be deleted. This must be a valid policy ID that exists within the specified policy engine. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.