View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_get_configuration_bundle | R Documentation |
Gets the latest version of a configuration bundle. By default, returns the latest version on the mainline branch. Use get_configuration_bundle_version to retrieve a specific historical version.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_configuration_bundle/ for full documentation.
bedrockagentcorecontrol_get_configuration_bundle(bundleId, branchName = NULL)
bundleId |
[required] The unique identifier of the configuration bundle to retrieve. |
branchName |
The branch name to get the latest version from. If not specified, returns the latest version on the mainline branch. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.