View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_get_online_evaluation_config | R Documentation |
Retrieves detailed information about an online evaluation configuration, including its rules, data sources, evaluators, and execution status.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_online_evaluation_config/ for full documentation.
bedrockagentcorecontrol_get_online_evaluation_config(onlineEvaluationConfigId)
onlineEvaluationConfigId |
[required] The unique identifier of the online evaluation configuration to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.