View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_get_registry_record | R Documentation |
Retrieves information about a specific registry record.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_get_registry_record/ for full documentation.
bedrockagentcorecontrol_get_registry_record(registryId, recordId)
registryId |
[required] The identifier of the registry containing the record. You can specify either the Amazon Resource Name (ARN) or the ID of the registry. |
recordId |
[required] The identifier of the registry record to retrieve. You can specify either the Amazon Resource Name (ARN) or the ID of the record. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.