View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_browser_profiles | R Documentation |
Lists all browser profiles in your account.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_browser_profiles/ for full documentation.
bedrockagentcorecontrol_list_browser_profiles(
maxResults = NULL,
nextToken = NULL,
name = NULL
)
maxResults |
The maximum number of results to return in the response. |
nextToken |
A token to retrieve the next page of results. |
name |
The name of the browser profile to filter results by. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.