View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_evaluators | R Documentation |
Lists all available evaluators, including both builtin evaluators provided by the service and custom evaluators created by the user.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_evaluators/ for full documentation.
bedrockagentcorecontrol_list_evaluators(nextToken = NULL, maxResults = NULL)
nextToken |
The pagination token from a previous request to retrieve the next page of results. |
maxResults |
The maximum number of evaluators to return in a single response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.