View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_gateway_rules | R Documentation |
Lists all rules for a gateway.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_gateway_rules/ for full documentation.
bedrockagentcorecontrol_list_gateway_rules(
gatewayIdentifier,
maxResults = NULL,
nextToken = NULL
)
gatewayIdentifier |
[required] The identifier of the gateway to list rules for. |
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
The pagination token from a previous request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.