View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_gateway_targets | R Documentation |
Lists all targets for a specific gateway.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_gateway_targets/ for full documentation.
bedrockagentcorecontrol_list_gateway_targets(
gatewayIdentifier,
maxResults = NULL,
nextToken = NULL
)
gatewayIdentifier |
[required] The identifier of the gateway to list targets for. |
maxResults |
The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the |
nextToken |
If the total number of results is greater than the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.