View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_list_online_evaluation_configs | R Documentation |
Lists all online evaluation configurations in the account, providing summary information about each configuration's status and settings.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_list_online_evaluation_configs/ for full documentation.
bedrockagentcorecontrol_list_online_evaluation_configs(
nextToken = NULL,
maxResults = NULL
)
nextToken |
The pagination token from a previous request to retrieve the next page of results. |
maxResults |
The maximum number of online evaluation configurations to return in a single response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.