View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_put_resource_policy | R Documentation |
Creates or updates a resource-based policy for a resource with the specified resourceArn.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_put_resource_policy/ for full documentation.
bedrockagentcorecontrol_put_resource_policy(resourceArn, policy)
resourceArn |
[required] The Amazon Resource Name (ARN) of the resource for which to create or update the resource policy. |
policy |
[required] The resource policy to create or update. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.