View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_set_token_vault_cmk | R Documentation |
Sets the customer master key (CMK) for a token vault.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_set_token_vault_cmk/ for full documentation.
bedrockagentcorecontrol_set_token_vault_cmk(
tokenVaultId = NULL,
kmsConfiguration
)
tokenVaultId |
The unique identifier of the token vault to update. |
kmsConfiguration |
[required] The KMS configuration for the token vault, including the key type and KMS key ARN. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.