View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_dataset | R Documentation |
Updates a dataset's metadata. Synchronous operation. Only provided fields are updated; omitted fields remain unchanged.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_dataset/ for full documentation.
bedrockagentcorecontrol_update_dataset(
datasetId,
clientToken = NULL,
description = NULL
)
datasetId |
[required] The unique identifier of the dataset to update. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
description |
The updated description for the dataset. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.