View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_dataset_examples | R Documentation |
Updates multiple existing examples in-place on DRAFT.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_dataset_examples/ for full documentation.
bedrockagentcorecontrol_update_dataset_examples(
datasetId,
clientToken = NULL,
examples
)
datasetId |
[required] The unique identifier of the dataset. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
examples |
[required] Examples to update. Each element is a JSON object containing a required |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.