View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_evaluator | R Documentation |
Updates a custom evaluator's configuration, description, or evaluation level. Built-in evaluators cannot be updated. The evaluator must not be locked for modification.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_evaluator/ for full documentation.
bedrockagentcorecontrol_update_evaluator(
clientToken = NULL,
evaluatorId,
description = NULL,
evaluatorConfig = NULL,
level = NULL,
kmsKeyArn = NULL
)
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
evaluatorId |
[required] The unique identifier of the evaluator to update. |
description |
The updated description of the evaluator. |
evaluatorConfig |
The updated configuration for the evaluator. Specify either LLM-as-a-Judge settings with instructions, rating scale, and model configuration, or code-based settings with a customer-managed Lambda function. |
level |
The updated evaluation level ( |
kmsKeyArn |
The Amazon Resource Name (ARN) of a customer managed KMS key to use for encrypting sensitive evaluator data. Specify a new key ARN to rotate the encryption key, or specify a key ARN to add encryption to an evaluator that was previously created without one. When you rotate to a new key, the service decrypts the existing data with the old key and re-encrypts it with the new key. Only symmetric encryption KMS keys are supported. For more information, see Encryption at rest for AgentCore Evaluations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.