View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_gateway_target | R Documentation |
Updates an existing gateway target.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_gateway_target/ for full documentation.
bedrockagentcorecontrol_update_gateway_target(
gatewayIdentifier,
targetId,
name,
description = NULL,
targetConfiguration,
credentialProviderConfigurations = NULL,
metadataConfiguration = NULL,
privateEndpoint = NULL
)
gatewayIdentifier |
[required] The unique identifier of the gateway associated with the target. |
targetId |
[required] The unique identifier of the gateway target to update. |
name |
[required] The updated name for the gateway target. |
description |
The updated description for the gateway target. |
targetConfiguration |
[required] The configuration for a gateway target. This structure defines how the gateway connects to and interacts with the target endpoint. |
credentialProviderConfigurations |
The updated credential provider configurations for the gateway target. |
metadataConfiguration |
Configuration for HTTP header and query parameter propagation to the gateway target. |
privateEndpoint |
The private endpoint configuration for the gateway target. Use this to connect the gateway to private resources in your VPC. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.