View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_memory | R Documentation |
Update an Amazon Bedrock AgentCore Memory resource memory.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_memory/ for full documentation.
bedrockagentcorecontrol_update_memory(
clientToken = NULL,
memoryId,
description = NULL,
eventExpiryDuration = NULL,
memoryExecutionRoleArn = NULL,
memoryStrategies = NULL,
addIndexedKeys = NULL,
streamDeliveryResources = NULL
)
clientToken |
A client token is used for keeping track of idempotent requests. It can contain a session id which can be around 250 chars, combined with a unique AWS identifier. |
memoryId |
[required] The unique identifier of the memory to update. |
description |
The updated description of the AgentCore Memory resource. |
eventExpiryDuration |
The number of days after which memory events will expire, between 7 and 365 days. |
memoryExecutionRoleArn |
The ARN of the IAM role that provides permissions for the AgentCore Memory resource. |
memoryStrategies |
The memory strategies to add, modify, or delete. |
addIndexedKeys |
Additional metadata keys to index. Previously indexed keys cannot be removed. |
streamDeliveryResources |
Configuration for streaming memory record data to external resources. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.