View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_payment_connector | R Documentation |
Updates an existing payment connector. This operation uses PATCH semantics, so you only need to specify the fields you want to change.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_payment_connector/ for full documentation.
bedrockagentcorecontrol_update_payment_connector(
paymentManagerId,
paymentConnectorId,
description = NULL,
type = NULL,
credentialProviderConfigurations = NULL,
clientToken = NULL
)
paymentManagerId |
[required] The unique identifier of the parent payment manager. |
paymentConnectorId |
[required] The unique identifier of the payment connector to update. |
description |
The updated description of the payment connector. |
type |
The updated type of the payment connector. |
credentialProviderConfigurations |
The updated credential provider configurations for the payment connector. |
clientToken |
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If you don't specify this field, a value is randomly generated for you. If this token matches a previous request, the service ignores the request, but doesn't return an error. For more information, see Ensuring idempotency. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.