View source: R/bedrockagentcorecontrol_operations.R
| bedrockagentcorecontrol_update_payment_credential_provider | R Documentation |
Updates an existing payment credential provider with new authentication credentials.
See https://www.paws-r-sdk.com/docs/bedrockagentcorecontrol_update_payment_credential_provider/ for full documentation.
bedrockagentcorecontrol_update_payment_credential_provider(
name,
credentialProviderVendor,
providerConfigurationInput
)
name |
[required] The name of the payment credential provider to update. |
credentialProviderVendor |
[required] The vendor type for the payment credential provider (e.g., CoinbaseCDP, StripePrivy). |
providerConfigurationInput |
[required] Configuration specific to the vendor, including API credentials. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.