View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_create_invocation | R Documentation |
Creates a new invocation within a session. An invocation groups the related invocation steps that store the content from a conversation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_create_invocation/ for full documentation.
bedrockagentruntime_create_invocation(
description = NULL,
invocationId = NULL,
sessionIdentifier
)
description |
A description for the interactions in the invocation. For example, "User asking about weather in Seattle". |
invocationId |
A unique identifier for the invocation in UUID format. |
sessionIdentifier |
[required] The unique identifier for the associated session for the invocation. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.