View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_delete_session | R Documentation |
Deletes a session that you ended. You can't delete a session with an ACTIVE status. To delete an active session, you must first end it with the end_session API operation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_delete_session/ for full documentation.
bedrockagentruntime_delete_session(sessionIdentifier)
sessionIdentifier |
[required] The unique identifier for the session to be deleted. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.