View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_end_session | R Documentation |
Ends the session. After you end a session, you can still access its content but you can’t add to it. To delete the session and it's content, you use the DeleteSession API operation. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_end_session/ for full documentation.
bedrockagentruntime_end_session(sessionIdentifier)
sessionIdentifier |
[required] The unique identifier for the session to end. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.