View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_get_execution_flow_snapshot | R Documentation |
Retrieves the flow definition snapshot used for a flow execution. The snapshot represents the flow metadata and definition as it existed at the time the execution was started. Note that even if the flow is edited after an execution starts, the snapshot connected to the execution remains unchanged.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_execution_flow_snapshot/ for full documentation.
bedrockagentruntime_get_execution_flow_snapshot(
executionIdentifier,
flowAliasIdentifier,
flowIdentifier
)
executionIdentifier |
[required] The unique identifier of the flow execution. |
flowAliasIdentifier |
[required] The unique identifier of the flow alias used for the flow execution. |
flowIdentifier |
[required] The unique identifier of the flow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.