View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_get_flow_execution | R Documentation |
Retrieves details about a specific flow execution, including its status, start and end times, and any errors that occurred during execution.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_flow_execution/ for full documentation.
bedrockagentruntime_get_flow_execution(
executionIdentifier,
flowAliasIdentifier,
flowIdentifier
)
executionIdentifier |
[required] The unique identifier of the flow execution to retrieve. |
flowAliasIdentifier |
[required] The unique identifier of the flow alias used for the execution. |
flowIdentifier |
[required] The unique identifier of the flow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.