View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_get_invocation_step | R Documentation |
Retrieves the details of a specific invocation step within an invocation in a session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_invocation_step/ for full documentation.
bedrockagentruntime_get_invocation_step(
invocationIdentifier,
invocationStepId,
sessionIdentifier
)
invocationIdentifier |
[required] The unique identifier for the invocation in UUID format. |
invocationStepId |
[required] The unique identifier (in UUID format) for the specific invocation step to retrieve. |
sessionIdentifier |
[required] The unique identifier for the invocation step's associated session. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.