View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_get_session | R Documentation |
Retrieves details about a specific session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_get_session/ for full documentation.
bedrockagentruntime_get_session(sessionIdentifier)
sessionIdentifier |
[required] A unique identifier for the session to retrieve. You can specify either the session's |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.