View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_list_flow_executions | R Documentation |
Lists all executions of a flow. Results can be paginated and include summary information about each execution, such as status, start and end times, and the execution's Amazon Resource Name (ARN).
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_list_flow_executions/ for full documentation.
bedrockagentruntime_list_flow_executions(
flowAliasIdentifier = NULL,
flowIdentifier,
maxResults = NULL,
nextToken = NULL
)
flowAliasIdentifier |
The unique identifier of the flow alias to list executions for. |
flowIdentifier |
[required] The unique identifier of the flow to list executions for. |
maxResults |
The maximum number of flow executions to return in a single response. If more executions exist than the specified |
nextToken |
A token to retrieve the next set of results. This value is returned in the response if more results are available. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.