View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_stop_flow_execution | R Documentation |
Stops an Amazon Bedrock flow's execution. This operation prevents further processing of the flow and changes the execution status to Aborted.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_stop_flow_execution/ for full documentation.
bedrockagentruntime_stop_flow_execution(
executionIdentifier,
flowAliasIdentifier,
flowIdentifier
)
executionIdentifier |
[required] The unique identifier of the flow execution to stop. |
flowAliasIdentifier |
[required] The unique identifier of the flow alias used for the execution. |
flowIdentifier |
[required] The unique identifier of the flow. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.