View source: R/bedrockagentruntime_operations.R
| bedrockagentruntime_update_session | R Documentation |
Updates the metadata or encryption settings of a session. For more information about sessions, see Store and retrieve conversation history and context with Amazon Bedrock sessions.
See https://www.paws-r-sdk.com/docs/bedrockagentruntime_update_session/ for full documentation.
bedrockagentruntime_update_session(sessionIdentifier, sessionMetadata = NULL)
sessionIdentifier |
[required] The unique identifier of the session to modify. You can specify either the session's |
sessionMetadata |
A map of key-value pairs containing attributes to be persisted across the session. For example the user's ID, their language preference, and the type of device they are using. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.