| bedrockdataautomation_list_data_automation_library_ingestion_jobs | R Documentation |
Lists all data automation library ingestion jobs
See https://www.paws-r-sdk.com/docs/bedrockdataautomation_list_data_automation_library_ingestion_jobs/ for full documentation.
bedrockdataautomation_list_data_automation_library_ingestion_jobs(
libraryArn,
maxResults = NULL,
nextToken = NULL
)
libraryArn |
[required] ARN generated at the server side when a DataAutomationLibrary is created |
maxResults |
Max Results |
nextToken |
Pagination token for retrieving the next set of results |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.