View source: R/bedrockruntime_operations.R
| bedrockruntime_apply_guardrail | R Documentation |
The action to apply a guardrail.
See https://www.paws-r-sdk.com/docs/bedrockruntime_apply_guardrail/ for full documentation.
bedrockruntime_apply_guardrail(
guardrailIdentifier,
guardrailVersion,
source,
content,
outputScope = NULL
)
guardrailIdentifier |
[required] The guardrail identifier used in the request to apply the guardrail. |
guardrailVersion |
[required] The guardrail version used in the request to apply the guardrail. |
source |
[required] The source of data used in the request to apply the guardrail. |
content |
[required] The content details used in the request to apply the guardrail. |
outputScope |
Specifies the scope of the output that you get in the response. Set to Note that the full output scope doesn't apply to word filters or regex in sensitive information filters. It does apply to all other filtering policies, including sensitive information with filters that can detect personally identifiable information (PII). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.