View source: R/lexmodelsv2_operations.R
| lexmodelsv2_delete_bot_analyzer_recommendation | R Documentation |
Permanently deletes the recommendations and analysis results for a specific bot analysis request. This operation is provided for GDPR compliance and cannot be undone.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_delete_bot_analyzer_recommendation/ for full documentation.
lexmodelsv2_delete_bot_analyzer_recommendation(botId, botAnalyzerRequestId)
botId |
[required] The unique identifier of the bot. |
botAnalyzerRequestId |
[required] The unique identifier of the analysis request whose recommendations should be deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.