View source: R/lexmodelsv2_operations.R
| lexmodelsv2_describe_bot_analyzer_recommendation | R Documentation |
Retrieves the analysis results and recommendations for bot optimization. The analysis must be in Available status before recommendations can be retrieved.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_describe_bot_analyzer_recommendation/ for full documentation.
lexmodelsv2_describe_bot_analyzer_recommendation(
botId,
botAnalyzerRequestId,
nextToken = NULL,
maxResults = NULL
)
botId |
[required] The unique identifier of the bot. |
botAnalyzerRequestId |
[required] The unique identifier of the analysis request. |
nextToken |
If the response from a previous request was truncated, the |
maxResults |
The maximum number of recommendations to return in the response. The default is 5. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.