View source: R/lexmodelsv2_operations.R
| lexmodelsv2_list_bot_analyzer_history | R Documentation |
Retrieves a list of historical bot analysis executions for a specific bot. You can filter the results by locale and bot version.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_list_bot_analyzer_history/ for full documentation.
lexmodelsv2_list_bot_analyzer_history(
botId,
localeId = NULL,
botVersion = NULL,
nextToken = NULL,
maxResults = NULL
)
botId |
[required] The unique identifier of the bot. |
localeId |
The locale identifier to filter the history. If not specified, returns history for all locales. |
botVersion |
The bot version to filter the history. If not specified, defaults to |
nextToken |
If the response from a previous request was truncated, the |
maxResults |
The maximum number of history entries to return in the response. The default is 10. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.