View source: R/lexmodelsv2_operations.R
| lexmodelsv2_start_bot_analyzer | R Documentation |
Initiates an asynchronous analysis of your bot configuration using AI-powered analysis to identify potential issues and recommend improvements based on AWS best practices.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_start_bot_analyzer/ for full documentation.
lexmodelsv2_start_bot_analyzer(
botId,
analysisScope,
localeId = NULL,
botVersion = NULL
)
botId |
[required] The unique identifier of the bot to analyze. |
analysisScope |
[required] The scope of analysis to perform. Currently only Valid Values: |
localeId |
The locale identifier for the bot locale to analyze. Required when |
botVersion |
The version of the bot to analyze. Defaults to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.