View source: R/lexmodelsv2_operations.R
| lexmodelsv2_stop_bot_analyzer | R Documentation |
Cancels an ongoing bot analysis execution. Once stopped, the analysis cannot be resumed and no recommendations will be generated.
See https://www.paws-r-sdk.com/docs/lexmodelsv2_stop_bot_analyzer/ for full documentation.
lexmodelsv2_stop_bot_analyzer(botId, botAnalyzerRequestId)
botId |
[required] The unique identifier of the bot. |
botAnalyzerRequestId |
[required] The unique identifier of the analysis request to stop. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.