View source: R/rekognition_operations.R
| rekognition_get_person_tracking | R Documentation |
End of support notice: On October 31, 2025, AWS will discontinue support for Amazon Rekognition People Pathing. After October 31, 2025, you will no longer be able to use the Rekognition People Pathing capability. For more information, visit this blog post.
See https://www.paws-r-sdk.com/docs/rekognition_get_person_tracking/ for full documentation.
rekognition_get_person_tracking(
JobId,
MaxResults = NULL,
NextToken = NULL,
SortBy = NULL
)
JobId |
[required] The identifier for a job that tracks persons in a video. You get the |
MaxResults |
Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. |
NextToken |
If the previous response was incomplete (because there are more persons to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of persons. |
SortBy |
Sort to use for elements in the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.