View source: R/sagemaker_operations.R
| sagemaker_attach_cluster_node_volume | R Documentation |
Attaches your Amazon Elastic Block Store (Amazon EBS) volume to a node in your EKS orchestrated HyperPod cluster.
See https://www.paws-r-sdk.com/docs/sagemaker_attach_cluster_node_volume/ for full documentation.
sagemaker_attach_cluster_node_volume(ClusterArn, NodeId, VolumeId)
ClusterArn |
[required] The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node. Your cluster must use EKS as the orchestration and be in the |
NodeId |
[required] The unique identifier of the cluster node to which you want to attach the volume. The node must belong to your specified HyperPod cluster and cannot be part of a Restricted Instance Group (RIG). |
VolumeId |
[required] The unique identifier of your EBS volume to attach. The volume must be in the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.