View source: R/sagemaker_operations.R
| sagemaker_batch_delete_cluster_nodes | R Documentation |
Deletes specific nodes within a SageMaker HyperPod cluster. batch_delete_cluster_nodes accepts a cluster name and a list of node IDs.
See https://www.paws-r-sdk.com/docs/sagemaker_batch_delete_cluster_nodes/ for full documentation.
sagemaker_batch_delete_cluster_nodes(
ClusterName,
NodeIds = NULL,
NodeLogicalIds = NULL
)
ClusterName |
[required] The name of the SageMaker HyperPod cluster from which to delete the specified nodes. |
NodeIds |
A list of node IDs to be deleted from the specified cluster.
|
NodeLogicalIds |
A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.