View source: R/sagemaker_operations.R
| sagemaker_batch_reboot_cluster_nodes | R Documentation |
Reboots specific nodes within a SageMaker HyperPod cluster using a soft recovery mechanism. batch_reboot_cluster_nodes performs a graceful reboot of the specified nodes by calling the Amazon Elastic Compute Cloud RebootInstances API, which attempts to cleanly shut down the operating system before restarting the instance.
See https://www.paws-r-sdk.com/docs/sagemaker_batch_reboot_cluster_nodes/ for full documentation.
sagemaker_batch_reboot_cluster_nodes(
ClusterName,
NodeIds = NULL,
NodeLogicalIds = NULL
)
ClusterName |
[required] The name or Amazon Resource Name (ARN) of the SageMaker HyperPod cluster containing the nodes to reboot. |
NodeIds |
A list of EC2 instance IDs to reboot using soft recovery. You can specify between 1 and 25 instance IDs.
|
NodeLogicalIds |
A list of logical node IDs to reboot using soft recovery. You can specify between 1 and 25 logical node IDs. The
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.