View source: R/sagemaker_operations.R
| sagemaker_batch_replace_cluster_nodes | R Documentation |
Replaces specific nodes within a SageMaker HyperPod cluster with new hardware. batch_replace_cluster_nodes terminates the specified instances and provisions new replacement instances with the same configuration but fresh hardware. The Amazon Machine Image (AMI) and instance configuration remain the same.
See https://www.paws-r-sdk.com/docs/sagemaker_batch_replace_cluster_nodes/ for full documentation.
sagemaker_batch_replace_cluster_nodes(
ClusterName,
NodeIds = NULL,
NodeLogicalIds = NULL
)
ClusterName |
[required] The name or Amazon Resource Name (ARN) of the SageMaker HyperPod cluster containing the nodes to replace. |
NodeIds |
A list of EC2 instance IDs to replace with new hardware. You can specify between 1 and 25 instance IDs. Replace operations destroy all instance volumes (root and secondary). Ensure you have backed up any important data before proceeding.
|
NodeLogicalIds |
A list of logical node IDs to replace with new hardware. You can specify between 1 and 25 logical node IDs. The
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.