View source: R/sagemaker_operations.R
| sagemaker_create_workforce | R Documentation |
Use this operation to create a workforce. This operation will return an error if a workforce already exists in the Amazon Web Services Region that you specify. You can only create one workforce in each Amazon Web Services Region per Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/sagemaker_create_workforce/ for full documentation.
sagemaker_create_workforce(
CognitoConfig = NULL,
OidcConfig = NULL,
SourceIpConfig = NULL,
WorkforceName,
Tags = NULL,
WorkforceVpcConfig = NULL,
IpAddressType = NULL
)
CognitoConfig |
Use this parameter to configure an Amazon Cognito private workforce. A single Cognito workforce is created using and corresponds to a single Amazon Cognito user pool. Do not use |
OidcConfig |
Use this parameter to configure a private workforce using your own OIDC Identity Provider. Do not use |
SourceIpConfig |
A list of IP address ranges (CIDRs). Used to create an allow list of IP addresses for a private workforce. Workers will only be able to log in to their worker portal from an IP address within this range. By default, a workforce isn't restricted to specific IP addresses. |
WorkforceName |
[required] The name of the private workforce. |
Tags |
An array of key-value pairs that contain metadata to help you categorize and organize our workforce. Each tag consists of a key and a value, both of which you define. |
WorkforceVpcConfig |
Use this parameter to configure a workforce using VPC. |
IpAddressType |
Use this parameter to specify whether you want |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.