View source: R/sagemaker_operations.R
| sagemaker_delete_training_job | R Documentation |
Deletes a training job. After SageMaker deletes a training job, all of the metadata for the training job is lost. You can delete only training jobs that are in a terminal state (Stopped, Failed, or Completed) and don't retain an Available managed warm pool. You cannot delete a job that is in the InProgress or Stopping state. After deleting the job, you can reuse its name to create another training job.
See https://www.paws-r-sdk.com/docs/sagemaker_delete_training_job/ for full documentation.
sagemaker_delete_training_job(TrainingJobName)
TrainingJobName |
[required] The name of the training job to delete. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.