View source: R/sagemaker_operations.R
| sagemaker_describe_training_plan_extension_history | R Documentation |
Retrieves the extension history for a specified training plan. The response includes details about each extension, such as the offering ID, start and end dates, status, payment status, and cost information.
See https://www.paws-r-sdk.com/docs/sagemaker_describe_training_plan_extension_history/ for full documentation.
sagemaker_describe_training_plan_extension_history(
TrainingPlanArn,
NextToken = NULL,
MaxResults = NULL
)
TrainingPlanArn |
[required] The Amazon Resource Name (ARN); of the training plan to retrieve extension history for. |
NextToken |
A token to continue pagination if more results are available. |
MaxResults |
The maximum number of extensions to return in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.