View source: R/sagemaker_operations.R
| sagemaker_detach_cluster_node_volume | R Documentation |
Detaches your Amazon Elastic Block Store (Amazon EBS) volume from a node in your EKS orchestrated SageMaker HyperPod cluster.
See https://www.paws-r-sdk.com/docs/sagemaker_detach_cluster_node_volume/ for full documentation.
sagemaker_detach_cluster_node_volume(ClusterArn, NodeId, VolumeId)
ClusterArn |
[required] The Amazon Resource Name (ARN) of your SageMaker HyperPod cluster containing the target node. Your cluster must use EKS as the orchestration and be in the |
NodeId |
[required] The unique identifier of the cluster node from which you want to detach the volume. |
VolumeId |
[required] The unique identifier of your EBS volume that you want to detach. Your volume must be currently attached to the specified node. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.