View source: R/sagemaker_operations.R
| sagemaker_extend_training_plan | R Documentation |
Extends an existing training plan by purchasing an extension offering. This allows you to add additional compute capacity time to your training plan without creating a new plan or reconfiguring your workloads.
See https://www.paws-r-sdk.com/docs/sagemaker_extend_training_plan/ for full documentation.
sagemaker_extend_training_plan(TrainingPlanExtensionOfferingId)
TrainingPlanExtensionOfferingId |
[required] The unique identifier of the extension offering to purchase. You can retrieve this ID from the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.