View source: R/sagemaker_operations.R
| sagemaker_list_ai_workload_configs | R Documentation |
Returns a list of AI workload configurations in your account. You can filter the results by name and creation time, and sort the results. The response is paginated.
See https://www.paws-r-sdk.com/docs/sagemaker_list_ai_workload_configs/ for full documentation.
sagemaker_list_ai_workload_configs(
MaxResults = NULL,
NextToken = NULL,
NameContains = NULL,
CreationTimeAfter = NULL,
CreationTimeBefore = NULL,
SortBy = NULL,
SortOrder = NULL
)
MaxResults |
The maximum number of AI workload configurations to return in the response. |
NextToken |
If the previous call to |
NameContains |
A string in the configuration name. This filter returns only configurations whose name contains the specified string. |
CreationTimeAfter |
A filter that returns only configurations created after the specified time. |
CreationTimeBefore |
A filter that returns only configurations created before the specified time. |
SortBy |
The field to sort results by. The default is |
SortOrder |
The sort order for results. The default is |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.