View source: R/sagemaker_operations.R
| sagemaker_list_pipeline_versions | R Documentation |
Gets a list of all versions of the pipeline.
See https://www.paws-r-sdk.com/docs/sagemaker_list_pipeline_versions/ for full documentation.
sagemaker_list_pipeline_versions(
PipelineName,
CreatedAfter = NULL,
CreatedBefore = NULL,
SortOrder = NULL,
NextToken = NULL,
MaxResults = NULL
)
PipelineName |
[required] The Amazon Resource Name (ARN) of the pipeline. |
CreatedAfter |
A filter that returns the pipeline versions that were created after a specified time. |
CreatedBefore |
A filter that returns the pipeline versions that were created before a specified time. |
SortOrder |
The sort order for the results. |
NextToken |
If the result of the previous |
MaxResults |
The maximum number of pipeline versions to return in the response. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.