View source: R/sagemaker_operations.R
| sagemaker_start_session | R Documentation |
Initiates a remote connection session between a local integrated development environments (IDEs) and a remote SageMaker space.
See https://www.paws-r-sdk.com/docs/sagemaker_start_session/ for full documentation.
sagemaker_start_session(ResourceIdentifier)
ResourceIdentifier |
[required] The Amazon Resource Name (ARN) of the resource to which the remote connection will be established. For example, this identifies the specific ARN space application you want to connect to from your local IDE. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.