View source: R/sagemaker_operations.R
| sagemaker_update_cluster_software | R Documentation |
Updates the platform software of a SageMaker HyperPod cluster for security patching. To learn how to use this API, see Update the SageMaker HyperPod platform software of a cluster.
See https://www.paws-r-sdk.com/docs/sagemaker_update_cluster_software/ for full documentation.
sagemaker_update_cluster_software(
ClusterName,
InstanceGroups = NULL,
DeploymentConfig = NULL,
ImageId = NULL
)
ClusterName |
[required] Specify the name or the Amazon Resource Name (ARN) of the SageMaker HyperPod cluster you want to update for security patching. |
InstanceGroups |
The array of instance groups for which to update AMI versions. |
DeploymentConfig |
The configuration to use when updating the AMI versions. |
ImageId |
When configuring your HyperPod cluster, you can specify an image ID using one of the following options:
If you choose to use a custom AMI (
When updating the instance group's AMI through the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.