View source: R/sagemaker_operations.R
| sagemaker_update_domain | R Documentation |
Updates the default settings for new user profiles in the domain.
See https://www.paws-r-sdk.com/docs/sagemaker_update_domain/ for full documentation.
sagemaker_update_domain(
DomainId,
DefaultUserSettings = NULL,
DomainSettingsForUpdate = NULL,
AppSecurityGroupManagement = NULL,
DefaultSpaceSettings = NULL,
SubnetIds = NULL,
AppNetworkAccessType = NULL,
TagPropagation = NULL,
HomeEfsFileSystemCreation = NULL,
VpcId = NULL
)
DomainId |
[required] The ID of the domain to be updated. |
DefaultUserSettings |
A collection of settings. |
DomainSettingsForUpdate |
A collection of |
AppSecurityGroupManagement |
The entity that creates and manages the required security groups for inter-app communication in |
DefaultSpaceSettings |
The default settings for shared spaces that users create in the domain. |
SubnetIds |
The VPC subnets that Studio uses for communication. If removing subnets, ensure there are no apps in the |
AppNetworkAccessType |
Specifies the VPC used for non-EFS traffic.
This configuration can only be modified if there are no apps in the |
TagPropagation |
Indicates whether custom tag propagation is supported for the domain. Defaults to |
HomeEfsFileSystemCreation |
Indicates whether to create a home EFS file system for the domain. You can change from |
VpcId |
The identifier for the VPC used by the domain for network communication. Use this field only when adding VPC configuration to a SageMaker AI domain used in Amazon SageMaker Unified Studio that was created without VPC settings. SageMaker AI doesn't automatically apply VPC updates to existing applications. Stop and restart your applications to apply the changes. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.