View source: R/sagemaker_operations.R
| sagemaker_update_hub_content | R Documentation |
Updates SageMaker hub content (either a Model or Notebook resource).
See https://www.paws-r-sdk.com/docs/sagemaker_update_hub_content/ for full documentation.
sagemaker_update_hub_content(
HubName,
HubContentName,
HubContentType,
HubContentVersion,
HubContentDisplayName = NULL,
HubContentDescription = NULL,
HubContentMarkdown = NULL,
HubContentSearchKeywords = NULL,
SupportStatus = NULL
)
HubName |
[required] The name of the SageMaker hub that contains the hub content you want to update. You can optionally use the hub ARN instead. |
HubContentName |
[required] The name of the hub content resource that you want to update. |
HubContentType |
[required] The content type of the resource that you want to update. Only specify a |
HubContentVersion |
[required] The hub content version that you want to update. For example, if you have two versions of a resource in your hub, you can update the second version. |
HubContentDisplayName |
The display name of the hub content. |
HubContentDescription |
The description of the hub content. |
HubContentMarkdown |
A string that provides a description of the hub content. This string can include links, tables, and standard markdown formatting. |
HubContentSearchKeywords |
The searchable keywords of the hub content. |
SupportStatus |
Indicates the current status of the hub content resource. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.