View source: R/sagemaker_operations.R
| sagemaker_update_inference_component | R Documentation |
Updates an inference component.
See https://www.paws-r-sdk.com/docs/sagemaker_update_inference_component/ for full documentation.
sagemaker_update_inference_component(
InferenceComponentName,
Specification = NULL,
Specifications = NULL,
RuntimeConfig = NULL,
DeploymentConfig = NULL
)
InferenceComponentName |
[required] The name of the inference component. |
Specification |
Details about the resources to deploy with this inference component, including the model, container, and compute resources. |
Specifications |
A list of specification objects for the inference component, one per instance type. Use this parameter when you want to specify different model or resource configurations for the inference component on each instance type. You can use either this parameter or the singular |
RuntimeConfig |
Runtime settings for a model that is deployed with an inference component. |
DeploymentConfig |
The deployment configuration for the inference component. The configuration contains the desired deployment strategy and rollback settings. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.